@@ -78,7 +78,7 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
 
   */
   gchar *help = NULL;
-
+  
   PxmMonomer *monomer = NULL;
   PxmChemgroup *chemgroup = NULL;
   PxmProp *prop = NULL;
@@ -89,8 +89,8 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
      element.
   */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "mnm"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, 
+			 "mnm"));
   
   /* Now go to the first child of current node.
    */
@@ -106,9 +106,9 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
   
   /* We now MUST have the <code> element.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "code"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "code"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
 
   /* We know the code of the monomer, we can allocate the monomer.
@@ -137,8 +137,7 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <chemgroup>.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar *) "chemgroup"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "chemgroup"));
       
       chemgroup = libpolyxmass_chemgroup_render_xml_node_chemgroup (xml_doc,
 						  xml_node,
@@ -147,8 +146,8 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
       if (chemgroup == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating a chemgroup instance "
-		 "from xml data\n",
+		 _("%s@%d: failed to create a chemgroup instance "
+		 "from xml data\n"),
 		 __FILE__, __LINE__);
 
 	  pxmchem_monomer_free (monomer);
@@ -207,9 +206,9 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
 							      "LE_PLM_MODIF"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: there can be at most one chemgroup in a monomer,"
+	     _("%s@%d: there can be at most one chemgroup in a monomer,"
 	     "that contains chemgrouprule instances with entity "
-	     "%s. The others have been removed.\n", 
+	     "%s. The others have been removed.\n"), 
 	     __FILE__, __LINE__, "LE_PLM_MODIF");
     }
 
@@ -218,9 +217,9 @@ libpolyxmass_acidobasic_render_xml_node_mnm (xmlDocPtr xml_doc,
 							      "RE_PLM_MODIF"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: there can be at most one chemgroup in a monomer,"
+	     _("%s@%d: there can be at most one chemgroup in a monomer,"
 	     "that contains chemgrouprule instances with entity "
-	     "%s. The others have been removed.\n", 
+	     "%s. The others have been removed.\n"), 
 	     __FILE__, __LINE__, "RE_PLM_MODIF");
     }
   
@@ -278,8 +277,7 @@ libpolyxmass_acidobasic_render_xml_node_monomers (xmlDocPtr xml_doc,
      element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "monomers"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "monomers"));
   
   /* Now go to the first child of current node. Since we do not know
      if there are elements of any kind, the best is to iterate in
@@ -299,8 +297,7 @@ libpolyxmass_acidobasic_render_xml_node_monomers (xmlDocPtr xml_doc,
     {
       /* Check that we have effectively a <mnm> element here.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar*) "mnm"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "mnm"));
       
       monomer = libpolyxmass_acidobasic_render_xml_node_mnm (xml_doc,
 							     xml_node,
@@ -308,7 +305,7 @@ libpolyxmass_acidobasic_render_xml_node_monomers (xmlDocPtr xml_doc,
       if (monomer == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not parse a <monomers> element\n",
+		 _("%s@%d: failed to parse a <monomers> element\n"),
 		 __FILE__, __LINE__);
 	  
 	  return FALSE;
@@ -363,7 +360,7 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
     
     xml_node is located at <mdf>
    */
-  gchar *help = NULL;
+  xmlChar *help = NULL;
 
   PxmModif *modif = NULL;
   
@@ -375,7 +372,7 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
      element.
   */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "mdf"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "mdf"));
   
   /* Now go to the first child of current node: <value>.
    */
@@ -391,7 +388,7 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
   
   /* We now MUST have the <name> element.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
   
   help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
@@ -400,7 +397,7 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
    */
   modif = pxmchem_modif_new ();
   
-  pxmchem_modif_set_name (modif, help);
+  pxmchem_modif_set_name (modif, (gchar *) help);
   
   g_free (help);
   
@@ -422,8 +419,7 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <chemgroup>.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar *) "chemgroup"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "chemgroup"));
       
       chemgroup = libpolyxmass_chemgroup_render_xml_node_chemgroup (xml_doc,
 						  xml_node,
@@ -431,8 +427,8 @@ libpolyxmass_acidobasic_render_xml_node_mdf (xmlDocPtr xml_doc,
       if (chemgroup == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating a chemgroup instance "
-		 "from xml data\n",
+		 _("%s@%d: failed to create a chemgroup instance "
+		 "from xml data\n"),
 		 __FILE__, __LINE__);
 
 	  pxmchem_modif_free (modif);
@@ -505,8 +501,7 @@ libpolyxmass_acidobasic_render_xml_node_modifs (xmlDocPtr xml_doc,
      element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "modifs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "modifs"));
   
   /* Now go to the first child of current node. Since we do not know
      if there are elements of any kind, the best is to iterate in
@@ -526,8 +521,7 @@ libpolyxmass_acidobasic_render_xml_node_modifs (xmlDocPtr xml_doc,
     {
       /* Check that we have effectively a <mdf> element here.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar*) "mdf"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "mdf"));
       
       modif = libpolyxmass_acidobasic_render_xml_node_mdf (xml_doc,
 							   xml_node,
@@ -536,7 +530,7 @@ libpolyxmass_acidobasic_render_xml_node_modifs (xmlDocPtr xml_doc,
       if (modif == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not parse a <modifs> element\n",
+		 _("%s@%d: failed to parse a <modifs> element\n"),
 		 __FILE__, __LINE__);
 	  
 	  return FALSE;
@@ -585,7 +579,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	     _("%s@%d: file does not exist: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return FALSE;
@@ -598,7 +592,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	     _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return FALSE;
@@ -611,7 +605,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
      return FALSE;
@@ -624,7 +618,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -632,11 +626,11 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
       return FALSE;
     }
 
-  if (xmlStrcmp (xml_node->name, (const xmlChar *) "acidobasicdata"))
+  if (strcmp ((gchar *) xml_node->name, "acidobasicdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"acidobasicdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not \"acidobasicdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -659,7 +653,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
   
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "monomers"))
+      if (0 == strcmp ((gchar *) xml_node->name, "monomers"))
 	{
 	  if (FALSE == 
 	      libpolyxmass_acidobasic_render_xml_node_monomers (xml_doc,
@@ -668,13 +662,13 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
 								NULL))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: could not render xml monomers node\n",
+		    _("%s@%d: failed to render xml monomers node\n"),
 		     __FILE__, __LINE__);
 	      
 	      return FALSE;
 	    }
 	}
-      else if (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "modifs"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "modifs"))
 	{
 	  if (FALSE == 
 	      libpolyxmass_acidobasic_render_xml_node_modifs (xml_doc,
@@ -683,7 +677,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
 							      NULL))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: could not render xml modifs node\n",
+		    _("%s@%d: failed to render xml modifs node\n"),
 		     __FILE__, __LINE__);
 	      
 	      return FALSE;
@@ -750,28 +744,16 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
       {
 	monomer = g_ptr_array_index (mnmGPA, iter);
 	
-	debug_printf (("monomer %s\n",monomer->code));
-
 	for (jter = 0; jter < monomer->propGPA->len ; jter++)
 	  {
 	    prop = g_ptr_array_index (monomer->propGPA, jter);
 
 	    chemgroup = prop->data;
 	    
-	    debug_printf (("\t prop is '%s'\n", prop->name));
-	    debug_printf (("\t chemgroup value is '%lf'; chemgroup end rule is '%d'; "
-			   "acidcharged is '%d'\n", 
-
-			   chemgroup->value,
-			   chemgroup->endrule,
-			   chemgroup->acidcharged));
-	    	    
 	    for (kter = 0 ; kter < chemgroup->prGPA->len; kter++)
 	      {
 		pr = g_ptr_array_index (chemgroup->prGPA, kter);
 		
-		debug_printf (("\t\t pr entity is '%s' and outcome is '%d'\n",
-			       pr->entity, pr->outcome));
 	      }
 	    
 	  }
@@ -781,28 +763,16 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
       {
 	modif = g_ptr_array_index (mdfGPA, iter);
 	
-	debug_printf (("modif %s\n",modif->name));
-
 	for (jter = 0; jter < modif->propGPA->len ; jter++)
 	  {
 	    prop = g_ptr_array_index (modif->propGPA, jter);
 
 	    chemgroup = prop->data;
 	    
-	    debug_printf (("\t prop is '%s'\n", prop->name));
-	    debug_printf (("\t chemgroup value is '%lf'; chemgroup end rule is '%d'; "
-			   "acidcharged is '%d'\n", 
-
-			   chemgroup->value,
-			   chemgroup->endrule,
-			   chemgroup->acidcharged));
-	    	    
 	    for (kter = 0 ; kter < chemgroup->prGPA->len; kter++)
 	      {
 		pr = g_ptr_array_index (chemgroup->prGPA, kter);
 		
-		debug_printf (("\t\t pr entity is '%s' and outcome is '%d'\n",
-			       pr->entity, pr->outcome));
 	      }
 	    
 	  }
@@ -814,7 +784,7 @@ libpolyxmass_acidobasic_render_xml_file (gchar *file,
 
 
 gdouble
-libpolyxmass_acidobasic_compute_charge_ratio (gdouble pka,
+libpolyxmass_acidobasic_calculate_charge_ratio (gdouble pka,
 					      gdouble ph,
 					      gboolean acidcharged)
 {
