@@ -211,7 +211,7 @@ libpolyxmass_atomspec_init_from_cat_line (gchar *line,
   if (atomdef_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error parsing a atomspec line: '%s'\n"),
+	     _("%s@%d: failed to parse atomspec line: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       g_string_free (gs, TRUE);
@@ -286,7 +286,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_file (gchar* file,
   if (cfgp == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with opening file '%s'\n"),
+	     _("%s@%d: failed to  open file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return -1;
@@ -311,7 +311,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_file (gchar* file,
       read = fgets (read, MAX_LINE_LENGTH, cfgp);
 
       /*
-      debug_printf (("file %s -- read line '%s'\n", 
+      debug_printf (("file: '%s' -- read line: '%s'\n", 
 		     file, read));
       */
       if (read != NULL && strlen (read) > 1)
@@ -375,12 +375,12 @@ libpolyxmass_atomspec_parse_atom_defs_cat_file (gchar* file,
 	      else /* if (pre_ap_pend == CONFIG_PREPEND) */
 		{
 		  /*
-		  debug_printf (("array length is %d\n", GPA->len));
+		  debug_printf (("array length is: '%d'\n", GPA->len));
 		  */
 		  g_ptr_array_insert_val (GPA, 0, as);
 	      
 	      /*
-		debug_printf (("added new as: %s--%s--%s\n",
+		debug_printf (("added new as: '%s--%s--%s'\n",
 		as->poltype, as->atomdef, as->file));
 	      */
 		}
@@ -462,7 +462,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_files (GPtrArray *GPA,
 	  while (parsed_file != NULL)
 	    {
 	      /*
-		debug_printf (("parsed_file is %s\n", parsed_file));
+		debug_printf (("parsed_file is: '%s'\n", parsed_file));
 	      */
 
 	      /* Translate the name to utf_8.
@@ -508,7 +508,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
@@ -560,7 +560,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_files (GPtrArray *GPA,
 	  while (parsed_file != NULL)
 	    {
 	      /*
-		debug_printf (("parsed_file is %s\n", parsed_file));
+		debug_printf (("parsed_file is: '%s'\n", parsed_file));
 	      */
 
 	      /* Translate the name to utf_8.
@@ -606,7 +606,7 @@ libpolyxmass_atomspec_parse_atom_defs_cat_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
@@ -706,7 +706,7 @@ libpolyxmass_atomspec_init_from_dic_line (gchar *line,
   if (poltype_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error parsing a atomspec line: '%s'\n"),
+	     _("%s@%d: failed to parse atomspec line: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       g_string_free (gs, TRUE);
@@ -764,7 +764,7 @@ libpolyxmass_atomspec_parse_polchem_defs_atom_defs_dic_file (gchar* file,
   if (cfgp == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with opening file '%s'\n"),
+	     _("%s@%d: failed to  open file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return -1;
@@ -789,7 +789,7 @@ libpolyxmass_atomspec_parse_polchem_defs_atom_defs_dic_file (gchar* file,
       read = fgets (read, MAX_LINE_LENGTH, cfgp);
 
       /*
-      debug_printf (("file %s -- read line '%s'\n", 
+      debug_printf (("file: '%s' -- read line: '%s'\n", 
 		     file, read));
       */
       if (read != NULL && strlen (read) > 1)
@@ -854,13 +854,13 @@ libpolyxmass_atomspec_parse_polchem_defs_atom_defs_dic_file (gchar* file,
 		{
 		  g_ptr_array_insert_val (GPA, 0, as);
 		  /*
-		  debug_printf (("array length is %d\n", GPA->len));
+		  debug_printf (("array length is: '%d'\n", GPA->len));
 		  */
 		}
 	      
 
 	      /*
-		debug_printf (("added new as: %s--%s--%s\n",
+		debug_printf (("added new as: '%s--%s--%s'\n",
 		as->poltype, as->atomdef, as->file));
 	      */
 	      
@@ -982,7 +982,7 @@ libpolyxmass_atomspec_parse_polchem_defs_atom_defs_dic_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
@@ -1077,7 +1077,7 @@ libpolyxmass_atomspec_parse_polchem_defs_atom_defs_dic_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
@@ -1215,7 +1215,7 @@ libpolyxmass_atomspec_arrays_cross_complete_dic_cat_data (GPtrArray *dicGPA,
 
       if (found == FALSE)
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-	       _("%s@%d: failed initializing atom dictionary data\n"),
+	       _("%s@%d: failed to initialize atom dictionary data\n"),
 	       __FILE__, __LINE__);
     }
   /* End of 
