@@ -287,9 +287,9 @@ libpolyxmass_chemgroup_ensure_single_containing_entity (PxmMonomer *monomer,
 		  g_assert (TRUE == g_ptr_array_remove (chemgroup->cgrGPA,
 							cgr));
 
-		  debug_printf (("removing chemgrouprule of entity '%s' "
-				 "at index '%d' of cgrGPA for chemgroup "
-				 "at index %d",cgr->entity, jter, iter));
+		  debug_printf (("removing chemgrouprule of entity: '%s' "
+				 "at index: '%d' of cgrGPA for chemgroup "
+				 "at index: '%d'", cgr->entity, jter, iter));
 		  
 		  libpolyxmass_chemgrouprule_free (cgr);
 
@@ -376,10 +376,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xmlDocPtr xml_doc,
 
   /* Make sure we have parameters pointing bona fide to the right xml
      element.
-   */
+%   */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "chemgrouprule"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "chemgrouprule"));
   
   /* Now go to the first child of current node. It has to be a <entity>
      element.
@@ -394,10 +393,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode (xml_node))
     xml_node = xml_node->next;
 
-  g_assert (0 == xmlStrcmp ("entity",
-			    (const xmlChar*) xml_node->name));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "entity"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
   
   /* We have an entity character string, so it makes sense to allocate
@@ -420,10 +418,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode (xml_node))
     xml_node = xml_node->next;
   
-  g_assert (0 == xmlStrcmp ("name",
-			    (const xmlChar*) xml_node->name));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
   
   libpolyxmass_chemgrouprule_set_name (cgr, help);
@@ -442,10 +439,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xmlDocPtr xml_doc,
     xml_node = xml_node->next;
   
 
-  g_assert (0 == xmlStrcmp ("outcome",
-			    (const xmlChar*) xml_node->name));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "outcome"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
   
   if (0 == strcmp ("LOST", help))
@@ -463,8 +459,8 @@ libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xmlDocPtr xml_doc,
   else
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: failed getting value for PxmChemgroupRule "
-	     "element <outcome>\n",
+	     _("%s@%d: failed to get value for PxmChemgroupRule "
+	     "element <outcome>\n"),
 	     __FILE__, __LINE__);
       
       libpolyxmass_chemgrouprule_free (cgr);
@@ -530,8 +526,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
      element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "chemgroup"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "chemgroup"));
   
   /* At this point we know we have a chemgroup so we can allocate a
      chemgroup object.
@@ -553,10 +548,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
   
   /* The first element is compulsory: <name>
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
   
   libpolyxmass_chemgroup_set_name (chemgroup, help);
@@ -576,10 +570,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 
   /* Check if we have a <pka> element here.
    */
-  if (0 == xmlStrcmp (xml_node->name, 
-		      (const xmlChar *) "pka"))
+  if (0 == strcmp ((gchar *) xml_node->name, "pka"))
     {
-      help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+      help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
       g_assert (help != NULL);
       
       if (FALSE == libpolyxmass_globals_strtod (help, &test))
@@ -587,7 +580,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 	  g_free (help);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not convert mass '%s' to gdouble\n",
+		_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, 
 		 xml_node->xmlChildrenNode->content);
 	  
@@ -601,7 +594,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
       if (test < 0 || test > 14)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: value of pka is not valid : '%lf'\n",
+		_("%s@%d: value of pka is incorrec: '%lf'\n"),
 		 __FILE__, __LINE__, 
 		 test);
 	  
@@ -626,10 +619,9 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
       while (TRUE == xmlIsBlankNode (xml_node))
 	xml_node = xml_node->next;
   
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar *) "acidcharged"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "acidcharged"));
       
-      help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+      help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
       g_assert (help != NULL);
 
       if (0 == strcmp ("FALSE", help))
@@ -643,7 +635,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 	  libpolyxmass_chemgroup_free (chemgroup);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not parse the <acidcharged> element\n",
+		_("%s@%d: failed to parse the <acidcharged> element\n"),
 		 __FILE__, __LINE__);
 	  
 	  return NULL;
@@ -673,12 +665,12 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
   
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp (xml_node->name, (const xmlChar*) "polrule"))
+      if (0 == strcmp ((gchar *) xml_node->name, "polrule"))
 	{
 	  /* We are parsing a <polrule> element. Do the work right here.
 	   */
 	  help = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
       
 	  g_assert (help != NULL);
       
@@ -693,7 +685,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 	      g_free (help);
 	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: failed getting value for <polrule>\n",
+		    _("%s@%d: failed to get value for <polrule>\n"),
 		     __FILE__, __LINE__);
 	  
 	      libpolyxmass_chemgroup_free (chemgroup);
@@ -737,8 +729,8 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 	 point the only elements that we can have are <chemgrouprule>
 	 elements.
       */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar*) "chemgrouprule"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, 
+			     "chemgrouprule"));
       
       cgr = libpolyxmass_chemgroup_render_xml_node_chemgrouprule (xml_doc,
 						     xml_node,
@@ -748,7 +740,7 @@ libpolyxmass_chemgroup_render_xml_node_chemgroup (xmlDocPtr xml_doc,
 	  libpolyxmass_chemgroup_free (chemgroup);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not parse a <chemgrouprule> element\n",
+		_("%s@%d: failed to parse a <chemgrouprule> element\n"),
 		 __FILE__, __LINE__);
 	  
 	  return NULL;
