@@ -38,7 +38,7 @@
 /* fully copied from glib file garray.c in order to implement
  * function below g_ptr_array_insert_val
  */
-/** glib function to compute the size of the GPtrArray in order
+/** glib function to calculate the size of the GPtrArray in order
  * to allow insertion of a new item to it
  */
 gint 
@@ -317,7 +317,7 @@ libpolyxmass_globals_parse_masses_in_text (gchar *text,
 	      /* Failed converting the string to a gdouble.
 	       */
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
-		     "%s@%d: failed converting '%s' into a gdouble\n",
+		    _("%s@%d: failed to convert from '%s' to gdouble\n"),
 		     __FILE__, __LINE__, unspacified_text);
 	      
 	      /* Go on anyway, maybe there are some strings that are worth
@@ -423,7 +423,7 @@ libpolyxmass_globals_check_xml_file (gchar *file)
   if (stream == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: could not open file: %s\n",
+	_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       return FALSE;
@@ -498,7 +498,7 @@ libpolyxmass_globals_copy_files (gchar *dest, gchar *src)
   if (srcp == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: error with opening source file %s\n"),
+	 _("%s@%d: failed to  open source file: '%s'\n"),
 	 __FILE__, __LINE__, src);
 
       if (srcp != NULL)
@@ -512,7 +512,7 @@ libpolyxmass_globals_copy_files (gchar *dest, gchar *src)
   if (destp == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: error with opening destination file %s\n"),
+	 _("%s@%d: failed to  open destination file: '%s'\n"),
 	 __FILE__, __LINE__, dest);
 
       if (destp != NULL)
@@ -543,7 +543,7 @@ libpolyxmass_globals_copy_files (gchar *dest, gchar *src)
 	  if (result == EOF || result < 0)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: error writing to file %s\n"),
+		     _("%s@%d: failed to write to file: '%s'\n"),
 		     __FILE__, __LINE__, dest);
 
 	      g_free (line);
@@ -583,7 +583,7 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
   if (strlen (str) <= 0)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	 "%s@%d: string to convert is empty\n",
+	_("%s@%d: string to convert is empty\n"),
 	 __FILE__, __LINE__);
 
       return FALSE;
@@ -607,6 +607,7 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
   if (strchr (str, '-') != strrchr (str, '-'))
     return FALSE;
 
+
   /* We first apply a conversion to a long, and then, using the returned
    * value we can test if it is higher or lower than the gint can
    * tolerate.
@@ -620,8 +621,8 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
       if (errno == ERANGE)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: Conversion error occurred, value too small\n",
-		 __FILE__, __LINE__);
+		_("%s@%d: failed to convert from '%s' to gdouble, value too small\n"),
+		 __FILE__, __LINE__, str);
 	  
 	  return FALSE;
 	}
@@ -631,8 +632,8 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
       if (errno == ERANGE)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: Overflow occurred, value too positively big\n",
-		 __FILE__, __LINE__);
+		_("%s@%d: failed to convert from '%s' to gdouble, overflow occurred: value too positively big\n"),
+		 __FILE__, __LINE__, str);
 
 	  return FALSE;
 	}
@@ -642,8 +643,8 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
       if (errno == ERANGE)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: Underflow occurred, value too negatively big\n",
-		 __FILE__, __LINE__);
+		_("%s@%d: failed to convert from '%s' to gdouble, underflow occurred, value too negatively big\n"),
+		 __FILE__, __LINE__, str);
 
 	  return FALSE;
 	}
@@ -651,7 +652,7 @@ libpolyxmass_globals_strtod (gchar* str, gdouble* val)
 
   if (strlen (endptr) > 0)
     return FALSE;
-
+  
   *val = doubleval;
   
   return TRUE;
@@ -674,7 +675,7 @@ libpolyxmass_globals_strtoi (gchar *str, gint* val, gint base)
   if (strlen (str) <= 0)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	 "%s@%d: string to convert is empty\n",
+	_("%s@%d: string to convert is empty\n"),
 	 __FILE__, __LINE__);
 
       return FALSE;
@@ -709,8 +710,8 @@ libpolyxmass_globals_strtoi (gchar *str, gint* val, gint base)
   if (errno != 0) 
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: Conversion error occurred, overflow\n",
-	     __FILE__, __LINE__);
+	    _("%s@%d: failed to convert from '%s' to gint, overflow\n"),
+	     __FILE__, __LINE__, str);
       
       return FALSE;
     }
@@ -718,10 +719,10 @@ libpolyxmass_globals_strtoi (gchar *str, gint* val, gint base)
   if (endptr != NULL && strlen (endptr) > 0)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: Conversion error occurred, \n"
-	     "with endptr='%s' (endptr[0]=%c) of length %d "
-	     "and long_val='%ld'.\n",
-	     __FILE__, __LINE__, endptr, endptr[0], 
+	     _("%s@%d: failed to convert from '%s' to gint\n"
+	     "with endptr='%s' (endptr[0]=%c) of length: '%zu'"
+	     " and long_val='%ld'.\n"),
+	     __FILE__, __LINE__, str, endptr, endptr[0], 
 	     strlen (endptr), long_val);
       
       return FALSE;
@@ -735,9 +736,8 @@ libpolyxmass_globals_strtoi (gchar *str, gint* val, gint base)
       /* Not in the gint range.
        */
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: Conversion error, %s is not in the gint range\n",
-	     __FILE__, __LINE__,
-	     str);
+	    _("%s@%d: failed to convert from '%s' to gint, not in the gint range\n"),
+	     __FILE__, __LINE__, str);
       
       return FALSE;
     }
@@ -754,7 +754,7 @@ libpolyxmass_globals_dtoa (gdouble val, gint prec)
   gchar *format = NULL;
   gchar *convert = NULL;
 
-  /*construct a format string like the ones used with printf()
+  /* Construct a format string like the ones used with printf()
    */
   format = g_strdup_printf ("%%.%df", prec);
 
