@@ -428,7 +428,7 @@ libpolyxmass_modifspec_init_from_monicons_dic_line (gchar *line,
       || action_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: line not well formed: %s\n"),
+	     _("%s@%d: line is not well formed: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       libpolyxmass_modifspec_free (ms);
@@ -487,7 +487,7 @@ libpolyxmass_modifspec_parse_monicons_dic_file (gchar *file,
   if (NULL == cfgp)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: file not found: %s\n"),
+	     _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       g_free (dir);
@@ -661,7 +661,7 @@ libpolyxmass_modifspec_init_from_sounds_dic_line (gchar *line,
   if (name_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: line not well formed: %s\n"),
+	     _("%s@%d: line is not well formed: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       libpolyxmass_modifspec_free (ms);
@@ -757,7 +757,7 @@ libpolyxmass_modifspec_parse_sounds_dic_file (gchar *file,
   if (NULL == cfgp)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: file not found: %s\n"),
+	     _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       g_free (dir);
