@@ -414,7 +414,7 @@ libpolyxmass_monomerspec_init_from_monicons_dic_line (gchar *line,
   if (code_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: line not well formed: %s\n"),
+	     _("%s@%d: line is not well formed: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       libpolyxmass_monomerspec_free (ms);
@@ -473,7 +473,7 @@ libpolyxmass_monomerspec_parse_monicons_dic_file (gchar *file,
   if (NULL == cfgp)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: file not found: %s\n"),
+	     _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       g_free (dir);
@@ -725,7 +725,7 @@ libpolyxmass_monomerspec_init_from_sounds_dic_line (gchar *line,
   if (code_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: line not well formed: %s\n"),
+	     _("%s@%d: line is not well formed: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       libpolyxmass_monomerspec_free (ms);
@@ -784,7 +784,7 @@ libpolyxmass_monomerspec_parse_sounds_dic_file (gchar *file,
   if (NULL == cfgp)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: file not found: %s\n"),
+	     _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       g_free (dir);
