@@ -111,7 +111,7 @@ libpolyxmass_noteval_dup (PxmNoteVal *noteval, gint how_dup)
 	}
       else
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-	       _("%s@%d: bad type for noteval value. Exiting.\n"),
+	       _("%s@%d: the noteval->type is not valid\n"),
 	       __FILE__, __LINE__);
     }
   
@@ -288,7 +288,7 @@ libpolyxmass_noteval_cmp (PxmNoteVal *noteval1,
 		   != *(gdouble *) noteval2->value);
       else
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-	       _("%s@%d: bad type for noteval values. Exiting.\n"),
+	       _("%s@%d: the noteval->type is not valid\n"),
 	       __FILE__, __LINE__);
     }
 
@@ -501,10 +501,10 @@ libpolyxmass_note_prop_cmp (PxmProp *prop1,
 /* RENDERING FUNCTIONS - FORMATTER FUNCTIONS
  */
 gchar*
-libpolyxmass_note_prop_format_xml_node_note (PxmProp *prop,
-					 gchar *indent,
-					 gint offset,
-					 gpointer user_data)
+libpolyxmass_note_prop_format_xml_note (PxmProp *prop,
+					gchar *indent,
+					gint offset,
+					gpointer user_data)
 {
   /* This formatter is used when a polymer sequence has property
      object (type PxmProp) of name "NOTE" (for which the data
@@ -614,7 +614,7 @@ libpolyxmass_note_prop_format_xml_node_note (PxmProp *prop,
 				"type=\"dbl\"",
 				*(gdouble *) noteval->value);
       else g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-		  _("%s@%d: the noteval->type is not valid. Exiting.\n"),
+		  _("%s@%d: the noteval->type is not valid\n"),
 		  __FILE__, __LINE__);
     }
   
@@ -636,10 +636,115 @@ libpolyxmass_note_prop_format_xml_node_note (PxmProp *prop,
 }
 
 
+gchar*
+libpolyxmass_note_prop_format_txt_note (PxmProp *prop,
+					gpointer user_data)
+{
+  /* This formatter is used when a polymer sequence has property
+     object (type PxmProp) of name "NOTE" (for which the data points
+     to a PxmNote object). If such polymer sequence has to be saved to
+     a file, under format txt, then when the saving function encounter
+     a "NOTE"-named PxmProp object, it calls this saving function
+     which is responsible for creating a character string to be sent
+     to the txt file (or txt string for clipboard operations).
+
+     The name of a PxmNote is a string of character, which is saved
+     very easily in the txt file, under heading "name:". The PxmNote
+     object contains an array of PxmNoteval objects, which have to be
+     deconstructed one by one (see array-iterating loop below) under a
+     "data:" header, with an attribute that can either be "str" or
+     "int" or "dbl", respectively to indicate that the data in the
+     PxmNoteval object is text or numerical gint or gdouble.
+  */
+  PxmNote *note = NULL;
+  
+  GString *gs = NULL;
+  
+  gchar *help = NULL;
+  PxmNoteVal *noteval = NULL;
+  
+  gint iter = 0;
+  
+  g_assert (prop != NULL);
+  g_assert (prop->name != NULL && prop->data != NULL);
+  
+  /* OK, the property to be formatter as XML text is not NULL and none
+     of its member either. Let's get to the PxmNote object that is
+     pointed by the prop->data member.
+  */
+  note = (PxmNote *) prop->data;
+  g_assert (note->name != NULL && note->notevalGPA != NULL);
+  
+  /* OK, both the name and value members of the PxmNote object
+     are non-NULL. We can start doing our work.
+  */
+  
+  gs = g_string_new ("");
+  g_assert (gs != NULL);
+
+  /* We are willing to create a SINGLE "note": text paragraph that
+     should look like this:
+
+     prop:
+     -----
+     name: NOTE
+     data: NOTE_NAME
+     data type="str" "WHATEVER_STRING: the note's value
+     data type="int" WHATEVER_STRING: the note's value
+     data type="dbl" WHATEVER_STRING: the note's value
+  */
+
+  g_string_append_printf (gs, "prop:\n"
+                               "-----\n");
+  
+  /* The prop name member.
+   */
+  g_string_append_printf (gs, "name: '%s'\n", prop->name);
+  
+  /* The note name member.
+   */
+  g_string_append_printf (gs, "data: '%s'\n", (gchar*) note->name);
+  
+  /* We now have to iterate in the note->valGPA and for each string
+     found in the array we have to make a <data> element.
+  */
+  for (iter = 0 ; iter < note->notevalGPA->len ; iter++)
+    {
+      noteval = g_ptr_array_index (note->notevalGPA, iter);
+      g_assert (noteval != NULL);
+      
+      /* Make the string to append to the gs xml string. The way the string
+	 is made depends on the type of the value:
+      */
+      if (noteval->type == PXM_NOTE_VAL_TYPE_STR)
+	g_string_append_printf (gs, 
+				"data type=\"str\" %s\n", 
+				(gchar*) noteval->value);
+      else if (noteval->type == PXM_NOTE_VAL_TYPE_INT)
+	g_string_append_printf (gs, 
+				"data type=\"int\" %d\n", 
+				*(gint *) noteval->value);
+      else if (noteval->type == PXM_NOTE_VAL_TYPE_DBL)
+	g_string_append_printf (gs, 
+				"data type=\"dbl\" %.9f\n",
+				*(gdouble *) noteval->value);
+      else g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
+		  _("%s@%d: the noteval->type is not valid\n"),
+		  __FILE__, __LINE__);
+    }
+  
+  help = gs->str;
+  
+  g_string_free (gs, FALSE);
+  
+  return help;
+}
+
+
 PxmProp*
-libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
-					 xmlNodePtr xml_node,
-					 gpointer user_data)
+libpolyxmass_note_prop_render_xml_note (xmlDocPtr xml_doc,
+					xmlNodePtr xml_node,
+					gpointer user_data)
 {
   /* This xml renderer is responsible for rendering a xml note that
      corresponds to a <prop> element of which the <name> element has
@@ -685,7 +790,7 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
   g_assert (xml_node != NULL);
   g_assert (xml_doc != NULL);
 
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "prop"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "prop"));
   
   /* Allocate the PxmProp object, so that we'll fill it with read
      data.
@@ -707,13 +812,14 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
   /* We have encountered the next children's element: it should be
      <name>. That <name> element should contain the "NOTE" string.
   */
-  g_assert (0 == strcmp (xml_node->name, (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, 
+			 "name"));
 
   /* Get the name of the property so that we can start filling the
    * prop instance.
    */
   prop->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (prop->name != NULL);
   g_assert (0 == strcmp ("NOTE", prop->name));
 
@@ -735,9 +841,9 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
   /* We got to the first <data> element, which is going to be the 
      PxmNote note->name member.
   */
-  g_assert (0 == strcmp (xml_node->name, "data"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "data"));
 
-  note->name = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  note->name = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (note->name != NULL);
   
   /* At this point go to the element(s) that is (are) to become the
@@ -753,7 +859,7 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
     {
       /* If there is a node, it cannot be of any name other than "data".
        */
-      g_assert (0 == strcmp (xml_node->name, "data"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "data"));
 
       /* Collect the value that is associated with the "data"
 	 element. That string is to go to the note->valGPA array of
@@ -761,7 +867,7 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
 	 existence _per se_ of the "data" element is questionable !
       */
       value = 
-	xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	(gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
       g_assert (value != NULL);
 
       /* We know that we are going to need a PxmNoteVal object. So just
@@ -773,7 +879,7 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
 	 optional, if it is absent, then that equals to a string
 	 type.
       */
-      type = xmlGetProp (xml_node, "type");
+      type = (gchar *) xmlGetProp (xml_node, (guchar*) "type");
 
       /*
 	debug_printf (("type is now %s\n", type));
@@ -804,9 +910,8 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
 					   (gint *) noteval->value,
 					   10))
 		g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-		       _("%s@%d: error converting value to gint. "
-			 "Exiting.\n"),
-		       __FILE__, __LINE__);
+		       _("%s@%d: failed to convert from '%s' to gint\n"),
+		       __FILE__, __LINE__, value);
 	    }
 	  else if (0 == strcmp ("dbl", type))
 	    {
@@ -816,13 +921,12 @@ libpolyxmass_note_prop_render_xml_node_note (xmlDocPtr xml_doc,
 		  libpolyxmass_globals_strtod (value,
 					   (gdouble *) noteval->value))
 		g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-		       _("%s@%d: error converting value to gdouble. "
-			 "Exiting.\n"),
-		       __FILE__, __LINE__);
+		       _("%s@%d: failed to convert from '%s' to gdouble\n"),
+		       __FILE__, __LINE__, value);
 	    }
 	  else
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-		   _("%s@%d: file badly formed. Exiting.\n"),
+		   _("%s@%d: file badly formed.\n"),
 		   __FILE__, __LINE__);
 
 	  /* At this point we do not need the attribute anymore.
