@@ -50,6 +50,24 @@ libpolyxmass_polchemdefspec_new (void)
 }
 
 
+PxmPolchemdefSpec *
+libpolyxmass_polchemdefspec_dup (PxmPolchemdefSpec *ps)
+{
+  PxmPolchemdefSpec *new_ps = NULL;
+  
+  g_assert (ps != NULL);
+  
+  new_ps = libpolyxmass_polchemdefspec_new ();
+  
+  new_ps->type = g_strdup (ps->type) ;
+  new_ps->file = g_strdup (ps->file) ;
+  new_ps->source = ps->source ;
+  
+  return new_ps;
+}
+
+
+
 gboolean
 libpolyxmass_polchemdefspec_set_type (PxmPolchemdefSpec *ps, gchar *type)
 {
@@ -352,7 +370,7 @@ libpolyxmass_polchemdefspec_init_from_cat_line (gchar *line,
   if (type_done == FALSE || file_done == FALSE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error parsing a polchemdefspec line: '%s'\n"),
+	     _("%s@%d: failed to parse polchemdefspec line: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       g_string_free (gs, TRUE);
@@ -430,7 +448,7 @@ libpolyxmass_polchemdefspec_parse_polchem_defs_cat_file (gchar *file,
   if (cfgp == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with opening file '%s'\n"),
+	     _("%s@%d: failed to  open file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return -1;
@@ -545,7 +563,7 @@ libpolyxmass_polchemdefspec_parse_polchem_defs_cat_file (gchar *file,
 			g_ptr_array_insert_val (GPA, 0, ps);
 		      
 		      /*
-			debug_printf (("added new ps: %s--%s--%s\n",
+			debug_printf (("added new ps: '%s--%s--%s'\n",
 			ps->type, ps->file, ps->dir));
 		      */
 		      
@@ -690,7 +708,7 @@ libpolyxmass_polchemdefspec_parse_polchem_defs_cat_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
@@ -787,7 +805,7 @@ libpolyxmass_polchemdefspec_parse_polchem_defs_cat_files (GPtrArray *GPA,
 	      if (count == -1)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-			 _("%s@%d: failed parsing file '%s'\n"),
+			 _("%s@%d: failed to parse file: '%s'\n"),
 			 __FILE__, __LINE__, absolute_filename);
 		}
 	      
