@@ -457,6 +457,44 @@ libpolyxmass_prop_format_xml_prop_default (PxmProp *prop,
 }
 
 
+gchar*
+libpolyxmass_prop_format_txt_prop_default (PxmProp *prop,
+					   gpointer user_data)
+{
+  /* This default txt formatter, considers that the data member of the
+     prop parameter is a string. It is thus considered simple
+     characters, exactly as is the name of the same prop instance.
+   */
+  GString *gs = NULL;
+  
+  gchar *help = NULL;
+
+  g_assert (prop != NULL);
+  g_assert (prop->name != NULL && prop->data != NULL);
+  
+  gs = g_string_new ("");
+  g_assert (gs != NULL);
+
+
+  g_string_append_printf (gs, "prop:\n"
+                               "-----\n");
+
+  /* The prop name member.
+   */
+  g_string_append_printf (gs, "name: '%s'\n", prop->name);
+  
+  /* The prop data member, which is a string in _this_ plugin.
+   */
+  g_string_append_printf (gs, "data: '%s'\n", (gchar*) prop->data);
+  
+  help = gs->str;
+  
+  g_string_free (gs, FALSE);
+  
+  return help;
+}
+
+
 PxmProp*
 libpolyxmass_prop_render_xml_prop_default (xmlDocPtr xml_doc,
 				       xmlNodePtr xml_node,
@@ -498,7 +536,7 @@ libpolyxmass_prop_render_xml_prop_default (xmlDocPtr xml_doc,
   g_assert (xml_node != NULL);
   g_assert (xml_doc != NULL);
 
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "prop"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "prop"));
   
   /* Allocate the PxmProp, so that we'll be able to fill it 
    * it with xml-based data.
@@ -517,13 +555,13 @@ libpolyxmass_prop_render_xml_prop_default (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode(xml_node))
     xml_node = xml_node->next;
 
-  g_assert (0 == strcmp (xml_node->name, (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   /* Get the name of the property so that we can start filling the
    * prop instance.
    */
   prop->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (prop->name != NULL);
   
   /* Go to next child of the prop element, which, according
@@ -538,10 +576,10 @@ libpolyxmass_prop_render_xml_prop_default (xmlDocPtr xml_doc,
    * contains #PCDATA
    * which means that we just allocate a string:
    */
-  g_assert (0 == strcmp (xml_node->name, "data"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "data"));
 
   prop->data = 
-    (gpointer) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gpointer) (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (prop->data != NULL);
   
   return prop;
