@@ -98,7 +98,7 @@ pxmchem_atom_new_by_symbol (gchar *symbol, GPtrArray *atom_refGPA)
    * found in the array. Error, then.
    */
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	 "%s@%d: no atom was found by the same symbol: %s\n",
+	_("%s@%d: failed to find an atom by the same symbol: '%s'\n"),
 	 __FILE__, __LINE__, symbol);
   
   return NULL;
@@ -201,7 +201,7 @@ pxmchem_atom_fill_masspair (gchar *symbol,
     }
   
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: could not find atom with symbol '%s'\n"),
+	 _("%s@%d: failed to find an atom with symbol: '%s'\n"),
 	 __FILE__, __LINE__, symbol);
   
   return FALSE;
@@ -335,6 +335,145 @@ pxmchem_atom_get_index_bottom_by_symbol (gchar *symbol, GPtrArray *GPA)
 }
 
 
+PxmAtom *
+pxmchem_atom_get_ptr_by_symbol (gchar *symbol, GPtrArray *GPA)
+{
+  return pxmchem_atom_get_ptr_top_by_symbol (symbol, GPA);
+}
+
+PxmAtom *
+pxmchem_atom_get_ptr_top_by_symbol (gchar *symbol, GPtrArray *GPA)
+{
+  gint iter = 0;
+  PxmAtom *atom = NULL;
+  
+
+  g_assert (GPA != NULL);
+  g_assert (symbol != NULL);
+  
+  
+  for (iter = 0; iter < GPA->len; iter ++)
+    {
+      atom = g_ptr_array_index (GPA, iter);
+      
+      if (0 == strcmp (atom->symbol, symbol))
+	return atom;
+    }
+  
+  return NULL;
+}
+
+
+PxmAtom *
+pxmchem_atom_get_ptr_bottom_by_symbol (gchar *symbol, GPtrArray *GPA)
+{
+  gint iter = 0;
+  PxmAtom *atom = NULL;
+  
+
+  g_assert (GPA != NULL);
+  g_assert (symbol != NULL);
+
+  if (GPA->len > 0)
+    {
+      for (iter = GPA->len -1 ; iter >= 0; iter--)
+	{
+	  atom = g_ptr_array_index (GPA, iter);
+	  
+	  if (0 == strcmp (atom->symbol, symbol))
+	    return atom;
+	}
+    }
+  
+  return NULL;
+}
+
+
+gint
+pxmchem_atom_get_highest_abund_isotope_idx (PxmAtom *atom)
+{
+  gdouble *abundance = NULL;
+  gdouble temp = 0;
+  
+  gint iter = 0;
+  gint idx = -1;
+
+  g_assert (atom != NULL);
+    
+  /* We just have to find which isotope has the highest abundance.
+   */
+  for (iter = 0; iter < atom->abundGPA->len; iter++)
+    {
+      abundance = g_ptr_array_index (atom->abundGPA, iter);
+      g_assert (abundance != NULL);
+      
+      if (*abundance > temp)
+	{
+	  temp = *abundance;
+	  idx = iter;
+	}
+    }
+  
+  /* At this point, we should have a idx variable greater than or
+   * equal to 0.
+   */
+  if (idx == -1)
+    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
+	   _("%s@%d: failed to search monoisotopic mass for atom: '%s'\n"),
+	   __FILE__, __LINE__, atom->symbol);
+  
+  return idx;
+}
+
+
+gint
+pxmchem_atom_get_lowest_mass_isotope_idx (PxmAtom *atom)
+{
+  gdouble *mass = NULL;
+  gdouble temp = 0;
+  
+  gint iter = 0;
+  gint idx = -1;
+  
+  g_assert (atom != NULL);
+
+  /* We just have to find which isotope has the lowest mass.
+   */
+  for (iter = 0; iter < atom->massGPA->len; iter++)
+    {
+      mass = g_ptr_array_index (atom->massGPA, iter);
+      g_assert (mass != NULL);
+      
+      if (temp == 0)
+	{
+	  temp = *mass;
+	  idx = iter;
+	}
+      else
+	{
+	  if (*mass < temp)
+	    {
+	      temp = *mass;
+	      idx = iter;
+	    }
+	}
+    }
+  
+  /* At this point, we should have a idx variable greater than or
+   * equal to 0.
+   */
+  if (idx == -1)
+    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
+	   _("%s@%d: failed to search monoisotopic mass for atom: '%s'\n"),
+	   __FILE__, __LINE__, atom->symbol);
+  
+  return idx;
+}
+
+
+
+
+
 
 
 
@@ -381,10 +520,14 @@ pxmchem_atom_check_symbol_syntax (gchar *symbol)
   gint len = 0;
   gint iter = 0;
   
+  gsize size = 0;
+  
   g_assert (symbol != NULL);
 
-  len = strlen (symbol);
-
+  size = strlen (symbol);
+  g_assert (size < G_MAXINT);
+  len = (gint) size;
+  
   if (len <= 0)
     return FALSE;
   
@@ -522,7 +665,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	  strlen (atom->name) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("atom at index '%d' has no name\n"),
+				  _("atom at index: '%d' has no name\n"),
 				  iter);
 	}
 	  
@@ -531,7 +674,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	  strlen (atom->symbol) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("atom at index '%d' has no symbol\n"),
+				  _("atom at index: '%d' has no symbol\n"),
 				  iter);
 	}
       else
@@ -539,7 +682,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	  if (FALSE == pxmchem_atom_check_symbol_syntax (atom->symbol))
 	    {
 	      g_string_append_printf (gs, 
-				      _("atom at index '%d' has an "
+				      _("atom at index: '%d' has an "
 					"invalid symbol\n"),
 				      iter);
 	    }
@@ -553,7 +696,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	{
 	  g_string_append_printf 
 	    (gs, 
-	     _("atom at index '%d' has empty monoisotopic mass array\n"),
+	     _("atom at index: '%d' has empty monoisotopic mass array\n"),
 	     iter);
 	}
       
@@ -565,7 +708,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	{
 	  g_string_append_printf 
 	    (gs, 
-	     _("atom at index '%d' has empty monoisotopic abundance array\n"),
+	     _("atom at index: '%d' has empty monoisotopic abundance array\n"),
 	     iter);
 	}
       
@@ -573,7 +716,7 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	{
 	  g_string_append_printf 
 	    (gs, 
-	     _("atom at index '%d' has monoisotopic "
+	     _("atom at index: '%d' has monoisotopic "
 	       "arrays of different size\n"),
 	     iter);
 	}
@@ -585,8 +728,8 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	  if (mass == NULL || *mass <= 0)
 	    g_string_append_printf 
 	      (gs, 
-	       _("atom at index '%d' has bad monoisotopic mass "
-		 "data at index '%d'\n"),
+	       _("atom at index: '%d' has bad monoisotopic mass "
+		 "data at index: '%d'\n"),
 	       iter, jter);
 	  
 	  abund = g_ptr_array_index (atom->abundGPA, jter);
@@ -594,8 +737,8 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 	  if (abund == NULL || *abund <= 0)
 	    g_string_append_printf 
 	      (gs, 
-	       _("atom at index '%d' has bad monoisotopic abundance "
-		 "data at index '%d'\n"),
+	       _("atom at index: '%d' has bad monoisotopic abundance "
+		 "data at index: '%d'\n"),
 	       iter, jter);
 	}
     }
@@ -622,6 +765,62 @@ pxmchem_atom_array_validate_all (GPtrArray *atomGPA, gchar **valid)
 
 /* COMPUTATION FUNCTIONS
  */
+gboolean
+pxmchem_atom_set_mono_in_atom_by_highest_abund (PxmAtom *atom)
+{
+  gint idx = -1;
+  
+  g_assert (atom != NULL);
+    
+  /* We just have to find which isotope has the highest abundance.
+   */
+  idx = pxmchem_atom_get_highest_abund_isotope_idx (atom);
+    
+  /* At this point, we should have a idx variable greater than or
+   * equal to 0.
+   */
+  if (idx == -1)
+    {
+      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
+	     _("%s@%d: failed to search monoisotopic mass for atom: '%s'\n"),
+	     __FILE__, __LINE__, atom->symbol);
+
+      return FALSE;
+    }
+  
+  atom->mono = *(gdouble *) g_ptr_array_index (atom->massGPA, idx);
+  
+  return TRUE;
+}
+
+
+gboolean
+pxmchem_atom_set_mono_in_atom_by_lowest_mass (PxmAtom *atom)
+{
+  gint idx = -1;
+  
+  /* We just have to find which isotope has the lowest mass.
+   */
+  idx = pxmchem_atom_get_lowest_mass_isotope_idx (atom);
+  
+  /* At this point, we should have a idx variable greater than or
+   * equal to 0.
+   */
+  if (idx == -1)
+    {
+      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
+	     _("%s@%d: failed to search monoisotopic mass for atom: '%s'\n"),
+	     __FILE__, __LINE__, atom->symbol);
+
+      return FALSE;
+    }
+  
+  atom->mono = *(gdouble *) g_ptr_array_index (atom->massGPA, idx);
+  
+  return TRUE;
+}
+
+
 gboolean
 pxmchem_atom_calc_avg_by_symbol (gchar *symbol, gdouble *avg,
 				 GPtrArray *atom_refGPA)
@@ -673,47 +872,6 @@ pxmchem_atom_calc_avg_by_symbol (gchar *symbol, gdouble *avg,
   return TRUE;
 }
 
-gboolean
-pxmchem_atom_set_mono_in_atom (PxmAtom *atom)
-{
-  gdouble *abundance = NULL;
-  gdouble temp = 0;
-  
-  gint iter = 0;
-  gint idx = -1;
-  
-  /* We just have to find which isotope has the highest abundance.
-   */
-  for (iter = 0; iter < atom->abundGPA->len; iter++)
-    {
-      abundance = g_ptr_array_index (atom->abundGPA, iter);
-      g_assert (abundance != NULL);
-      
-      if (*abundance > temp)
-	{
-	  temp = *abundance;
-	  idx = iter;
-	}
-    }
-  
-  /* At this point, we should have a idx variable greater than or
-   * equal to 0.
-   */
-  if (idx == -1)
-    {
-      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed searching monoisotopic mass for atom '%s'\n"),
-	     __FILE__, __LINE__, atom->symbol);
-
-      return FALSE;
-    }
-  
-  atom->mono = *(gdouble *) g_ptr_array_index (atom->massGPA, idx);
-  
-  return TRUE;
-}
-
-
 gboolean
 pxmchem_atom_calc_avg_in_atom (PxmAtom *atom)
 {
@@ -1053,8 +1211,7 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
    */
 
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "atom"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "atom"));
 
   /* Allocate the atom instance that we'll fill with the xml-based
    * data.
@@ -1076,11 +1233,10 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar*) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
   
   atom->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   
   /* Now go to the next child of <atom> node, which is a sibling
    * of the <name> node, actually <symbol>.
@@ -1091,11 +1247,10 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <symbol> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar*) "symbol"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "symbol"));
   
   atom->symbol = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 
   /* At this point we may have one or more <isotope> elements.
    * We should have one now, as this is going to be the first 
@@ -1115,8 +1270,7 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
     {
       /* Check that we have effectively a <isotope> element here.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar*) "isotope"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "isotope"));
 
       if (FALSE == pxmchem_atom_render_xml_node_isotope (xml_doc,
 							 xml_node,
@@ -1126,7 +1280,7 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
 	  pxmchem_atom_free (atom);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: could not render an isotope node\n",
+		_("%s@%d: failed to render an isotope node\n"),
 		 __FILE__, __LINE__);
 	  
 	  return NULL;
@@ -1153,7 +1307,7 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
       pxmchem_atom_free (atom);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-	     "%s@%d: not possible that an atom has no single isotope\n",
+	    _("%s@%d: an atom can not have no isotope\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -1164,14 +1318,14 @@ pxmchem_atom_render_xml_node_atom (xmlDocPtr xml_doc,
    * to the mono membmer of PxmAtom and that the average mass be 
    * calculated and set to the avg member.
    */
-  if (FALSE == pxmchem_atom_set_mono_in_atom (atom))
+  if (FALSE == pxmchem_atom_set_mono_in_atom_by_lowest_mass (atom))
     g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	   _("%s@%d: failed setting monoisotopic mass to atom '%s'\n"),
+	   _("%s@%d: failed to set monoisotopic mass to atom: '%s'\n"),
 	   __FILE__, __LINE__, atom->symbol);
 
   if (FALSE == pxmchem_atom_calc_avg_in_atom (atom))
     g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	   _("%s@%d: failed computing/setting average mass to atom '%s'\n"),
+	   _("%s@%d: failed to calculate/set average mass to atom: '%s'\n"),
 	   __FILE__, __LINE__, atom->symbol);
 
   return atom ;
@@ -1215,8 +1369,7 @@ pxmchem_atom_render_xml_node_isotope (xmlDocPtr xml_doc,
   g_assert (atom->massGPA != NULL);
 
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "isotope"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "isotope"));
 
 
   /* Now go to the first child of current node: <mass>.
@@ -1233,8 +1386,7 @@ pxmchem_atom_render_xml_node_isotope (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <mass> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar*) "mass"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "mass"));
   
 
   /* Allocate the gdouble so that the mass will fit in.
@@ -1242,14 +1394,14 @@ pxmchem_atom_render_xml_node_isotope (xmlDocPtr xml_doc,
   val = g_malloc0 (sizeof (gdouble));
   
   help = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
       
   if (FALSE == libpolyxmass_globals_strtod (help, val))
     {
       g_free (help);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not convert mass '%s' to gdouble\n",
+	    _("%s@%d: failed to convert mass: '%s' to gdouble\n"),
 	     __FILE__, __LINE__, 
 	     xml_node->xmlChildrenNode->content);
       
@@ -1269,22 +1421,21 @@ pxmchem_atom_render_xml_node_isotope (xmlDocPtr xml_doc,
       
   /* Check that current node is <abund>
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar*) "abund"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "abund"));
   
   /* Allocate the gdouble so that the abundance will fit in.
    */
   val = g_malloc0 (sizeof (gdouble));
       
   help = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   
   if (FALSE == libpolyxmass_globals_strtod (help, val))
     {
       g_free (help);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not convert abund '%s' to gdouble\n",
+	    _("%s@%d: failed to convert abund: '%s' to gdouble\n"),
 	     __FILE__, __LINE__, 
 	     xml_node->xmlChildrenNode->content);
 
@@ -1351,7 +1502,7 @@ pxmchem_atom_render_xml_file (gchar *file, GPtrArray *fillGPA)
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: document is empty: %s\n"),
+	     _("%s@%d: the document is empty: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -1365,10 +1516,10 @@ pxmchem_atom_render_xml_file (gchar *file, GPtrArray *fillGPA)
   /* The root of the document should be a non-blank node of name
      "atomdefdata".
    */
-  if (0 != xmlStrcmp ("atomdefdata", (const xmlChar*) xml_node->name))
+  if (0 != strcmp ((gchar *) xml_node->name, "atomdefdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: wrong type document, root node != atomdefdata: %s\n"), 
+	     _("%s@%d: wrong type document, root node is not \"atomdefdata\": '%s'\n"), 
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1388,7 +1539,7 @@ pxmchem_atom_render_xml_file (gchar *file, GPtrArray *fillGPA)
   
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp ("atom", (const xmlChar*) xml_node->name))
+      if (0 == strcmp ((gchar *) xml_node->name, "atom"))
 	{
 	  atom = pxmchem_atom_render_xml_node_atom (xml_doc,
 						    xml_node,
@@ -1396,7 +1547,7 @@ pxmchem_atom_render_xml_file (gchar *file, GPtrArray *fillGPA)
 	  if (NULL == atom)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: could not render atom from xml node\n",
+		    _("%s@%d: failed to render an atom from xml node\n"),
 		     __FILE__, __LINE__);
 	      
 	      xmlFreeDoc (xml_doc);
@@ -1429,13 +1580,13 @@ pxmchem_atom_render_xml_file (gchar *file, GPtrArray *fillGPA)
     
     PxmAtom *iter_atom = NULL;
     
-    printf ("number of atoms parsed: %d\n", fillGPA->len);
+    printf ("number of atoms parsed: '%d'\n", fillGPA->len);
     
     for (iter = 0; iter < fillGPA->len; iter++)
       {
 	iter_atom = g_ptr_array_index (fillGPA, iter);
 	
-	printf ("atom at index %d is %s (%s)\n",
+	printf ("atom at index: '%d' is: '%s' ('%s')\n",
 		iter, 
 		iter_atom->name,
 		iter_atom->symbol);
