@@ -29,7 +29,7 @@
 */
 
 #include "pxmchem-cleave.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 #include "pxmchem-polchemdef.h"
 #include "pxmchem-masscalc.h"
@@ -105,7 +105,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
 					       codelen))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	   _("%s@%d: failed parsing cleavespec pattern: %s\n"),
+	   _("%s@%d: failed to parse cleavespec pattern: '%s'\n"),
 	   __FILE__, __LINE__, cleaveopt->cleavespec->pattern);
 
       return -1;
@@ -126,7 +126,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
 	     jter < clm->motifGPA->len;
 	     jter++)
 	  {
-	    debug_printf (("motif number %d is %s\n", jter,
+	    debug_printf (("motif number: '%d' is: '%s'\n", jter,
 			   (gchar *) g_ptr_array_index (clm->motifGPA,
 							jter)));
 	  }
@@ -152,7 +152,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
 						    nocleaveidxGA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed parsing cleavespec pattern: %s\n"),
+	     _("%s@%d: failed to parse cleavespec pattern: '%s'\n"),
 	     __FILE__, __LINE__, cleaveopt->cleavespec->pattern);
       
       g_array_free (cleaveidxGA, TRUE);
@@ -165,7 +165,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
 						   nocleaveidxGA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	   _("%s@%d: error removing not for cleave positions\n"),
+	   _("%s@%d: failed to remove not-for-cleave positions\n"),
 	   __FILE__, __LINE__);
 
       g_array_free (cleaveidxGA, TRUE);
@@ -210,7 +210,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
   if (count == -1)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error filling array of arrays of oligomers\n"),
+	     _("%s@%d: failed to fill the array of arrays of oligomers\n"),
 	     __FILE__, __LINE__);
       
       g_array_free (cleaveidxGA, TRUE);
@@ -220,7 +220,7 @@ pxmchem_cleave_polymer (PxmPolymer *polymer,
     }
   
   /* Now that all the work was done, we can free the arrays that were
-     only instrumental in the cleavage computation.
+     only instrumental in the cleavage calculatation.
   */
   g_array_free (cleaveidxGA, TRUE);
   g_array_free (nocleaveidxGA, TRUE);
@@ -282,7 +282,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
    */
   if (strlen (cls->pattern) < 2)
     g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	   _("%s@%d: cleavage pattern is invalid: %s\n"),
+	   _("%s@%d: cleavage pattern is invalid: '%s'\n"),
 	   __FILE__, __LINE__, cls->pattern);
 
   /* There can be more than one site in a pattern, and each different
@@ -314,7 +314,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
       if (strlen (cur) < 2)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: this site is invalid: %s\n"),
+		 _("%s@%d: this cleavage site is invalid: '%s'\n"),
 		 __FILE__, __LINE__, cur);
 	  
 	  g_free (cur);
@@ -331,7 +331,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
       if (left == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: this site is invalid: %s\n"),
+		 _("%s@%d: this cleavage site is invalid: '%s'\n"),
 		 __FILE__, __LINE__, cur);
 	  
 	  g_free (cur);
@@ -348,7 +348,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
       if (left != right)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: this site is invalid: %s\n"),
+		 _("%s@%d: this cleavage site is invalid: '%s'\n"),
 		 __FILE__, __LINE__, cur);
 	  
 	  g_free (cur);
@@ -378,7 +378,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
 	  if (cur [0] != '-')
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: this site is invalid: %s\n"),
+		     _("%s@%d: this cleavage site is invalid: '%s'\n"),
 		     __FILE__, __LINE__, cur);
 	  
 	      g_free (cur);
@@ -416,7 +416,7 @@ pxmchem_cleave_parse_cleavespec_pattern (PxmCleaveSpec *cls,
       if (result == -1)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: could not parse the cleavage site: %s\n"),
+		 _("%s@%d: failed to parse the cleavage site: '%s'\n"),
 		 __FILE__, __LINE__, cur);
 	  
 	  
@@ -500,16 +500,17 @@ pxmchem_cleave_parse_cleavage_site (gchar *site,
 
   GString *gs = NULL;
   
+  gsize size = 0;
     
-  
   g_assert (site != NULL);
   g_assert (clm != NULL);
   g_assert (delim_codes != NULL);
   
 
-
-  length = strlen (site);
-  
+  size = strlen (site);
+  g_assert (size < G_MAXINT);
+  length = (gint) size;
+    
   /* Allocate the slot in which we'll receive each code as it is gotten
    * from the site.
    */
@@ -522,7 +523,7 @@ pxmchem_cleave_parse_cleavage_site (gchar *site,
   
   while (1)
     {
-      /* The function that we'll use must be able to compute the
+      /* The function that we'll use must be able to calculate the
        * length of the code string made available to it, which is why
        * it requires that it be filled with 'X' characters.
        */
@@ -610,8 +611,7 @@ pxmchem_cleave_parse_cleavage_site (gchar *site,
 	  if (NULL == strstr (delim_codes, delim))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: the following monomer code"
-		       " is unknown: '%s'\n"),
+		     _("%s@%d: monomer code is unknown: '%s'\n"),
 		     __FILE__, __LINE__, code);
 	      
 	      g_free (code);
@@ -1228,7 +1228,7 @@ pxmchem_cleave_oligomer_new_with_options (PxmPolymer *polymer,
   if (oligomer == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed newing oligomer.\n"),
+	     _("%s@%d: failed to create oligomer.\n"),
 	     __FILE__, __LINE__);
       
       return NULL;
@@ -1236,7 +1236,7 @@ pxmchem_cleave_oligomer_new_with_options (PxmPolymer *polymer,
   
   /* Now that we have the oligomer, we can tailor its name:
    */
-  oligomer->name = g_strdup_printf ("p%d-n%d", partial, index + 1);
+  oligomer->name = g_strdup_printf ("p%d#%d", partial, index + 1);
 
   /* Now that we have dealt with all the cleavage-independent bits, we
      can deal with the cleavage-specific stuff. Note that at this
