@@ -33,7 +33,7 @@
 #endif
 
 #include "pxmchem-cleavespec.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 #include "pxmchem-cleave.h"
 
@@ -444,7 +444,7 @@ pxmchem_cleavespec_validate (PxmCleaveSpec *cleavespec, gchar *delim_codes,
   if (cleavespec->name == NULL)
     {
       g_string_append_printf (gs, 
-			      _("cleavespec has a NULL name\n"));
+			      _("cleavespec has a NULL 'name' member\n"));
     }
   else
     {
@@ -457,7 +457,7 @@ pxmchem_cleavespec_validate (PxmCleaveSpec *cleavespec, gchar *delim_codes,
       if (strlen (help) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("cleavespec has an invalid name:"
+				  _("cleavespec has an invalid 'name' member:"
 				    " '%s'\n"), cleavespec->name);
 	}
 
@@ -469,7 +469,7 @@ pxmchem_cleavespec_validate (PxmCleaveSpec *cleavespec, gchar *delim_codes,
   if (cleavespec->pattern == NULL)
     {
       g_string_append_printf (gs, 
-			      _("cleavespec has a NULL pattern\n"));
+			      _("cleavespec has a NULL 'pattern' member\n"));
     }
   else
     {
@@ -480,7 +480,7 @@ pxmchem_cleavespec_validate (PxmCleaveSpec *cleavespec, gchar *delim_codes,
 						    delim_codes,
 						    codelen))
 	g_string_append_printf (gs, 
-				_("cleavespec has an invalid pattern:"
+				_("cleavespec has an invalid 'pattern' member:"
 				  " '%s'\n"), cleavespec->pattern);
     }
   
@@ -504,8 +504,8 @@ pxmchem_cleavespec_validate (PxmCleaveSpec *cleavespec, gchar *delim_codes,
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-				  _("cleavespec has an invalid"
-				    "cleaverule:\n%s"),
+				  _("cleavespec has an invalid "
+				    "cleaverule:\n'%s'"),
 				  help);
 	  g_free (help);
 	  help = NULL;
@@ -586,7 +586,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
 	{
 	  g_string_append_printf (gs, 
 				  _("cleaverule has an invalid"
-				    " 'left_code': '%s'\n"),
+				    " 'left_code' member: '%s'\n"),
 				  clr->left_code);
 	}
       
@@ -607,7 +607,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
 	{
 	  g_string_append_printf (gs, 
 				  _("cleaverule has an invalid"
-				    " actform: '%s'\n"),
+				    " 'actform' member: '%s'\n"),
 				  clr->left_actform);
 	}
       
@@ -618,7 +618,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
     {
       g_string_append_printf (gs, 
 			      _("cleaverule has an invalid pair of"
-				" left_code and left_actform\n"));
+				" 'left_code' and 'left_actform' members\n"));
     }
 
 
@@ -641,7 +641,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
 	{
 	  g_string_append_printf (gs, 
 				  _("cleaverule has an invalid"
-				    " 'right_code': '%s'\n"),
+				    " 'right_code' member: '%s'\n"),
 				  clr->right_code);
 	}
       
@@ -662,7 +662,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
 	{
 	  g_string_append_printf (gs, 
 				  _("cleaverule has an invalid"
-				    " actform: '%s'\n"),
+				    " 'actform' member: '%s'\n"),
 				  clr->right_actform);
 	}
       
@@ -673,7 +673,7 @@ pxmchem_cleaverule_validate (PxmCleaveRule *clr, gchar *delim_codes,
     {
       g_string_append_printf (gs, 
 			      _("cleaverule has an invalid pair of"
-				" right_code and right_actform\n"));
+				" 'right_code' and 'right_actform' members\n"));
     }
 
   
@@ -975,8 +975,9 @@ pxmchem_cleavespec_format_xml_string_cls (PxmCleaveSpec *cls,
 	}
       else
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	       "%s@%d: could not format xml string for one "
-	       "clr of cleavespec\n", __FILE__, __LINE__);
+	       _("%s@%d: failed to format xml string for one"
+	       " cleaverule of cleavespec\n"),
+	       __FILE__, __LINE__);
     }
 
   g_free (lead);
@@ -1034,8 +1035,7 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "cls"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "cls"));
   
   /* Now go to the first child of current node: <name>.
    */
@@ -1051,8 +1051,7 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   /* Allocate the cls NOT INITIALIZED instance that we'll characterize
    * using allocated strings modelled after xml data.
@@ -1064,7 +1063,7 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
      direct assignements, without recoursing to the _set_xxx ().
   */
   cls->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (cls->name != NULL);
     
   /* Now go to the second child: <pattern>, which is the next sibling
@@ -1076,11 +1075,10 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <pattern> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "pattern"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "pattern"));
 
   cls->pattern = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (cls->pattern != NULL);
 
   /* Now go to the third child: <clr>, if any. This one is optional,
@@ -1094,8 +1092,7 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
     {
       /* Check that we have bona fide a <clr> element.
        */
-      g_assert (0 == xmlStrcmp (xml_node->name, 
-				(const xmlChar *) "clr"));
+      g_assert (0 == strcmp ((gchar *) xml_node->name, "clr"));
       
       /* Ask that a PxmCleaveRule object be allocated and 
        * initialized according to the xml data from the 
@@ -1106,7 +1103,7 @@ pxmchem_cleavespec_render_xml_node_cls (xmlDocPtr xml_doc,
 						       NULL);
       if (clr == NULL)
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	       "%s@%d: failed rendering clr from xml node\n",
+	      _("%s@%d: failed to render clr from xml node\n"),
 	       __FILE__, __LINE__);
 
       /* Store the newly allocated PxmCleaveRule instance into
@@ -1259,8 +1256,7 @@ pxmchem_cleaverule_render_xml_node_clr (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "clr"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "clr"));
 
   /* Allocate the clr NOT INITIALIZED instance that we'll characterize
    * using allocated strings modelled after xml data.
@@ -1293,41 +1289,37 @@ pxmchem_cleaverule_render_xml_node_clr (xmlDocPtr xml_doc,
 	 make direct assignements, without recoursing to the _set_xxx
 	 functions.
       */
-      if (0 == xmlStrcmp (xml_node->name, 
-			  (const xmlChar *) "le-mnm-code"))
+      if (0 == strcmp ((gchar *) xml_node->name, "le-mnm-code"))
 	{
 	  clr->left_code = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 	  g_assert (clr->left_code != NULL);
 	  
 	  le_code_set = TRUE;
 	}
       
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "le-actform"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "le-actform"))
 	{
 	  clr->left_actform = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 	  g_assert (clr->left_actform != NULL);
 	  
 	  le_actform_set = TRUE;
 	}
       
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "re-mnm-code"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "re-mnm-code"))
 	{
 	  clr->right_code = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 	  g_assert (clr->right_code != NULL);
 
 	  re_code_set = TRUE;
 	}
       
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "re-actform"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "re-actform"))
 	{
 	  clr->right_actform = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 	  g_assert (clr->right_actform != NULL);
 	  
 	  re_actform_set = TRUE;
@@ -1351,7 +1343,7 @@ pxmchem_cleaverule_render_xml_node_clr (xmlDocPtr xml_doc,
       if (le_actform_set == FALSE)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed rendering clr from xml node\n",
+		_("%s@%d: failed to render clr from xml node\n"),
 		 __FILE__, __LINE__);
 	
 	  pxmchem_cleaverule_free (clr);
@@ -1365,7 +1357,7 @@ pxmchem_cleaverule_render_xml_node_clr (xmlDocPtr xml_doc,
       if (re_actform_set == FALSE)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed rendering clr from xml node\n",
+		_("%s@%d: failed to render clr from xml node\n"),
 		 __FILE__, __LINE__);
 	
 	  pxmchem_cleaverule_free (clr);
