@@ -70,7 +70,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
   /* We want to allow that the user calls this function with an allocated
      GPtrArray of PxmAtomcount objects because that enables her to 
      perform incremental elemental composition calculations by 
-     stacking onto the same array the computations from different 
+     stacking onto the same array the calculatations from different 
      function calls.
 
      If the acGPA param is NULL, we still need one such array, so we
@@ -132,7 +132,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
   if (TRUE != res)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed computing the polymer's non-capped masses\n"),
+	     _("%s@%d: failed to calculate the non-capped masses of the polymer\n"),
 	     __FILE__, __LINE__);
       
       compcalcres = PXM_COMPCALC_FAILURE;
@@ -154,7 +154,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for caps of the polymer\n"),
+		 _("%s@%d: failed to account for caps of the polymer\n"),
 		 __FILE__, __LINE__);
 	  
 	  compcalcres = PXM_COMPCALC_FAILURE;
@@ -177,7 +177,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
+		 _("%s@%d: failed to account for polymer's "
 		   "left end modif.\n"),
 		 __FILE__, __LINE__);
 	  
@@ -198,7 +198,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
+		 _("%s@%d: failed to account for polymer's "
 		   "right end modif.\n"),
 		 __FILE__, __LINE__);
 	  
@@ -210,7 +210,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
 
   /******************** IONIZATION REQUIREMENTS**********************/
 
-  /* For the moment the elemental composition computed is for a
+  /* For the moment the elemental composition calculated is for a
      non-charged polymer: let's check if caller wants some kind of
      charge to be put on it.  For this we also need to know what atom
      is responsible for the charge formation (proton or whatever).
@@ -221,7 +221,7 @@ pxmchem_elemcompcalc_polymer (PxmPolymer *polymer,
   if (FALSE == res)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for the ionizerule.\n"),
+	     _("%s@%d: failed to account for the ionizerule.\n"),
 	     __FILE__, __LINE__);
       
       compcalcres = PXM_COMPCALC_FAILURE;
@@ -266,7 +266,7 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
 
      Note that the calcopt struct passed as param contains two members
      that will allow us to know which monomer stretch from the GPA
-     should be taken into account during the computation.
+     should be taken into account during the calculatation.
   */
 
   /* Some easy checks to start with, in particular the array of
@@ -290,7 +290,7 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
     }
 
   /* Now check some of the options passed as param pertaining to
-   * elemental composition computation of the non capped chain (make
+   * elemental composition calculatation of the non capped chain (make
    * code FOOL PROOF).
    */
 
@@ -332,7 +332,7 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
    */
   g_assert (calcopt->end_idx >= 0);
   
-  /* NOW start computing the elemental composition of the non-capped
+  /* NOW start calculating the elemental composition of the non-capped
    * polymer by accumulating the formula of each iterated monomer in
    * the GPtrArray of monomer passed as param.
    */
@@ -345,8 +345,8 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
 				 1, acGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting formula '%s' "
-		   "for monomer '%s'\n"),
+		 _("%s@%d: failed to account formula: '%s' "
+		   "for monomer: '%s'\n"),
 		 __FILE__, __LINE__, monomer->formula, monomer->name);
 	  
 	  return FALSE;
@@ -367,8 +367,8 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
 							    acGPA))
 	    {	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for modif of "
-		       "monomer named '%s'\n"),
+		     _("%s@%d: failed to account for modif of "
+		       "monomer: '%s'\n"),
 		     __FILE__, __LINE__, monomer->name);
 
 
@@ -383,11 +383,11 @@ pxmchem_elemcompcalc_noncapped_monomer_GPA (GPtrArray *GPA,
   /* end iterating in the GPtrArray of monomers */
 
   /* At this stage we have the NON CAPPED elemental composition
-     computed for the given polymer stretch comprised of monomers
+     calculated for the given polymer stretch comprised of monomers
      [calcopt->start_idx - calcopt->end_idx]. If the options stated
      that the monomer modif's had to be taken into account, this has
      been done! Also, here both the elemental composition have been
-     computed.
+     calculated.
    */
 
   return TRUE;
@@ -417,7 +417,7 @@ pxmchem_elemcompcalc_polymer_account_caps (GPtrArray *acGPA,
 					      1 /*times*/, acGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for left cap: '%s'\n"),
+		 _("%s@%d: failed to account for left cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->leftcap);
 	  return FALSE;
 	}
@@ -431,7 +431,7 @@ pxmchem_elemcompcalc_polymer_account_caps (GPtrArray *acGPA,
 					      1 /*times*/, acGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for right cap: '%s'\n"),
+		 _("%s@%d: failed to account for right cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->rightcap);
 	  return FALSE;
 	}
@@ -468,7 +468,7 @@ pxmchem_elemcompcalc_polymer_account_left_end_modif (PxmPolymer *polymer,
 						acGPA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for left end modif: '%s'\n"),
+	     _("%s@%d: failed to account for left end modif of the polymer: '%s'\n"),
 	     __FILE__, __LINE__, (gchar *) prop->data);
 
       return FALSE;
@@ -505,7 +505,7 @@ pxmchem_elemcompcalc_polymer_account_right_end_modif (PxmPolymer *polymer,
 						acGPA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for right end modif: '%s'\n"),
+	     _("%s@%d: failed to account for right end modif of polymer: '%s'\n"),
 	     __FILE__, __LINE__, (gchar *) prop->data);
       return FALSE;
     }
@@ -550,8 +550,8 @@ pxmchem_elemcompcalc_polymer_account_ionizerule (PxmIonizerule *ionizerule,
 					  ionizerule->level /*times*/, acGPA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for ionization "
-	       "rule's actform:'%s'\n"),
+	     _("%s@%d: failed to account for the actform of the ionization "
+	       "rule: '%s'\n"),
 	     __FILE__, __LINE__, ionizerule->actform);
       
       return FALSE;
@@ -619,7 +619,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
   /* We want to allow that the user calls this function with an allocated
      GPtrArray of PxmAtomcount objects because that enables her to 
      perform incremental elemental composition calculations by 
-     stacking onto the same array the computations from different 
+     stacking onto the same array the calculatations from different 
      function calls.
      
      If the acGPA param is NULL, we still need one such array, so we
@@ -676,7 +676,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
   if (FALSE == res)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed calculating oligomer's composition\n"),
+	     _("%s@%d: failed to calculate the composition of the oligomer\n"),
 	     __FILE__, __LINE__);
       
       return PXM_COMPCALC_FAILURE;
@@ -684,13 +684,13 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
   
 
   /* At this stage we have the NON CAPPED elemental composition
-     computed for the given polymer stretch comprised of monomers
+     calculated for the given polymer stretch comprised of monomers
      [calcopt->start_idx - calcopt->end_idx]. If the options stated
      that the monomer modif's had to be taken into account, this has
      been done!
   */
   
-  /* Here is one part that is a bit tricky with the computing of
+  /* Here is one part that is a bit tricky with the calculating of
      oligomer elemental composition: the cleaverule handling. Each
      oligomer may result from a cleavage that has as side effects the
      chemical modification of the monomers that were bordering the
@@ -734,7 +734,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
 	  if (FALSE == res)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting cleaverule.\n"),
+		     _("%s@%d: failed to account for cleaverule\n"),
 		     __FILE__, __LINE__);
 	      
 	      return PXM_COMPCALC_FAILURE;
@@ -759,7 +759,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for caps of the polymer\n"),
+		 _("%s@%d: failed to account for caps of the polymer\n"),
 		 __FILE__, __LINE__);
 	  
 	  return PXM_COMPCALC_FAILURE;
@@ -784,7 +784,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
+		 _("%s@%d: failed to account for polymer's "
 		   "left end modif.\n"),
 		 __FILE__, __LINE__);
 	  
@@ -808,7 +808,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
       if (FALSE == res)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
+		 _("%s@%d: failed to account for polymer's "
 		   "right end modif.\n"),
 		 __FILE__, __LINE__);
 	  
@@ -820,7 +820,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
 
   /******************** IONIZATION REQUIREMENTS**********************/
 
-  /* For the moment the masses computed are for a non-charged polymer:
+  /* For the moment the masses calculated are for a non-charged polymer:
      let's check if caller wants some kind of charge to be put on it.
      For this we also need to know what atom is responsible for the
      charge formation (proton or whatever).
@@ -831,7 +831,7 @@ pxmchem_elemcompcalc_oligomer (PxmOligomer *oligomer,
   if (FALSE == res)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for the ionizerule.\n"),
+	     _("%s@%d: failed to account for the ionizerule.\n"),
 	     __FILE__, __LINE__);
       
       return PXM_COMPCALC_FAILURE;
@@ -941,7 +941,7 @@ pxmchem_elemcompcalc_oligomer_account_cleaverule (PxmCleaveRule *lr_rule,
 	      if (FALSE == res)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			 _("%s@%d: failed accounting cleaverule: '%s'\n"),
+			 _("%s@%d: failed to account for actform of cleaverule: '%s'\n"),
 			 __FILE__, __LINE__, lr_rule->left_actform);
 		  
 		  return PXM_COMPCALC_FAILURE;
@@ -988,7 +988,7 @@ pxmchem_elemcompcalc_oligomer_account_cleaverule (PxmCleaveRule *lr_rule,
 	      if (FALSE == res)
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			 _("%s@%d: failed accounting cleaverule: '%s'\n"),
+			 _("%s@%d: failed to account for actform of cleaverule: '%s'\n"),
 			 __FILE__, __LINE__, lr_rule->right_actform);
 		  
 		  return PXM_COMPCALC_FAILURE;
