@@ -51,7 +51,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
    * is going on. 
    *
    * The 'times' parameter governs the number of times the count results
-   * need to be computed into the GPA array. For example 
+   * need to be calculated into the GPA array. For example 
    * one may ask that a given formula be taken into account ten times.
    * The 'times' value may have a negative sign, in which case the
    * operation is for DEC, otherwise it is for INC.
@@ -92,7 +92,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
   if (0 == isalpha (formula [0]) || 0 == isupper (formula [0]))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: bad formula: '%s'\n"),
+	     _("%s@%d: the formula is incorrect: '%s'\n"),
 	     __FILE__, __LINE__, formula);
 
       return FALSE;
@@ -106,7 +106,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
   if (bad_char != NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: bad formula: '%s'\n"),
+	     _("%s@%d: the formula is incorrect: '%s'\n"),
 	     __FILE__, __LINE__, formula);
 
       return FALSE;
@@ -197,8 +197,8 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 		      if (atom_idx == -1)
 			{
 			  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-				 "%s@%d: failed checking if atom"
-				 " is known: %s\n",
+				 _("%s@%d: failed to check if atom"
+				 " is known: '%s'\n"),
 				 __FILE__, __LINE__, parsed_symb);
 
 			  return FALSE;
@@ -206,7 +206,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 		      else
 			{
 			  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-				 "%s@%d: atom is unknown: %s\n",
+				_("%s@%d: the atom is unknown: '%s'\n"),
 				 __FILE__, __LINE__, parsed_symb);
 
 			  return FALSE;
@@ -224,7 +224,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 							    10))
 		    {
 		      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			     "%s@%d: could not convert to gint: %s\n",
+			     _("%s@%d: failed to convert from '%s' to gint\n"),
 			     __FILE__, __LINE__, gs_atomcount->str);
 
 		      g_string_free (gs_atomcount, TRUE);
@@ -286,8 +286,8 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 		      if (atom_idx == -1)
 			{
 			  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-				 "%s@%d: failed checking if atom"
-				 " is known: %s\n",
+				 _("%s@%d: failed to check if atom"
+				 " is known: '%s'\n"),
 				 __FILE__, __LINE__, parsed_symb);
 
 			  return FALSE;
@@ -295,7 +295,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 		      else
 			{
 			  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-				 "%s@%d: atom is unknown: %s\n",
+				 _("%s@%d: the atom is unknown: '%s'\n"),
 				 __FILE__, __LINE__, parsed_symb);
 
 			  return FALSE;
@@ -373,8 +373,8 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 	      if (!was_upper) /* == was_lower */
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			 "%s@%d: two lowercase chars in a row in this"
-			 " formula: %s\n",
+			 _("%s@%d: two lowercase chars in a row in this"
+			 " formula: '%s'\n"),
 			 __FILE__, __LINE__, formula);
 		  
 		  g_string_free (gs_atomcount, TRUE);
@@ -451,7 +451,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
       if (atom_idx == -1)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: failed checking if atom known: %s\n",
+	 _("%s@%d: failed to check if atom is known: '%s'\n"),
 	 __FILE__, __LINE__, parsed_symb);
       
 	  g_string_free (gs_atomcount, TRUE);
@@ -461,7 +461,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: atom is unknown: %s\n",
+	 _("%s@%d: the atom is unknown: '%s'\n"),
 	 __FILE__, __LINE__, parsed_symb);
 
 	  g_string_free (gs_atomcount, TRUE);
@@ -486,7 +486,7 @@ pxmchem_formula_parse (gchar *formula, GPtrArray *atom_refGPA,
 				  10))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not convert to gint: %s\n",
+	     _("%s@%d: failed to convert from '%s' to gint\n"),
 	     __FILE__, __LINE__, gs_atomcount->str);
       
       g_string_free (gs_atomcount, TRUE);
@@ -576,7 +576,7 @@ pxmchem_formula_set_atomcount_in_GPA (GPtrArray *GPA,
 	      /*
 		g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
 		_("%s@%d: the atomcount for atom '%s' has a negative"
-		" count: %d\n"),
+		" count: '%d'\n"),
 		__FILE__, __LINE__,
 		iter_atomcount->atom,
 		iter_atomcount->count);
@@ -604,7 +604,7 @@ pxmchem_formula_set_atomcount_in_GPA (GPtrArray *GPA,
       /*
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
 	_("%s@%d: the atomcount for atom '%s' has a negative"
-	" count: %d\n"),
+	" count: '%d'\n"),
 	__FILE__, __LINE__,
 	new_atomcount->atom,
 	new_atomcount->count);
@@ -633,7 +633,7 @@ pxmchem_actform_split_parts (gchar *actform,
 {
   /* The actform param is of the form "-C1H2S1+O1" or "+O1-C1H2S1",
    * which is fundamentally a chemical reaction formalism. From this
-   * pair of actform substrings (-C1H2S1 and +O1) we have to compute a
+   * pair of actform substrings (-C1H2S1 and +O1) we have to calculate a
    * plus formula and a minus formula (with no signs after that the
    * parsing has been accomplished). Further, the actform that we get
    * as parameter may also be a formula without any sign, in which
@@ -653,6 +653,8 @@ pxmchem_actform_split_parts (gchar *actform,
   gint length = 0;
   gint iter = 0;
 
+  gsize size = 0;
+  
   /* By default, if no '+' sign is found and no '-' neither, 
    * '+' is considered.
    */
@@ -672,7 +674,10 @@ pxmchem_actform_split_parts (gchar *actform,
 
   /* Mininum length of formula is 1 char, as in "H". 
    */
-  length = strlen (actform);
+  size = strlen (actform);
+  g_assert (size < G_MAXINT);
+  length = (gint) size;
+
   if (length <= 0) 
     return FALSE;
 
@@ -702,7 +707,10 @@ pxmchem_actform_split_parts (gchar *actform,
       /* Set the iter variable to the last '\x0' character index,
        * so that we do not enter the while loop below.
        */
-      iter = strlen (actform);
+      size = strlen (actform);
+      g_assert (size < G_MAXINT);
+      iter = (gint) size;
+
     }
   
   while (actform [iter] != '\x0')
@@ -817,7 +825,7 @@ pxmchem_actform_split_parts (gchar *actform,
   if (error == TRUE)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: bad actform: %s\n",
+	 _("%s@%d: the actform is incorrect: '%s'\n"),
 	 __FILE__, __LINE__, actform);
 
       g_string_free (gs_plus, TRUE);
@@ -949,7 +957,7 @@ gboolean
 pxmchem_formula_account_mass (gchar *formula, GPtrArray *atom_refGPA,
 			      gint times, PxmMasspair *masspair)
 {
-  /* We get a formula, and we have to compute a mass for it. Thus we
+  /* We get a formula, and we have to calculate a mass for it. Thus we
    * first have to parse it and make an array of atomcount objects.
    * The calculation will be done by iterating the atomcount array.
    *
@@ -986,7 +994,7 @@ pxmchem_formula_account_mass (gchar *formula, GPtrArray *atom_refGPA,
   if (FALSE == pxmchem_formula_parse (formula, atom_refGPA, times, GPA))
     {
         g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	       _("%s@%d: failed parsing formula '%s'\n"),
+	       _("%s@%d: failed to parse formula: '%s'\n"),
 	       __FILE__, __LINE__, formula);
 
 	g_ptr_array_free (GPA, TRUE);
@@ -1008,7 +1016,7 @@ pxmchem_formula_account_mass (gchar *formula, GPtrArray *atom_refGPA,
       if (FALSE == pxmchem_atom_fill_masspair (symbol, &atom_mp, atom_refGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed getting masses for atom '%s'\n"),
+		 _("%s@%d: failed to get masses for atom: '%s'\n"),
 		 __FILE__, __LINE__, symbol);
 	  
 	  pxmchem_atomcount_GPA_free (GPA);
@@ -1052,7 +1060,7 @@ pxmchem_actform_account_mass (gchar *actform, GPtrArray *atom_refGPA,
 					    &plus, &minus))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: could not split parts of actform '%s'\n"),
+	     _("%s@%d: failed to split parts of actform: '%s'\n"),
 	     __FILE__, __LINE__, actform);
       
       if (plus != NULL)
@@ -1068,8 +1076,8 @@ pxmchem_actform_account_mass (gchar *actform, GPtrArray *atom_refGPA,
 #if 0
   /***************************************************************/
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-	 _("%s@%d: actform '%s' was split into"
-	   " 'plus: %s' and 'minus: %s' - times is %d\n"),
+	 _("%s@%d: actform: '%s' was split into"
+	   " plus: '%s' and minus: '%s' - times is: '%d'\n"),
 	 __FILE__, __LINE__, actform, plus, minus, times);
   
   
@@ -1095,7 +1103,7 @@ pxmchem_actform_account_mass (gchar *actform, GPtrArray *atom_refGPA,
 						 times, masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: could not account for formula plus '%s'\n"),
+		 _("%s@%d: failed to account for formula plus: '%s'\n"),
 		 __FILE__, __LINE__, plus);
 	  
 	  g_free (plus);
@@ -1111,7 +1119,7 @@ pxmchem_actform_account_mass (gchar *actform, GPtrArray *atom_refGPA,
 #if 0
   /***************************************************************/
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-	     _("%s@%d: after accounting 'plus' with times=%d:"
+	     _("%s@%d: after accounting for 'plus' with times=%d:"
 	       " mono=%f, avg=%f\n"),
 	     __FILE__, __LINE__, 
 	     times, masspair->mono, masspair->avg);
@@ -1130,7 +1138,7 @@ pxmchem_actform_account_mass (gchar *actform, GPtrArray *atom_refGPA,
 						 -1 * times, masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: could not account for formula minus '%s'\n"),
+		 _("%s@%d: failed to account for formula minus: '%s'\n"),
 		 __FILE__, __LINE__, minus);
 	  
 	  g_free (minus);
@@ -1170,7 +1178,7 @@ pxmchem_actform_account_elemcompos (gchar *actform, GPtrArray *atom_refGPA,
 					    &plus, &minus))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: could not split parts of actform '%s'\n"),
+	     _("%s@%d: failed to split parts of actform: '%s'\n"),
 	     __FILE__, __LINE__, actform);
       
       if (plus != NULL)
@@ -1186,8 +1194,8 @@ pxmchem_actform_account_elemcompos (gchar *actform, GPtrArray *atom_refGPA,
 #if 0
   /***************************************************************/
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-	 _("%s@%d: actform '%s' was split into"
-	   " 'plus: %s' and 'minus: %s' - times is %d\n"),
+	 _("%s@%d: actform: '%s' was split into"
+	   " plus: '%s' and minus: '%s' - times is: '%d'\n"),
 	 __FILE__, __LINE__, actform, plus, minus, times);
   
   
@@ -1213,7 +1221,7 @@ pxmchem_actform_account_elemcompos (gchar *actform, GPtrArray *atom_refGPA,
 					  times, acGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: could not account for formula plus '%s'\n"),
+		 _("%s@%d: failed to  account for formula plus: '%s'\n"),
 		 __FILE__, __LINE__, plus);
 	  
 	  g_free (plus);
@@ -1238,7 +1246,7 @@ pxmchem_actform_account_elemcompos (gchar *actform, GPtrArray *atom_refGPA,
 					  -1 * times, acGPA))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: could not account for formula minus '%s'\n"),
+		 _("%s@%d: failed to account for formula minus: '%s'\n"),
 		 __FILE__, __LINE__, minus);
 	  
 	  g_free (minus);
