@@ -29,7 +29,7 @@
 */
 
 #include "pxmchem-fragment.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 #include "pxmchem-polchemdef.h"
 #include "pxmchem-masscalc.h"
@@ -102,7 +102,7 @@ pxmchem_fragment_polymer (PxmPolymer *polymer,
   else
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: the end member of the fragspec is invalid.\n"),
+	     _("%s@%d: the 'end' member of the fragspec is invalid.\n"),
 	     __FILE__, __LINE__);
   
       return -1;
@@ -192,7 +192,7 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 						oligomer_1->masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting mass for monomer '%s'\n"),
+		 _("%s@%d: failed to account mass for monomer: '%s'\n"),
 		 __FILE__, __LINE__, monomer->name);
 	  
 	  pxmchem_oligomer_free (oligomer_1);
@@ -212,8 +212,8 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 						      oligomer_1->masspair))
 	    {	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for modif of "
-		       "monomer named '%s'\n"),
+		     _("%s@%d: failed to account for modif of "
+		       "monomer: '%s'\n"),
 		     __FILE__, __LINE__, monomer->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -282,8 +282,8 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 					    oligomer_1->masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for fragspec's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for actform of fragspec: "
+		       "'%s'\n"),
 		     __FILE__, __LINE__, fragspec->actform);
 
 	      pxmchem_oligomer_free (oligomer_1);
@@ -312,8 +312,8 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 							       polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "left end modif.\n"),
+		     _("%s@%d: failed to account for the left end"
+		       " modif of the polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -340,8 +340,8 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 								polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "right end modif.\n"),
+		     _("%s@%d: failed to account for the "
+		       "right end modif of the polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -456,7 +456,7 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 						 polchemdef->atomGPA))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for the fragrule: '%s'\n"),
+		     _("%s@%d: failed to account for the fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -467,7 +467,7 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 	  
 	  /* We can construct a name for this fragment:
 	   */
-	  oligomer_1->name = g_strdup_printf ("%s-%s-(%s)",
+	  oligomer_1->name = g_strdup_printf ("%s-%s#1-(%s)",
 					      fragspec->name, 
 					      monomer->code,
 					      fragrule->name);
@@ -495,7 +495,7 @@ pxmchem_fragment_polymer_end_none (PxmPolymer *polymer,
 	{
 	  /* We have to make a complete oligomer with oligomer_1:
 	   */
-	  oligomer_1->name = g_strdup_printf ("%s-%s",
+	  oligomer_1->name = g_strdup_printf ("%s-%s#1",
 					      fragspec->name, 
 					      monomer->code);
 	  
@@ -627,7 +627,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 						masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting mass for monomer '%s'\n"),
+		 _("%s@%d: failed to account for monomer: '%s'\n"),
 		 __FILE__, __LINE__, monomer->name);
 	  
 	  libpolyxmass_masspair_free (masspair);
@@ -650,8 +650,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 						      masspair))
 	    {	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for modif of "
-		       "monomer named '%s'\n"),
+		     _("%s@%d: failed to account for modif of "
+		       "monomer: '%s'\n"),
 		     __FILE__, __LINE__, monomer->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -664,50 +664,47 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	    }
 	}
       
-      /* Also, if the user wanted that the modification eventually found
-	 in the monomer be signalled, we can do this.
+      /* Also, signal the modification eventually found in the monomer
+	 be signalled, we can do this.
       */
-      if (fragopt->mnm_chement != PXMCHEMENT_MNM_NONE)
-	{
-	  prop =  libpolyxmass_prop_find_prop (monomer->propGPA,
+      prop =  libpolyxmass_prop_find_prop (monomer->propGPA,
 					   NULL,
 					   NULL,
 					   "MODIF",
 					   NULL,
 					   PXM_UNDEF_PROP_CMP);
+      
+      if (NULL != prop)
+	{
+	  prop_new = libpolyxmass_prop_new ();
 	  
-	  if (NULL != prop)
-	    {
-	      prop_new = libpolyxmass_prop_new ();
-
-	      /* The nomenclature here is more complex than with the
-		 polymer cleavage case, because the fact the monomer
-		 number depends on the PxmEnd of the fragmentation
-		 complicates much the work. So we simply construct a
-		 prop name by telling what is the offset position of
-		 the monomer that is modified with respect to the end
-		 at which the fragmentation occurs, and also by
-		 telling what the true index of the monomer is in the
-		 whole polymer sequence. We need this datum so that
-		 later we can access the monomer in question and thus
-		 get to the name of the modification.... This is when
-		 GUI programs need to display...
-	      */
-	      libpolyxmass_prop_set_name (prop_new, "POS/IDX/MODIF");
-	      prop_new->data =g_strdup_printf ("%d/%d/%s",
-					       /* pos in the oligomer */
-					       iter - calcopt->start_idx + 1,
-					       /* index in the sequence */
-					       iter,
-					       (gchar *) prop->data);
-
-	      g_ptr_array_add (modifpropGPA, prop_new);
-	    }
+	  /* The nomenclature here is more complex than with the
+	     polymer cleavage case, because the fact the monomer
+	     number depends on the PxmEnd of the fragmentation
+	     complicates much the work. So we simply construct a
+	     prop name by telling what is the offset position of
+	     the monomer that is modified with respect to the end
+	     at which the fragmentation occurs, and also by
+	     telling what the true index of the monomer is in the
+	     whole polymer sequence. We need this datum so that
+	     later we can access the monomer in question and thus
+	     get to the name of the modification.... This is when
+	     GUI programs need to display...
+	  */
+	  libpolyxmass_prop_set_name (prop_new, "POS/IDX/MODIF");
+	  prop_new->data =g_strdup_printf ("%d/%d/%s",
+					   /* pos in the oligomer */
+					   iter - calcopt->start_idx + 1,
+					   /* index in the sequence */
+					   iter,
+					   (gchar *) prop->data);
+	  
+	  g_ptr_array_add (modifpropGPA, prop_new);
 	}
-  
+    
 
       /* Make a "local" copy of the masspair instance that will be
-	 stuck in the oligomer at the end of mass computing. This is
+	 stuck in the oligomer at the end of mass calculating. This is
 	 required, because masspair holds the masses of the elongating
 	 fragment and should not be incremented with masses from 
 	 evaluation of logical conditions and other fragrules...
@@ -729,8 +726,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 					    masspair_tmp))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for fragspec's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for the actform of fragspec: "
+		       "'%s'\n"),
 		     __FILE__, __LINE__, fragspec->actform);
 
 	      libpolyxmass_masspair_free (masspair);
@@ -758,7 +755,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 					1 /*times*/, masspair_tmp))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for left cap: '%s'\n"),
+		 _("%s@%d: failed to account for left cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->leftcap);
 	 
 	  libpolyxmass_masspair_free (masspair);
@@ -800,8 +797,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 							       polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "left end modif.\n"),
+		     _("%s@%d: failed to account for the left"
+		       " end modif of polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      libpolyxmass_masspair_free (masspair);
@@ -840,8 +837,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 								polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "right end modif.\n"),
+		     _("%s@%d: failed to account for right"
+		       " end modif of polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      libpolyxmass_masspair_free (masspair);
@@ -869,30 +866,28 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	 LEFT). So we test if we are required to let the oligomer know
 	 what were its ends...
       */
-      if (fragopt-> plm_chement & PXMCHEMENT_PLM_LEFT_MODIF 
-	  && calcopt->start_idx == 0)
+      if (calcopt->start_idx == 0)
 	{
 	  prop = libpolyxmass_prop_find_prop (polymer->propGPA,
-					  NULL,
-					  NULL,
-					  "LEFT_END_MODIF",
-					  NULL,
-					  PXM_UNDEF_PROP_CMP);
-	      
+					      NULL,
+					      NULL,
+					      "LEFT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
 	  if (NULL != prop)
 	    {
 	      if (prop->data != NULL)
 		{
 		  prop_new = 
 		    libpolyxmass_prop_dup (prop, PXM_MODIF_PROP_DUP_DEEP_YES);
-		      
+		  
 		  g_ptr_array_add (oligomer_1->propGPA, prop_new);
 		}
 	    }
 	}
-
-      if (fragopt-> plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF 
-	  && calcopt->end_idx == polymer->monomerGPA->len - 1
+      
+      if (calcopt->end_idx == polymer->monomerGPA->len - 1
 	  && iter == calcopt->end_idx)
 	{
 	  prop = libpolyxmass_prop_find_prop (polymer->propGPA,
@@ -907,7 +902,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	      if (prop->data != NULL)
 		{
 		  prop_new = 
-		    libpolyxmass_prop_dup (prop, PXM_MODIF_PROP_DUP_DEEP_YES);
+		    libpolyxmass_prop_dup (prop, 
+					   PXM_MODIF_PROP_DUP_DEEP_YES);
 		      
 		  g_ptr_array_add (oligomer_1->propGPA, prop_new);
 		}
@@ -925,7 +921,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
       */
       if (fragopt->put_sequence == TRUE)
 	{
-	  prop_new = libpolyxmass_prop_both_strings_new ("SEQUENCE", seq->str);
+	  prop_new = libpolyxmass_prop_both_strings_new ("SEQUENCE", 
+							 seq->str);
 	  
 	  g_ptr_array_add (oligomer_1->propGPA, prop_new);
 	}
@@ -943,7 +940,8 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	  prop = g_ptr_array_index (modifpropGPA, kter);
 	  g_assert (prop != NULL);
 	  
-	  prop_new = libpolyxmass_prop_dup (prop, PXM_MODIF_PROP_DUP_DEEP_YES);
+	  prop_new = libpolyxmass_prop_dup (prop, 
+					    PXM_MODIF_PROP_DUP_DEEP_YES);
 	  
 	  g_ptr_array_add (oligomer_1->propGPA, prop_new);
 	}
@@ -993,7 +991,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 						 polchemdef->atomGPA))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for the fragrule: '%s'\n"),
+		     _("%s@%d: failed to account for the fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -1004,7 +1002,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	  
 	  /* We can construct a name for this fragment:
 	   */
-	  oligomer_2->name = g_strdup_printf ("%s-%d-(%s)",
+	  oligomer_2->name = g_strdup_printf ("%s#%d-(%s)",
 					      fragspec->name, 
 					      numb + 1,
 					      fragrule->name);
@@ -1039,7 +1037,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	     construct the name of the oligomer because there are no
 	     fragrules!
 	   */
-	  oligomer_1->name = g_strdup_printf ("%s-%d",
+	  oligomer_1->name = g_strdup_printf ("%s#%d",
 					      fragspec->name, 
 					      numb + 1);
 	  g_ptr_array_add (GPA, oligomer_1);
@@ -1055,7 +1053,7 @@ pxmchem_fragment_polymer_end_left (PxmPolymer *polymer,
 	    pxmchem_oligomer_free (oligomer_1);
 	  else
 	    {
-	      oligomer_1->name = g_strdup_printf ("%s-%d",
+	      oligomer_1->name = g_strdup_printf ("%s#%d",
 						  fragspec->name, 
 						  numb + 1);
 	      g_ptr_array_add (GPA, oligomer_1);
@@ -1196,7 +1194,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 						masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting mass for monomer '%s'\n"),
+		 _("%s@%d: failed to account for monomer: '%s'\n"),
 		 __FILE__, __LINE__, monomer->name);
 	  
 	  libpolyxmass_masspair_free (masspair);
@@ -1219,8 +1217,8 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 						      masspair))
 	    {	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for modif of "
-		       "monomer named '%s'\n"),
+		     _("%s@%d: failed to account for modif of "
+		       "monomer: '%s'\n"),
 		     __FILE__, __LINE__, monomer->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -1276,7 +1274,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
   
 
       /* Make a "local" copy of the masspair instance that will be
-	 stuck in the oligomer at the end of mass computing. This is
+	 stuck in the oligomer at the end of mass calculating. This is
 	 required, because masspair holds the masses of the elongating
 	 fragment and should not be incremented with masses from 
 	 evaluation of fragrules...
@@ -1297,8 +1295,8 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 					    1 /*times*/, masspair_tmp))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for fragspec's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for actform of fragspec: "
+		       "'%s'\n"),
 		     __FILE__, __LINE__, fragspec->actform);
 
 	      libpolyxmass_masspair_free (masspair);
@@ -1326,7 +1324,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 					1 /*times*/, masspair_tmp))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for right cap: '%s'\n"),
+		 _("%s@%d: failed to account for right cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->rightcap);
 	 
 	  libpolyxmass_masspair_free (masspair);
@@ -1370,8 +1368,8 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 								polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "right end modif.\n"),
+		     _("%s@%d: failed to account for right end modif"
+		       " of polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      libpolyxmass_masspair_free (masspair);
@@ -1409,8 +1407,8 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 							       polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "left end modif.\n"),
+		     _("%s@%d: failed to account for "
+		       "left end modif of polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      libpolyxmass_masspair_free (masspair);
@@ -1563,7 +1561,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 						 polchemdef->atomGPA))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for the fragrule: '%s'\n"),
+		     _("%s@%d: failed to account for the fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->name);
 	      
 	      pxmchem_oligomer_free (oligomer_1);
@@ -1574,7 +1572,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 	  
 	  /* We can construct a name for this fragment:
 	   */
-	  oligomer_2->name = g_strdup_printf ("%s-%d-(%s)",
+	  oligomer_2->name = g_strdup_printf ("%s#%d-(%s)",
 					      fragspec->name, 
 					      numb + 1,
 					      fragrule->name);
@@ -1609,7 +1607,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 	     construct the name of the oligomer because there are no
 	     fragrules!
 	   */
-	  oligomer_1->name = g_strdup_printf ("%s-%d",
+	  oligomer_1->name = g_strdup_printf ("%s#%d",
 					      fragspec->name, 
 					      numb + 1);
 	  g_ptr_array_add (GPA, oligomer_1);
@@ -1625,7 +1623,7 @@ pxmchem_fragment_polymer_end_right (PxmPolymer *polymer,
 	    pxmchem_oligomer_free (oligomer_1);
 	  else
 	    {
-	      oligomer_1->name = g_strdup_printf ("%s-%d",
+	      oligomer_1->name = g_strdup_printf ("%s#%d",
 						  fragspec->name, 
 						  numb + 1);
 	      g_ptr_array_add (GPA, oligomer_1);
@@ -1768,7 +1766,8 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: bad 'end' member found in fragrule '%s'\n"),
+		 _("%s@%d: 'end' member found in fragrule "
+		   "is incorrect: '%s'\n"),
 		 __FILE__, __LINE__, fragrule->name);
 
 	  return FALSE;
@@ -1793,8 +1792,8 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
 					    1 /*times*/, masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting fragrule's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for the "
+		       "actform of fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->actform);
 	      
 	      return FALSE;
@@ -1869,8 +1868,8 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
 					    1 /*times*/, masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting fragrule's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for the actform "
+		       "of fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->actform);
 	      
 	      return FALSE;
@@ -1918,7 +1917,7 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: bad 'end' member found in fragrule '%s'\n"),
+		 _("%s@%d: 'end' member found in fragrule is incorrect: '%s'\n"),
 		 __FILE__, __LINE__, fragrule->name);
 
 	  return FALSE;
@@ -1942,8 +1941,8 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
 					    1 /*times*/, masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting fragrule's "
-		       "actform: '%s'\n"),
+		     _("%s@%d: failed to account for the actform of"
+		       " fragrule: '%s'\n"),
 		     __FILE__, __LINE__, fragrule->actform);
 	      
 	      return FALSE;
@@ -1981,8 +1980,8 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
 					1 /*times*/, masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting fragrule's "
-		   "actform: '%s'\n"),
+		 _("%s@%d: failed to account for the actform"
+		   " of fragrule: '%s'\n"),
 		 __FILE__, __LINE__, fragrule->actform);
 	  
 	  return FALSE;
@@ -1998,3 +1997,225 @@ pxmchem_fragment_account_fragrule (PxmFragRule *fragrule,
   return FALSE;
 }
 
+
+gboolean
+pxmchem_fragment_parse_name (gchar *name,
+			     gchar **pattern,
+			     gint *number)
+{
+
+
+
+  g_assert (name != NULL);
+  g_assert (pattern != NULL);
+  g_assert (number != NULL);
+
+
+  /* The typical name of a fragmentation oligomer is "a-16" for
+     "fragmentation patter a, number 16". If something follows in the
+     name (like in the case of fragmentation rules being applied), it
+     should be separated using a '-', like "x#1271-(x-fgr-2)". We only
+     deal with the first part of the name (a#16 or imm-E).
+   */
+  
+
+  gint iter = 0;
+  
+  GString * gs_current = NULL;
+  GString * gs_pattern = NULL;
+
+  /* Indicates if '#' was encountered during parsing.
+   */
+  gboolean found_delim = FALSE;
+
+  
+  gs_current = g_string_new ("");
+  gs_pattern = g_string_new ("");
+  
+
+  for (iter = 0; iter < strlen (name); iter++)
+    {
+      if (0 != isalpha (name [iter]))
+	{
+	  /* We get an alphabetical character. If we have already
+	     parsed the pattern (that is: if found_delim is TRUE),
+	     then finding an alphabetic character means that we are
+	     terminating the number part of the oligomer name.
+	  */
+	  if (TRUE == found_delim)
+	    {
+	      if (strlen (gs_pattern->str) <= 0)
+		{
+		  g_string_free (gs_current, TRUE);
+		  g_string_free (gs_pattern, TRUE);
+		  
+		  return FALSE;
+		}
+
+	      if (TRUE != 
+		  libpolyxmass_globals_strtoi (gs_current->str, number, 10))
+		{
+		  g_string_free (gs_current, TRUE);
+		  g_string_free (gs_pattern, TRUE);
+		  
+		  return FALSE;
+		}
+
+	      /* At this point we have all we need. 
+	       */
+	      *pattern = gs_pattern->str;
+	      
+	      g_string_free (gs_current, TRUE);
+	      g_string_free (gs_pattern, FALSE);
+	      
+	      return TRUE;
+	    }
+	  
+	  /* We are parsing the pattern part of the name of the
+	     oligomer.
+	   */
+	  gs_current = g_string_append_c (gs_current, name [iter]);
+	  
+	  continue;
+	}
+      
+      if (0 != isdigit (name [iter]))
+	{
+	  /* We get a digit. At this point we should have gotten a '#'
+	     character, since that delim is used to separate the
+	     pattern part of the name from the number part.
+	  */
+	  if (FALSE == found_delim)
+	    {
+	      g_string_free (gs_current, TRUE);
+	      g_string_free (gs_pattern, TRUE);
+	      
+	      return FALSE;
+	    }
+	  
+	  /* We are truly parsing the number part of the name of the
+	     oligomer.
+	   */
+	  gs_current = g_string_append_c (gs_current, name [iter]);
+	  
+	  continue;
+	}
+  
+      if ('#' == name [iter])
+	{
+	  if (TRUE == found_delim)
+	    {
+	      /* there is a syntax error
+	       */
+	      g_string_free (gs_current, TRUE);
+	      g_string_free (gs_pattern, TRUE);
+	      
+	      return FALSE;
+	    }
+
+	  /* OK, we got the pattern part of the oligomer name in
+	     gs_current. Let's put that string in the gs_pattern
+	     object.
+	  */
+	  gs_pattern = g_string_append (gs_pattern, gs_current->str);
+	  
+	  gs_current = g_string_truncate (gs_current, 0);
+	  
+	  found_delim = TRUE;
+	  
+	  continue;
+	}
+      else
+	{
+	  /* We are parsing something that is neither alphabetical,
+	     nor numerical, nor '#'. Typically, that could be '-'.
+
+	     We have to make sure we append that character to the
+	     pattern part of the oligomer name. But this can be only
+	     if we have not already encountered the '#' character and
+	     if the pattern is not already done.
+	  */
+	  if (TRUE == found_delim) 
+	    {
+	      /* OK, since found_delim is TRUE, that means that we
+		 have already parsed the pattern element of the
+		 oligomer name. 
+
+		 Thus, it should be that we also have finished parsing
+		 the number part of the oligome name. If so, then the
+		 strlen of gs_current should be > 0.
+	      */
+	      if (strlen (gs_current->str) <= 0)
+		{
+		  /* there is a syntax error
+		   */
+		  g_string_free (gs_current, TRUE);
+		  g_string_free (gs_pattern, TRUE);
+		  
+		  return FALSE;
+		}
+
+	      if (TRUE != 
+		  libpolyxmass_globals_strtoi (gs_current->str, number, 10))
+		{
+		  g_string_free (gs_current, TRUE);
+		  g_string_free (gs_pattern, TRUE);
+		  
+		  return FALSE;
+		}
+	      
+	      /* At this point we have all we need. 
+	       */
+	      *pattern = gs_pattern->str;
+	      
+	      g_string_free (gs_current, TRUE);
+	      g_string_free (gs_pattern, FALSE);
+	      
+	      return TRUE;
+	    }
+	  	      
+	  
+	  /* OK, still not found the delimitator character. Thus, we
+	     are still iterating in the pattern part of the oligomer
+	     name. We should just add the newly parsed character to
+	     the currently elongating GString.
+	  */
+	  gs_current = g_string_append_c (gs_current, name [iter]);
+	  
+	  continue;
+	}
+    }
+
+  /* At this point we might have finished parsing the pattern and
+     number parts of the oligomer name.
+  */
+  if (TRUE == found_delim)
+    {
+      /* Check if we can successfully convert the elongating
+	 string into an integer in the variable pointed to by
+	 the 'number' parameter.
+      */
+      if (TRUE != 
+	  libpolyxmass_globals_strtoi (gs_current->str, number, 10))
+	{
+	  g_string_free (gs_current, TRUE);
+	  g_string_free (gs_pattern, TRUE);
+	  
+	  return FALSE;
+	}
+      
+      /* At this point we have all we need. 
+       */
+      *pattern = gs_pattern->str;
+      
+      g_string_free (gs_current, TRUE);
+      g_string_free (gs_pattern, FALSE);
+      
+      return TRUE;
+    }
+  
+  g_string_free (gs_current, TRUE);
+  g_string_free (gs_pattern, TRUE);
+  
+  return FALSE;
+}
