@@ -34,7 +34,7 @@
 
 #include "pxmchem-fragspec.h"
 #include "pxmchem-monomer.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 
 
@@ -414,7 +414,7 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
   if (fragspec->name == NULL)
     {
       g_string_append_printf (gs, 
-			      _("fragspec has a NULL name\n"));
+			      _("fragspec has a NULL 'name' member\n"));
     }
   else
     {
@@ -427,7 +427,7 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
       if (strlen (help) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("fragspec has an invalid name:"
+				  _("fragspec has an invalid 'name' member:"
 				    " '%s'\n"), fragspec->name);
 	}
 
@@ -441,7 +441,7 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
    */
   if (PXM_FRAG_END_BOTH == fragspec->end)
     g_string_append_printf (gs, 
-			    _("fragspec has not a valid end: '%d'\n"),
+			    _("fragspec has not a valid 'end' member: '%d'\n"),
 			    fragspec->end);
 
   /* The actform: it cannot be NULL. And must be a chemically valid
@@ -450,7 +450,7 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
   if (fragspec->actform == NULL)
     {
       g_string_append_printf (gs, 
-			      _("fragspec has a NULL actform\n"));
+			      _("fragspec has a NULL 'actform' member\n"));
     }
   else
     {
@@ -463,7 +463,7 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
 					  polchemdef->atomGPA))
 	{
 	  g_string_append_printf (gs, 
-				  _("fragspec has an invalid actform:"
+				  _("fragspec has an invalid 'actform' member:"
 				    " '%s'\n"), fragspec->actform);
 	}
     }
@@ -496,8 +496,8 @@ pxmchem_fragspec_validate (PxmFragSpec *fragspec, PxmPolchemdef *polchemdef,
 						    fragspec->fgrGPA))
 	{
 	  g_string_append_printf (gs,
-				  _("fragrule at index %d: '%s'"
-				    " is not unique\n"),
+				  _("fragrule at index: '%d'"
+				    " is not unique: '%s'\n"),
 				  iter, fragrule->name);
 	}      
 
@@ -586,7 +586,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
   if (fragrule->name == NULL)
     {
       g_string_append_printf (gs, 
-			      _("fragrule has a NULL name"));
+			      _("fragrule has a NULL 'name' member"));
     }
   else
     {
@@ -599,7 +599,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
       if (strlen (help) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("fragrule has not a valid name"));
+				  _("fragrule has not a valid 'name' member"));
 	}
       
       g_free (help);
@@ -610,7 +610,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
   if (fragrule->actform == NULL)
     {
       g_string_append_printf (gs, 
-			      _("fragrule has a NULL actform\n"));
+			      _("fragrule has a NULL 'actform' member\n"));
     }
   else
     {
@@ -621,7 +621,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
 					  polchemdef->atomGPA))
 	{
 	  g_string_append_printf (gs, 
-				  _("fragrule has an invalid actform:"
+				  _("fragrule has an invalid 'actform' member:"
 				    " '%s'\n"), fragrule->actform);
 	}
     }
@@ -635,7 +635,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
       if (-1 == pxmchem_monomer_get_index_by_code (fragrule->prev,
 						   polchemdef->monomerGPA))
 	g_string_append_printf (gs, 
-				_("fragrule has an invalid prev_code:"
+				_("fragrule has an invalid 'prev' member:"
 				  " '%s'\n"), fragrule->prev);
     }
   else
@@ -653,7 +653,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
       if (-1 == pxmchem_monomer_get_index_by_code (fragrule->this, 
 						   polchemdef->monomerGPA))
 	g_string_append_printf (gs, 
-				_("fragrule has an invalid this_code:"
+				_("fragrule has an invalid 'this' member:"
 				  " '%s'\n"), fragrule->this);
     }
   else
@@ -671,7 +671,7 @@ pxmchem_fragrule_validate (PxmFragRule *fragrule, PxmPolchemdef *polchemdef,
       if (-1 == pxmchem_monomer_get_index_by_code (fragrule->next,
 						   polchemdef->monomerGPA))
 	g_string_append_printf (gs, 
-				_("fragrule has an invalid next_code:"
+				_("fragrule has an invalid 'next' member:"
 				  " '%s'\n"), fragrule->next);
     }
   else
@@ -1010,8 +1010,8 @@ pxmchem_fragspec_format_xml_string_fgs (PxmFragSpec *fgs,
 	}
       else
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	       "%s@%d: could not format xml string for one fragrule "
-	       "of fragspec\n", __FILE__, __LINE__);
+	       _("%s@%d: failed formatting xml string for one fragrule"
+	       " of fragspec\n"), __FILE__, __LINE__);
     }
 
 
@@ -1197,8 +1197,7 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "fgs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "fgs"));
   
   /* Now go to the first child of current node: <name>.
    */
@@ -1214,8 +1213,7 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   fgs = pxmchem_fragspec_new ();
   
@@ -1224,7 +1222,7 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
      assignements, without recoursing to the _set_xxx ().
   */
   fgs->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (fgs->name != NULL);
   
   /* Now go to the next sibling of current node: <end>.
@@ -1235,11 +1233,10 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <end> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "end"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "end"));
 
   help = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (help != NULL);
   
   if (0 == strcmp ("NE", help))
@@ -1250,7 +1247,7 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
     fgs->end = PXM_FRAG_END_RIGHT;
   else
     g_log (G_LOG_DOMAIN, G_LOG_LEVEL_ERROR,
-	   _("%s@%d: invalid fragspec end: '%s'\n"),
+	   _("%s@%d: fragspec has an invalid 'end' member: '%s'\n"),
 	   __FILE__, __LINE__, help);
 
   g_free (help);
@@ -1263,11 +1260,10 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <actformn> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "actform"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "actform"));
 
   fgs->actform = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (fgs->actform != NULL);
 
 
@@ -1280,25 +1276,23 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
 
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "comment"))
+      if (0 == strcmp ((gchar *) xml_node->name, "comment"))
 	{
 	  if (comment_set == TRUE)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: two xml comment elements not allowed\n",
+		   _("%s@%d: two xml comment elements not allowed\n"),
 		   __FILE__, __LINE__);
 	  else
 	    {
 	      fgs->comment = 
-		xmlNodeListGetString (xml_doc, 
-				      xml_node->xmlChildrenNode, 1);
+		(gchar *) xmlNodeListGetString (xml_doc, 
+						xml_node->xmlChildrenNode, 1);
 	      g_assert (fgs->comment != NULL);
 
 	      comment_set = TRUE;
 	    }
 	}
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "fgr"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "fgr"))
 	{
 	  xml_child_node = xml_node;
 	  
@@ -1307,7 +1301,7 @@ pxmchem_fragspec_render_xml_node_fgs (xmlDocPtr xml_doc,
 						      NULL);
 	  if (fgr == NULL)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: failed rendering fragrule from xml node\n",
+		   _("%s@%d: failed to render fragrule from xml node\n"),
 		   __FILE__, __LINE__);
 	  else
 	    g_ptr_array_add (fgs->fgrGPA, fgr);
@@ -1372,8 +1366,7 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "fgr"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "fgr"));
   
   /* Now go to the first child of current node: <name>.
    */
@@ -1389,8 +1382,7 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   fgr = pxmchem_fragrule_new ();
   
@@ -1399,7 +1391,7 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
      assignements, without recoursing to the _set_xxx ().
   */
   fgr->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (fgr->name != NULL);
   
   /* Now go to the next sibling of current node: <actform>.
@@ -1410,11 +1402,10 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <actform> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "actform"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "actform"));
 
   fgr->actform = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (fgr->actform != NULL);
 
   /* Since the following items are not obligatory, we have to 
@@ -1426,17 +1417,16 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
 
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp (xml_node->name, 
-			  (const xmlChar *) "prev-mnm-code"))
+      if (0 == strcmp ((gchar *) xml_node->name, "prev-mnm-code"))
 	{
 	  if (prev_set == TRUE)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: two xml prev elements not allowed\n",
+		   _("%s@%d: two xml prev elements not allowed\n"),
 		   __FILE__, __LINE__);
 	  else
 	    {
 	      fgr->prev = 
-		xmlNodeListGetString (xml_doc, 
+		(gchar *) xmlNodeListGetString (xml_doc, 
 				      xml_node->xmlChildrenNode, 1);
 
 	      g_assert (fgr->prev != NULL);
@@ -1444,17 +1434,16 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
 	      prev_set = TRUE;
 	    }
 	}
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "this-mnm-code"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "this-mnm-code"))
 	{
 	  if (this_set == TRUE)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: two xml this elements not allowed\n",
+		   _("%s@%d: two xml this elements not allowed\n"),
 		   __FILE__, __LINE__);
 	  else
 	    {
 	      fgr->this = 
-		xmlNodeListGetString (xml_doc, 
+		(gchar *) xmlNodeListGetString (xml_doc, 
 				      xml_node->xmlChildrenNode, 1);
 
 	      g_assert (fgr->this != NULL);
@@ -1462,17 +1451,16 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
 	      this_set = TRUE;
 	    }
 	}
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "next-mnm-code"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "next-mnm-code"))
 	{
 	  if (next_set == TRUE)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: two xml next elements not allowed\n",
+		   _("%s@%d: two xml 'next' elements not allowed\n"),
 		   __FILE__, __LINE__);
 	  else
 	    {
 	      fgr->next = 
-		xmlNodeListGetString (xml_doc, 
+		(gchar *) xmlNodeListGetString (xml_doc, 
 				      xml_node->xmlChildrenNode, 1);
 	      
 	      g_assert (fgr->next != NULL);
@@ -1480,17 +1468,16 @@ pxmchem_fragrule_render_xml_node_fgr (xmlDocPtr xml_doc,
 	      next_set = TRUE;
 	    }
 	}
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar *) "comment"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "comment"))
 	{
 	  if (comment_set == TRUE)
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   "%s@%d: two xml comment elements not allowed\n",
+		   _("%s@%d: two xml comment elements not allowed\n"),
 		   __FILE__, __LINE__);
 	  else
 	    {
 	      fgr->comment = 
-		xmlNodeListGetString (xml_doc, 
+		(gchar *) xmlNodeListGetString (xml_doc, 
 				      xml_node->xmlChildrenNode, 1);
 	      
 	      g_assert (fgr->comment != NULL);
