@@ -80,7 +80,7 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 						      calcopt))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed computing the polymer's non-capped masses\n"),
+	     _("%s@%d: failed to calculate the non-capped masses of the polymer\n"),
 	     __FILE__, __LINE__);
 
       masscalcres = PXM_MASSCALC_FAILURE;
@@ -105,7 +105,7 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 						 polchemdef))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for caps of the polymer\n"),
+		 _("%s@%d: failed to account for caps of the polymer\n"),
 		 __FILE__, __LINE__);
 
 	  masscalcres = PXM_MASSCALC_FAILURE;
@@ -130,8 +130,8 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 							   polchemdef))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
-		   "left end modif.\n"),
+		 _("%s@%d: failed to account for the left"
+		   " end modif of the polymer.\n"),
 		 __FILE__, __LINE__);
 	  
 	  masscalcres = PXM_MASSCALC_FAILURE;
@@ -154,8 +154,8 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 							    polchemdef))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for polymer's "
-		   "right end modif.\n"),
+		 _("%s@%d: failed to account for the"
+		   " right end modif of the polymer.\n"),
 		 __FILE__, __LINE__);
 	  
 	  masscalcres = PXM_MASSCALC_FAILURE;
@@ -170,7 +170,7 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 
   /******************** IONIZATION REQUIREMENTS**********************/
 
-  /* For the moment the masses computed are for a non-charged polymer:
+  /* For the moment the masses calculated are for a non-charged polymer:
      let's check if caller wants some kind of charge to be put on it.
      For this we also need to know what atom is responsible for the
      charge formation (proton or whatever).
@@ -181,7 +181,7 @@ pxmchem_masscalc_polymer (PxmPolymer *polymer,
 					   polchemdef->atomGPA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for the ionizerule.\n"),
+	     _("%s@%d: failed to account for the ionizerule.\n"),
 	     __FILE__, __LINE__);
       
       masscalcres = PXM_MASSCALC_FAILURE;
@@ -216,7 +216,7 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
 
      Note that the calcopt struct passed as param contains two members
      that will allow us to know which monomer stretch from the GPA
-     should be taken into account during the computation.
+     should be taken into account during the calculatation.
   */
 
   /* Some easy checks to start with, in particular the array of
@@ -240,7 +240,7 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
     }
 
   /* Now check some of the options passed as param pertaining to mass
-   * computation of the non capped chain (make code FOOL PROOF).
+   * calculatation of the non capped chain (make code FOOL PROOF).
    */
 
   /* Left end first. 
@@ -281,8 +281,8 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
    */
   g_assert (calcopt->end_idx >= 0);
   
-  /* NOW start computing the masses of the non-capped polymer by 
-   * accumulating the masses computed for the formula of each
+  /* NOW start calculating the masses of the non-capped polymer by 
+   * accumulating the masses calculated for the formula of each
    * iterated monomer in the GPtrArray of monomer passed as param.
    */
   for (iter = calcopt->start_idx; iter < calcopt->end_idx; iter++)
@@ -297,7 +297,7 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
 						masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting mass for monomer '%s'\n"),
+		 _("%s@%d: failed to account for monomer: '%s'\n"),
 		 __FILE__, __LINE__, monomer->name);
 
 	  
@@ -316,8 +316,8 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
 						      masspair))
 	    {	  
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for modif of "
-		       "monomer named '%s'\n"),
+		     _("%s@%d: failed to account for modif of "
+		       "monomer: '%s'\n"),
 		     __FILE__, __LINE__, monomer->name);
 
 
@@ -331,11 +331,11 @@ pxmchem_masscalc_noncapped_monomer_GPA (GPtrArray *GPA,
     }
   /* end iterating in the GPtrArray of monomers */
 
-  /* At this stage we have the NON CAPPED masses computed for the
+  /* At this stage we have the NON CAPPED masses calculated for the
      given polymer stretch comprised of monomers [calcopt->start_idx -
      calcopt->end_idx]. If the options stated that the monomer modif's
      had to be taken into account, this has been done! Also, here both
-     the masses avg and mono have been computed.
+     the masses avg and mono have been calculated.
    */
 
   return TRUE;
@@ -360,11 +360,12 @@ pxmchem_masscalc_polymer_account_caps (PxmMasspair *masspair,
   if (FALSE != (cap & PXM_CAPPING_LEFT))
     {
       if (FALSE == 
-	  pxmchem_actform_account_mass (polchemdef->leftcap, polchemdef->atomGPA,
+	  pxmchem_actform_account_mass (polchemdef->leftcap, 
+					polchemdef->atomGPA,
 					1 /*times*/, masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for left cap: '%s'\n"),
+		 _("%s@%d: failed to account for left cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->leftcap);
 	  return FALSE;
 	}
@@ -373,11 +374,12 @@ pxmchem_masscalc_polymer_account_caps (PxmMasspair *masspair,
   if (FALSE != (cap & PXM_CAPPING_RIGHT))
     {
       if (FALSE == 
-	  pxmchem_actform_account_mass (polchemdef->rightcap, polchemdef->atomGPA, 
+	  pxmchem_actform_account_mass (polchemdef->rightcap, 
+					polchemdef->atomGPA, 
 					1 /*times*/, masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for right cap: '%s'\n"),
+		 _("%s@%d: failed to account for right cap: '%s'\n"),
 		 __FILE__, __LINE__, polchemdef->rightcap);
 	  return FALSE;
 	}
@@ -414,7 +416,7 @@ pxmchem_masscalc_polymer_account_left_end_modif (PxmPolymer *polymer,
 					  masspair))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for left end modif: '%s'\n"),
+	     _("%s@%d: failed to account for left end modif of the polymer: '%s'\n"),
 	     __FILE__, __LINE__, (gchar *) prop->data);
       return FALSE;
     }
@@ -450,7 +452,7 @@ pxmchem_masscalc_polymer_account_right_end_modif (PxmPolymer *polymer,
 					  masspair))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for right end modif: '%s'\n"),
+	     _("%s@%d: failed to account for right end modif of polymer: '%s'\n"),
 	     __FILE__, __LINE__, (gchar *) prop->data);
       return FALSE;
     }
@@ -505,15 +507,15 @@ pxmchem_masscalc_account_ionizerule (PxmIonizerule *ionizerule,
 				    masspair))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for ionization "
-	       "rule's actform:'%s'\n"),
+	     _("%s@%d: failed to account for the actform of"
+	       " the ionizerule: '%s'\n"),
 	     __FILE__, __LINE__, ionizerule->actform);
       
       return FALSE;
     }
  
   /* OK we have accounted the masspair for the ionizerule->actform by
-     a number of times ionizerule->level. Now we have to compute the
+     a number of times ionizerule->level. Now we have to calculate the
      new m/z ratio according to the charge ionizationrule's member
      along with the ionizerule->level member.
    */
@@ -599,8 +601,8 @@ pxmchem_masscalc_decount_ionizerule (PxmIonizerule *ionizerule,
 				    masspair))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed decounting ionization"
-	       "rule's actform:'%s'\n"),
+	     _("%s@%d: failed to de-count for the actform of the ionization "
+	       "rule:'%s'\n"),
 	     __FILE__, __LINE__, ionizerule->actform);
       
       return FALSE;
@@ -679,21 +681,21 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 					      calcopt))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed calculating oligomer's masses\n"),
+	     _("%s@%d: failed to calculate the masses of the oligomer\n"),
 	     __FILE__, __LINE__);
       
       return PXM_MASSCALC_FAILURE;
     }
   
 
-  /* At this stage we have the NON CAPPED masses computed for the
+  /* At this stage we have the NON CAPPED masses calculated for the
      given polymer stretch comprised of monomers [calcopt->start_idx -
      calcopt->end_idx]. If the options stated that the monomer modif's
      had to be taken into account, this has been done! Also, here both
-     the masses avg and mono have been computed.
+     the masses avg and mono have been calculated.
   */
   
-  /* Here is one part that is a bit tricky with the computing of
+  /* Here is one part that is a bit tricky with the calculating of
      oligomer masses: the cleaverule handling. Each oligomer may
      result from a cleavage that has as side effects the chemical
      modification of the monomers that were bordering the chemical
@@ -734,7 +736,7 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 	       polchemdef->atomGPA))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting cleaverule.\n"),
+		     _("%s@%d: failed to account for cleaverule.\n"),
 		     __FILE__, __LINE__);
 	      
 	      return PXM_MASSCALC_FAILURE;
@@ -759,7 +761,7 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 						 polchemdef))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for caps of the polymer\n"),
+		 _("%s@%d: failed to account for caps of the polymer\n"),
 		 __FILE__, __LINE__);
 
 	  return PXM_MASSCALC_FAILURE;
@@ -789,8 +791,8 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 							       polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "left end modif.\n"),
+		     _("%s@%d: failed to account for the"
+		       " left end modif of the polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      return PXM_MASSCALC_FAILURE;
@@ -818,8 +820,8 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 								polchemdef))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: failed accounting for polymer's "
-		       "right end modif.\n"),
+		     _("%s@%d: failed to account for the "
+		       "right end modif of the polymer.\n"),
 		     __FILE__, __LINE__);
 	      
 	      return PXM_MASSCALC_FAILURE;
@@ -836,7 +838,7 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 
   /******************** IONIZATION REQUIREMENTS**********************/
 
-  /* For the moment the masses computed are for a non-charged polymer:
+  /* For the moment the masses calculated are for a non-charged polymer:
      let's check if caller wants some kind of charge to be put on it.
      For this we also need to know what atom is responsible for the
      charge formation (proton or whatever).
@@ -847,7 +849,7 @@ pxmchem_masscalc_oligomer (PxmOligomer *oligomer,
 						   polchemdef->atomGPA))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: failed accounting for the ionizerule.\n"),
+	     _("%s@%d: failed to account for the ionizerule.\n"),
 	     __FILE__, __LINE__);
       
       return PXM_MASSCALC_FAILURE;
@@ -944,7 +946,7 @@ pxmchem_masscalc_oligomer_account_cleaverule (PxmCleaveRule *lr_rule,
 						1 /*times*/, masspair))
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			 _("%s@%d: failed accounting cleaverule: '%s'\n"),
+			 _("%s@%d: failed to account for actform of cleaverule: '%s'\n"),
 			 __FILE__, __LINE__, lr_rule->left_actform);
 		  
 		  return PXM_MASSCALC_FAILURE;
@@ -989,7 +991,7 @@ pxmchem_masscalc_oligomer_account_cleaverule (PxmCleaveRule *lr_rule,
 						1 /*times*/, masspair))
 		{
 		  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-			 _("%s@%d: failed accounting cleaverule: '%s'\n"),
+			 _("%s@%d: failed to account for actform of cleaverule: '%s'\n"),
 			 __FILE__, __LINE__, lr_rule->right_actform);
 		  
 		  return PXM_MASSCALC_FAILURE;
