@@ -33,7 +33,7 @@
 #endif
 
 #include "pxmchem-modif.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 
 
@@ -447,7 +447,7 @@ pxmchem_modif_validate (PxmModif *modif, GPtrArray *atom_refGPA,
   if (modif->name == NULL)
     {
       g_string_append_printf (gs, 
-			      _("modif has a NULL name\n"));
+			      _("modif has a NULL 'name' member\n"));
     }
   else
     {
@@ -460,7 +460,7 @@ pxmchem_modif_validate (PxmModif *modif, GPtrArray *atom_refGPA,
       if (strlen (help) <= 0)
 	{
 	  g_string_append_printf (gs, 
-				  _("modif has an in valid name: '%s'\n"),
+				  _("modif has an in valid 'name' member: '%s'\n"),
 				  modif->name);
 	}
       
@@ -472,7 +472,7 @@ pxmchem_modif_validate (PxmModif *modif, GPtrArray *atom_refGPA,
   if (modif->actform == NULL)
     {
       g_string_append_printf (gs, 
-			      _("modif has a NULL actform\n"));
+			      _("modif has a NULL 'actform' member\n"));
     }
   else
     {
@@ -482,7 +482,7 @@ pxmchem_modif_validate (PxmModif *modif, GPtrArray *atom_refGPA,
       if (FALSE == pxmchem_actform_check (modif->actform, atom_refGPA))
 	{
 	  g_string_append_printf (gs, 
-				  _("modif has an invalid actform: '%s'\n"),
+				  _("modif has an invalid 'actform' member: '%s'\n"),
 				  modif->actform);
 	}
     }
@@ -647,10 +647,10 @@ pxmchem_modif_account_mass_by_name (gchar *name,
 				    gint times,
 				    PxmMasspair *masspair)
 {
-  /* We have a modif name, and we want to compute its masses
+  /* We have a modif name, and we want to calculate its masses
    * according to its actform ( ie actform of the modif ) - Thus we
    * need to search the modif in the array of modifs pointed to by
-   * refGPA, get its actform and compute the masses from the actform.
+   * refGPA, get its actform and calculate the masses from the actform.
    */
   gint iter = 0;
 
@@ -677,8 +677,8 @@ pxmchem_modif_account_mass_by_name (gchar *name,
 					    masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: error accounting for modif '%s'"
-		       " with actform '%s'\n"),
+		     _("%s@%d: failed to account for modif: '%s'"
+		       " with actform: '%s'\n"),
 		     __FILE__, __LINE__, 
 		     modif->name, modif->actform);
 
@@ -696,7 +696,7 @@ pxmchem_modif_account_mass_by_name (gchar *name,
    * provided in the function parameters. This an error contidition :
    */
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: modif '%s' was not found in the reference array\n"),
+	 _("%s@%d: failed to find modif in the reference array: '%s'\n"),
 	 __FILE__, __LINE__, name);
 
   return FALSE;
@@ -710,10 +710,10 @@ pxmchem_modif_account_elemcompos_by_name (gchar *name,
 					  gint times,
 					  GPtrArray *acGPA)
 {
-  /* We have a modif name, and we want to compute its elemental
+  /* We have a modif name, and we want to calculate its elemental
      contribution according to its actform ( ie actform of the modif )
      - Thus we need to search the modif in the array of modifs pointed
-     to by refGPA, get its actform and compute its contribution into the
+     to by refGPA, get its actform and calculate its contribution into the
      array of atomcount instances passed as parameter.
   */
   gint iter = 0;
@@ -742,8 +742,8 @@ pxmchem_modif_account_elemcompos_by_name (gchar *name,
 						  acGPA))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: error accounting for modif '%s'"
-		       " with formula '%s'\n"),
+		     _("%s@%d: failed to account for modif: '%s'"
+		       " with formula: '%s'\n"),
 		     __FILE__, __LINE__, 
 		     modif->name, modif->actform);
 	      
@@ -762,7 +762,7 @@ pxmchem_modif_account_elemcompos_by_name (gchar *name,
    * provided in the function parameters. This an error condition :
    */
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: modif '%s' was not found in the reference array\n"),
+	 _("%s@%d: failed to find modif from the reference array: '%s'\n"),
 	 __FILE__, __LINE__, name);
 
   return FALSE;
@@ -871,8 +871,7 @@ pxmchem_modif_render_xml_node_mdf (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "mdf"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "mdf"));
   
   /* Now go to the first child of current node: <name>.
    */
@@ -888,8 +887,7 @@ pxmchem_modif_render_xml_node_mdf (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   modif = pxmchem_modif_new ();
   
@@ -898,7 +896,7 @@ pxmchem_modif_render_xml_node_mdf (xmlDocPtr xml_doc,
      assignements, without recoursing to the _set_xxx ().
   */
   modif->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (modif->name != NULL);
     
   /* Now go to the second child: <actform>, which is the next 
@@ -910,11 +908,10 @@ pxmchem_modif_render_xml_node_mdf (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <actform> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "actform"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "actform"));
 
   modif->actform = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (modif->actform != NULL);
   
   /* Finished the rendering of the current <mdf> node.
