@@ -33,7 +33,7 @@
 #endif
 
 #include "pxmchem-monomer.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-formula.h"
 
 
@@ -180,7 +180,7 @@ pxmchem_monomer_set_code (PxmMonomer *monomer, gchar *code)
   if (NULL != strchr (code, libpolyxmass_globals_delim))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with code %s, it was not set.\n"),
+	     _("%s@%d: failed to set monomer code: '%s'\n"),
 	     __FILE__, __LINE__, code);
       
       return FALSE;
@@ -477,7 +477,7 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
   if (monomer->name == NULL)
     {
       g_string_append_printf (gs, 
-			 _("monomer has a NULL name\n"));
+			 _("monomer has a NULL 'name' member\n"));
     }
   else
     {
@@ -490,7 +490,7 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
       if (strlen (help) <= 0)
 	{
 	  g_string_append_printf (gs, 
-			     _("monomer has an invalid name: '%s'\n"),
+			     _("monomer has an invalid 'name' member: '%s'\n"),
 			     monomer->name);
 	}
       
@@ -504,14 +504,14 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
   if (monomer->code == NULL)
     {
       g_string_append_printf (gs, 
-			 _("monomer has a NULL code\n"));
+			 _("monomer has a NULL 'code' member\n"));
     }
   else
     {
       if (FALSE == pxmchem_monomer_check_code_syntax (monomer->code, 
 						      codelen))
 	g_string_append_printf (gs, 
-			   _("monomer has an invalid code: '%s'\n"),
+			   _("monomer has an invalid 'code' member: '%s'\n"),
 			   monomer->code);
     }
   /* Further, the code must not have the globally character that is
@@ -522,7 +522,7 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
   if (NULL != strchr (monomer->code, (gchar) libpolyxmass_globals_delim))
     {
       g_string_append_printf (gs, 
-			 _("monomer has an invalid code: '%s'\n"),
+			 _("monomer has an invalid 'code' member: '%s'\n"),
 			 monomer->code);
     }
   
@@ -532,7 +532,7 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
   if (monomer->formula == NULL)
     {
       g_string_append_printf (gs, 
-			 _("monomer has a NULL formula\n"));
+			 _("monomer has a NULL 'formula' member\n"));
     }
   else
     {
@@ -542,7 +542,7 @@ pxmchem_monomer_validate (PxmMonomer *monomer, gint codelen,
       if (FALSE == pxmchem_formula_check (monomer->formula, atom_refGPA))
 	{
 	  g_string_append_printf (gs, 
-			     _("monomer has an invalid formula: '%s'\n"),
+			     _("monomer has an invalid 'formula' member: '%s'\n"),
 			     monomer->formula);
 	}
     }
@@ -600,6 +600,8 @@ pxmchem_monomer_check_code_syntax (gchar *code, gint max_chars)
   gint iter = 0;
   gint len = 0;
   
+  gsize size = 0;
+
   /* The code must:
    * be at least one char long.
    * start with an uppercase character
@@ -610,7 +612,9 @@ pxmchem_monomer_check_code_syntax (gchar *code, gint max_chars)
 
   g_assert (code != NULL);
   
-  len = strlen (code);
+  size = strlen (code);
+  g_assert (size < G_MAXINT);
+  len = (gint) size;
   
   if (len > max_chars)
     return FALSE;
@@ -1014,10 +1018,10 @@ pxmchem_monomer_account_mass_by_name (gchar *name,
 				      gint times,
 				      PxmMasspair *masspair)
 {
-  /* We have a monomer name, and we want to compute its masses
+  /* We have a monomer name, and we want to calculate its masses
    * according to its formula ( ie formula of the monomer ) - Thus we
    * need to search the monomer in the array of monomers pointed to by
-   * monomerGPA, get its formula and compute the masses from the formula.
+   * monomerGPA, get its formula and calculate the masses from the formula.
    */
   gint iter = 0;
 
@@ -1048,8 +1052,8 @@ pxmchem_monomer_account_mass_by_name (gchar *name,
 					    masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: error accounting mass for monomer '%s'"
-		       " with formula '%s'\n"),
+		     _("%s@%d: failed to account for monomer: '%s'"
+		       " with formula: '%s'\n"),
 		     __FILE__, __LINE__, 
 		     monomer->name, monomer->formula);
 
@@ -1067,7 +1071,7 @@ pxmchem_monomer_account_mass_by_name (gchar *name,
    * provided in the function parameters. This an error contidition :
    */
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: monomer '%s' was not found in the reference array\n"),
+	 _("%s@%d: failed to find monomer in the reference array: '%s'\n"),
 	 __FILE__, __LINE__, name);
 
   return FALSE;
@@ -1081,10 +1085,10 @@ pxmchem_monomer_account_mass_by_code (gchar *code,
 				      gint times,
 				      PxmMasspair *masspair)
 {
-  /* We have a monomer code, and we want to compute its masses
+  /* We have a monomer code, and we want to calculate its masses
    * according to its formula ( ie formula of the monomer ) - Thus we
    * need to search the monomer in the array of monomers pointed to by
-   * monomerGPA, get its formula and compute the masses from the formula.
+   * monomerGPA, get its formula and calculate the masses from the formula.
    */
   gint iter = 0;
 
@@ -1115,8 +1119,8 @@ pxmchem_monomer_account_mass_by_code (gchar *code,
 					    masspair))
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     _("%s@%d: error accounting mass for monomer '%s'"
-		       " with formula '%s'\n"),
+		     _("%s@%d: failed to  account for monomer: '%s'"
+		       " with formula: '%s'\n"),
 		     __FILE__, __LINE__, 
 		     monomer->code, monomer->formula);
 
@@ -1134,7 +1138,7 @@ pxmchem_monomer_account_mass_by_code (gchar *code,
    * provided in the function parameters. This an error contidition :
    */
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 _("%s@%d: monomer '%s' was not found in the reference array\n"),
+	 _("%s@%d: failed to find monomer in the reference array: '%s'\n"),
 	 __FILE__, __LINE__, code);
 
   return FALSE;
@@ -1174,7 +1178,7 @@ pxmchem_monomer_account_mass_for_modif (PxmMonomer *monomer,
 					      masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed accounting for monomer modif '%s'\n"),
+		 _("%s@%d: failed to account for monomer modif: '%s'\n"),
 		 __FILE__, __LINE__, (gchar *)prop->data);
 	  
 	  return FALSE;
@@ -1216,7 +1220,7 @@ pxmchem_monomer_account_elemcompos_for_modif (PxmMonomer *monomer,
 						    acGPA))
 	{
 	    g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		   _("%s@%d: failed accounting for monomer modif '%s'\n"),
+		   _("%s@%d: failed to account for monomer modif: '%s'\n"),
 		   __FILE__, __LINE__, (gchar *)prop->data);
 	  
 	  return FALSE;
@@ -1399,7 +1403,7 @@ pxmchem_monomer_make_delimited_codes_string_by_idces (GPtrArray *GPA,
   if (end_index >= GPA->len)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	     "%s@%d: end index is greater than last array item index\n",
+	    _("%s@%d: 'end_index' index is greater than last array item index\n"),
 	     __FILE__, __LINE__);
 
       end_index = GPA->len - 1;
@@ -1408,7 +1412,7 @@ pxmchem_monomer_make_delimited_codes_string_by_idces (GPtrArray *GPA,
   if (start_index >= GPA->len)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	     "%s@%d: start index is greater than last array item index\n",
+	    _("%s@%d: 'start_index' index is greater than last array item index\n"),
 	     __FILE__, __LINE__);
       
       start_index = 0;
@@ -1483,7 +1487,7 @@ pxmchem_monomer_make_codes_string_by_idces (GPtrArray *GPA,
   if (end_index >= GPA->len)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	     "%s@%d: end index is greater than last array item index\n",
+	    _("%s@%d: end index is greater than last array item index\n"),
 	     __FILE__, __LINE__);
 
       end_index = GPA->len - 1;
@@ -1492,7 +1496,7 @@ pxmchem_monomer_make_codes_string_by_idces (GPtrArray *GPA,
   if (start_index >= GPA->len)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
-	     "%s@%d: start index is greater than last array item index\n",
+	    _("%s@%d: start index is greater than last array item index\n"),
 	     __FILE__, __LINE__);
       
       start_index = 0;
@@ -1525,7 +1529,8 @@ pxmchem_monomer_extract_code_from_string (gchar *code, gint codelen,
   gint len = 0;
   gint iter = 0;
 
-
+  gsize size = 0;
+  
   /* We get a pointer to a string that represents a polymer sequence
    * containing monomer codes. 
    *
@@ -1552,8 +1557,10 @@ pxmchem_monomer_extract_code_from_string (gchar *code, gint codelen,
   g_assert (code != NULL && strlen (code) <= codelen);
   
 
-  len = strlen (seq);
-  
+  size = strlen (seq);
+  g_assert (size < G_MAXINT);
+  len = (gint) size;
+
   if (len <= 0)
     return -1;
 
@@ -1640,7 +1647,7 @@ pxmchem_monomer_extract_code_from_string (gchar *code, gint codelen,
 	  if (is_lower)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: first char of code MUST be UPPERcase\n",
+		    _("%s@%d: first char of code MUST be UPPERcase\n"),
 		     __FILE__, __LINE__);
 
 	      memset (code, '\x0', codelen + 1);
@@ -1736,6 +1743,8 @@ pxmchem_monomer_fill_array_from_string (GPtrArray *fillGPA,
   gint index = 0;
   gint count = 0;
   
+  gsize size = 0;
+  
   gchar *code = NULL;
 
   PxmMonomer *monomer = NULL;
@@ -1761,8 +1770,10 @@ pxmchem_monomer_fill_array_from_string (GPtrArray *fillGPA,
       pxmchem_monomer_GPA_empty (fillGPA);
     }
 
-  seq_len = strlen (seq);
-  
+  size = strlen (seq);
+  g_assert (size < G_MAXINT);
+  seq_len = (gint) size;
+
   if (seq_len == 0)
     return fillGPA->len;
   
@@ -1804,8 +1815,8 @@ pxmchem_monomer_fill_array_from_string (GPtrArray *fillGPA,
 	  */
 
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed getting next valid monomer code"
-		 " from string %s at position %d\n",
+		 _("%s@%d: failed to get next valid monomer code"
+		 " from string: '%s' at position: '%d'\n"),
 		 __FILE__, __LINE__, seq, index + 1);
 	  
 	  g_free (code);
@@ -1824,7 +1835,7 @@ pxmchem_monomer_fill_array_from_string (GPtrArray *fillGPA,
       if (monomer == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: failed allocating monomer from code %s\n",
+	_("%s@%d: failed to allocate monomer from code: '%s'\n"),
 	 __FILE__, __LINE__, code);
 
 	  g_free (code);
@@ -1873,8 +1884,9 @@ pxmchem_monomer_fill_array_from_string_check_errors (GPtrArray *fillGPA,
   gint *errindex = NULL;
   gint count = 0;
 
-  gchar errchar = '\x0';
-    
+  gsize size = 0;
+
+  gchar errchar = '\x0';  
   gchar *code = NULL;
 
   PxmMonomer *monomer = NULL;
@@ -1902,7 +1914,9 @@ pxmchem_monomer_fill_array_from_string_check_errors (GPtrArray *fillGPA,
       pxmchem_monomer_GPA_empty (fillGPA);
     }
 
-  seq_len = strlen (seq);
+  size = strlen (seq);
+  g_assert (size < G_MAXINT);
+  seq_len = (gint) size;
   
   if (seq_len == 0)
     return fillGPA->len;
@@ -2046,7 +2060,7 @@ pxmchem_monomer_count_from_string (gchar* seq, gint codelen,
 	  */
 
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed extracting valid code from string %s\n",
+		_("%s@%d: failed to extract a valid code from string: '%s'\n"),
 		 __FILE__, __LINE__, seq);
 	  
 	  g_free (code);
@@ -2167,12 +2181,12 @@ pxmchem_monomer_format_xml_string_monomer (PxmMonomer *monomer,
         make sense for the current prop instance to be "serialized"
         permanently to disk files.
        */
-      pxmchem_prop_formatter_xml_prop_plugin =
-	pxmchem_prop_choose_format_xml_prop_plugin (prop->name);
+      libpolyxmass_prop_formatter_xml_prop_plugin =
+	libpolyxmass_prop_choose_format_xml_prop_plugin (prop->name);
 
-      if (pxmchem_prop_formatter_xml_prop_plugin != NULL)
+      if (libpolyxmass_prop_formatter_xml_prop_plugin != NULL)
 	{
-	  xml = pxmchem_prop_formatter_xml_prop_plugin (prop, 
+	  xml = libpolyxmass_prop_formatter_xml_prop_plugin (prop, 
 							indent,
 							new_offset,
 							NULL);
@@ -2196,7 +2210,7 @@ pxmchem_monomer_format_xml_string_monomer (PxmMonomer *monomer,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
-		 "%s@%d: plugin prop %s has no registered xml formatter\n",
+		_("%s@%d: plugin prop: '%s' has no registered xml formatter\n"),
 		 __FILE__, __LINE__, prop->name);
 	  
 	}
@@ -2223,6 +2237,90 @@ pxmchem_monomer_format_xml_string_monomer (PxmMonomer *monomer,
 }
 
 
+gchar *
+pxmchem_monomer_format_txt_string_monomer (PxmMonomer *monomer,
+					   PxmReportOpt *reportopt)
+{
+  /* The pointer to the monomer will allow an iteration in the array
+     of prop instances (propGPA) and for each prop instance will call
+     the relevant pluging function which is registered to make the xml
+     string to describe the property object.
+   */
+  gint iter = 0;
+  
+  gchar *txt = NULL;
+  gchar *help = NULL;
+  
+  GString *gs = NULL;
+  
+  PxmProp *prop = NULL;
+  
+
+  g_assert (monomer != NULL && reportopt != NULL);
+  
+  gs = g_string_new ("");
+  g_assert (gs != NULL);
+
+  
+  /* The monomer may have zero, one or more properties, so we must
+   * iterate in its array of property instances.
+   */
+  for (iter = 0; iter < monomer->propGPA->len; iter++)
+    {
+      /* Get the iterated PxmProp object.
+       */
+      prop = g_ptr_array_index (monomer->propGPA, iter);
+      g_assert (prop != NULL && prop->name != NULL);
+
+      /* Ask what function is responsible for formatting the xml
+        string corresponding to the current PxmProp instance.
+      */
+      libpolyxmass_prop_formatter_txt_prop_plugin =
+	libpolyxmass_prop_choose_format_txt_prop_plugin (prop->name);
+      
+      if (libpolyxmass_prop_formatter_txt_prop_plugin != NULL)
+	{
+	  txt = libpolyxmass_prop_formatter_txt_prop_plugin (prop, NULL);
+	  
+	  g_assert (txt != NULL);
+	  
+	  /* In some cases, we want to bypass a given prop processing
+	     (like the monomer chembridge prop, for example) returning
+	     a string that says not to append it to the elongating
+	     gs_prop GString... this is why we check for a "non
+	     applicable" "N/A" pattern. See the chembridge dealing
+	     function write_seq_monomer_chembridge_prop_plugin for an
+	     explanation.
+	  */
+	  if (0 != strcmp ("N/A", txt))
+	    gs = g_string_append (gs, txt);
+	  
+	  g_free (txt);
+	  txt = NULL;
+	}
+      else
+	{
+	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
+		 _("%s@%d: plugin prop: '%s' has no registered txt formatter\n"),
+		 __FILE__, __LINE__, prop->name);
+	  
+	}
+    }
+  /* end of:
+     for (iter = 0; iter < monomer->propGPA->len; iter++)
+   */
+
+  g_string_append_printf (gs, 
+			  _("---------------------------------------------\n"));
+  
+  help = gs->str;
+  
+  g_string_free (gs, FALSE);
+  
+  return help;
+}
+
+
 PxmMonomer *
 pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
 					 xmlNodePtr xml_node,
@@ -2267,8 +2365,7 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "monomer"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "monomer"));
   
   /* Now go to the first child of current node: <code>.
    */
@@ -2284,10 +2381,9 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <code> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "code"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "code"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 
   /* Allocate the monomer instance by using the code that was read
    * from xml data, and by giving the array of reference mononomers
@@ -2301,7 +2397,7 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
   if (monomer == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	 "%s@%d: could not create monomer from code %s\n",
+	 _("%s@%d: failed to create monomer from code: '%s'\n"),
 	     __FILE__, __LINE__, help);
 
       g_free (help);
@@ -2329,8 +2425,8 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
     {
       /* There is a node there, it MUST BE a <prop> element !
        */
-      g_assert (0 == xmlStrcmp ("prop", 
-				(const xmlChar*) xml_node->name));
+      g_assert (0 == strcmp ("prop", 
+			     (gchar *) xml_node->name));
       
       /* Just get the prop's name so that we can get to the
        * proper xml renderer plugin function, without modifying
@@ -2341,21 +2437,21 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
       while (TRUE == xmlIsBlankNode (xml_child_node))
 	xml_child_node = xml_child_node->next;
   
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-			     (const xmlChar*) "name"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, 
+			     "name"));
 
       help = 
-	xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
+	(gchar *) xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
 
-      pxmchem_prop_renderer_xml_prop_plugin = 
-	pxmchem_prop_choose_render_xml_prop_plugin (help);
+      libpolyxmass_prop_renderer_xml_prop_plugin = 
+	libpolyxmass_prop_choose_render_xml_prop_plugin (help);
       
       g_free (help);
       
-      if (pxmchem_prop_renderer_xml_prop_plugin == NULL)
+      if (libpolyxmass_prop_renderer_xml_prop_plugin == NULL)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: plugin prop %s has no registered xml renderer\n",
+		 _("%s@%d: plugin prop: '%s' has no registered xml renderer\n"),
 		 __FILE__, __LINE__, help);
 
 	  pxmchem_monomer_free (monomer);
@@ -2364,7 +2460,7 @@ pxmchem_monomer_render_xml_node_monomer (xmlDocPtr xml_doc,
 	}
       
       prop = 
-	pxmchem_prop_renderer_xml_prop_plugin (xml_doc, xml_node, NULL);
+	libpolyxmass_prop_renderer_xml_prop_plugin (xml_doc, xml_node, NULL);
       g_assert (prop != NULL);
 
       /* Append the newly allocated prop instance to the array of the 
@@ -2435,9 +2531,9 @@ pxmchem_monomer_render_xml_node_codes (xmlDocPtr xml_doc,
   /* Check that we have effectively a <code> element here and that
    * its contents are not NULL.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "codes"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "codes"));
   
-  codes = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  codes = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 
   /* We now have to iterate in the string and extract each monomer
    * code in order to create with it a newly allocated monomer instance.
@@ -2450,8 +2546,8 @@ pxmchem_monomer_render_xml_node_codes (xmlDocPtr xml_doc,
   if (-1 == count)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: failed filling monomer array from string "
-	     "of codes: %s\n",
+	     _("%s@%d: failed to fill monomer array from string "
+	     "of codes: '%s'\n"),
 	     __FILE__, __LINE__, codes);
       
       return -1;
@@ -2572,8 +2668,7 @@ pxmchem_monomer_render_xml_node_mnm (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "mnm"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "mnm"));
   
   /* Now go to the first child of current node: <name>.
    */
@@ -2589,8 +2684,7 @@ pxmchem_monomer_render_xml_node_mnm (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <name> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   monomer = pxmchem_monomer_new ();
   
@@ -2599,7 +2693,7 @@ pxmchem_monomer_render_xml_node_mnm (xmlDocPtr xml_doc,
      assignements, without recoursing to the _set_xxx ().
   */
   monomer->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (monomer->name != NULL);
     
   /* Now go to the second child: <code> which is the next sibling of <name>.
@@ -2610,11 +2704,10 @@ pxmchem_monomer_render_xml_node_mnm (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <code> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "code"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "code"));
 
   monomer->code = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (monomer->code != NULL);
 
   /* Now go to the third child: <formula> which is the next sibling of
@@ -2626,11 +2719,10 @@ pxmchem_monomer_render_xml_node_mnm (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <formula> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "formula"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "formula"));
 
   monomer->formula = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (monomer->formula != NULL);
   
   /* Finished the rendering of the current <mnm> node.
