@@ -47,7 +47,7 @@ pxmchem_oligomer_new (void)
   oligomer->propGPA = g_ptr_array_new ();
 
   /* 'masspair' member is not allocated because an oligo may not need
-     to have masses computed for it.
+     to have masses calculated for it.
   */
 
   return oligomer;
@@ -82,7 +82,7 @@ pxmchem_oligomer_dup (const PxmOligomer *oligomer, gint how_dup)
   oligomer_new->end_idx = oligomer->end_idx;
 
   /* 'masspair' member may not be allocated because an oligo may not need
-     to have masses computed for it.
+     to have masses calculated for it.
   */
   if (oligomer->masspair != NULL)
     oligomer_new->masspair = libpolyxmass_masspair_dup (oligomer->masspair);
@@ -175,152 +175,150 @@ pxmchem_oligomer_with_options_new (PxmPolymer *polymer,
   oligomer->start_idx = start_idx;
   oligomer->end_idx = end_idx;
   
+  /* We always put the informations in the oligomer (if the oligomer
+     is the Left-End oligomer of the polymer sequence, for example, or
+     if the oligomer has an End-modification) but without calculating
+     masses. The masses calculations stuff is down to the bottom of
+     this function.
+  */
+
   /*
     ONLY INFORMATIONAL STUFF, NOT FOR MASS CALCULATIONS...
     ------------------------------------------------------
      
-    Here we want to set properties to the oligomer only if the following
-    data are required to be checked:
+    Here we want to set properties to the oligomer for the following
+    data:
 
-    1. if the oligomer should know if it corresponds to the left
-    end of the parent polymer.
+    1. if the oligomer corresponds to the left end of the parent
+    polymer.
 
-    2.  if the oligomer should know if it corresponds to the right
-    end of the parent polymer.
+    2.  if the oligomer corresponds to the right end of the parent
+    polymer.
   */
-  if (0 != (plm_chement & PXMCHEMENT_PLM_LEFT_MODIF) ||
-      0 != (plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF))
+  if (oligomer->start_idx == 0 && oligomer->end_idx == length - 1)
     {
-      if (oligomer->start_idx == 0 && oligomer->end_idx == length - 1)
-	{
-	  /*
-	    The oligomer is both the left end-terminal and right
-	    end-terminal oligomer.
-	  */
-	  prop_new = 
-	    libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
+      /*
+	The oligomer is both the left end-terminal and right
+	end-terminal oligomer.
+      */
+      prop_new = 
+	libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
 					    "BOTH_ENDS");
-	  
-	  g_ptr_array_add (oligomer->propGPA, prop_new);
-	  
-	  /*
-	    Now that we know that the current oligomer corresponds in
-	    fact to the whole polymer (both left end-terminal and
-	    right end-terminal oligomer of one polymer), we must check
-	    if these two ends are modified or not.
-	  */
-	  prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
+      
+      g_ptr_array_add (oligomer->propGPA, prop_new);
+      
+      /*
+	Now that we know that the current oligomer corresponds in
+	fact to the whole polymer (both left end-terminal and
+	right end-terminal oligomer of one polymer), we must check
+	if these two ends are modified or not.
+      */
+      prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
 						NULL,
 						NULL,
 						"LEFT_END_MODIF",
 						NULL,
 						PXM_UNDEF_PROP_CMP);
-	  if (NULL != prop_found)
+      if (NULL != prop_found)
+	{
+	  if (prop_found->data != NULL)
 	    {
-	      if (prop_found->data != NULL)
-		{
-		  prop_new = libpolyxmass_prop_dup (prop_found,
+	      prop_new = libpolyxmass_prop_dup (prop_found,
 						PXM_MODIF_PROP_DUP_DEEP_YES);
-		  
-		  g_ptr_array_add (oligomer->propGPA, prop_new);
-		}
+	      
+	      g_ptr_array_add (oligomer->propGPA, prop_new);
 	    }
-	  
-	  prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
+	}
+      
+      prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
 						NULL,
 						NULL,
 						"RIGHT_END_MODIF",
 						NULL,
 						PXM_UNDEF_PROP_CMP);
-	  if (NULL != prop_found)
+      if (NULL != prop_found)
+	{
+	  if (prop_found->data != NULL)
 	    {
-	      if (prop_found->data != NULL)
-		{
-		  prop_new = libpolyxmass_prop_dup (prop_found,
+	      prop_new = libpolyxmass_prop_dup (prop_found,
 						PXM_MODIF_PROP_DUP_DEEP_YES);
-		  
-		  g_ptr_array_add (oligomer->propGPA, prop_new);
-		}
+	      
+	      g_ptr_array_add (oligomer->propGPA, prop_new);
 	    }
 	}
-      /* end of 
-	 if (oligomer->start_idx == 0 && oligomer->end_idx == length - 1)
-      */
     }
-  else if (0 != (plm_chement & PXMCHEMENT_PLM_LEFT_MODIF) )
+  /* end of 
+     if (oligomer->start_idx == 0 && oligomer->end_idx == length - 1)
+  */
+  else if (oligomer->start_idx == 0)
     {
-      if (oligomer->start_idx == 0)
-	{
-	  prop_new = 
-	    libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
+      prop_new = 
+	libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
 					    "LEFT_END");
-	  
-	  g_ptr_array_add (oligomer->propGPA, prop_new);
-	  
-	  /*
-	    Now that we know that the current oligomer corresponds in
-	    fact to the left end-terminal oligomer of the polymer),
-	    we must check if these two ends are modified or not.
-	  */
-	  prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
+      
+      g_ptr_array_add (oligomer->propGPA, prop_new);
+      
+      /*
+	Now that we know that the current oligomer corresponds in
+	fact to the left end-terminal oligomer of the polymer),
+	we must check if these two ends are modified or not.
+      */
+      prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
 						NULL,
 						NULL,
 						"LEFT_END_MODIF",
 						NULL,
 						PXM_UNDEF_PROP_CMP);
-	  
-	  if (NULL != prop_found)
+      
+      if (NULL != prop_found)
+	{
+	  if (prop_found->data != NULL)
 	    {
-	      if (prop_found->data != NULL)
-		{
-		  prop_new = libpolyxmass_prop_dup (prop_found,
+	      prop_new = libpolyxmass_prop_dup (prop_found,
 						PXM_MODIF_PROP_DUP_DEEP_YES);
-		  
-		  g_ptr_array_add (oligomer->propGPA, prop_new);
-		}
+	      
+	      g_ptr_array_add (oligomer->propGPA, prop_new);
 	    }
 	}
-      /* end of 
-	 else if (oligomer->start_idx == 0)
-      */
     }
-  else if (0 != (plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF))
+  /* end of 
+     else if (oligomer->start_idx == 0)
+  */
+  else if (oligomer->end_idx == length - 1)
     {
-      if (oligomer->end_idx == length - 1)
-	{
-	  prop_new = 
-	    libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
+      prop_new = 
+	libpolyxmass_prop_both_strings_new ("LEFT_RIGHT_END_OLIGOMER",
 					    "RIGHT_END");
-	  
-	  g_ptr_array_add (oligomer->propGPA, prop_new);
-	  
-	  /*
-	    Now that we know that the current oligomer corresponds in
-	    fact to the left end-terminal oligomer of the polymer),
-	    we must check if these two ends are modified or not.
-	  */
-	  prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
+      
+      g_ptr_array_add (oligomer->propGPA, prop_new);
+      
+      /*
+	Now that we know that the current oligomer corresponds in
+	fact to the left end-terminal oligomer of the polymer),
+	we must check if these two ends are modified or not.
+      */
+      prop_found = libpolyxmass_prop_find_prop (polymer->propGPA,
 						NULL,
 						NULL,
 						"RIGHT_END_MODIF",
 						NULL,
 						PXM_UNDEF_PROP_CMP);
-	  
-	  if (NULL != prop_found)
+      
+      if (NULL != prop_found)
+	{
+	  if (prop_found->data != NULL)
 	    {
-	      if (prop_found->data != NULL)
-		{
-		  prop_new = libpolyxmass_prop_dup (prop_found,
+	      prop_new = libpolyxmass_prop_dup (prop_found,
 						PXM_MODIF_PROP_DUP_DEEP_YES);
-		  
-		  g_ptr_array_add (oligomer->propGPA, prop_new);
-		}
+	      
+	      g_ptr_array_add (oligomer->propGPA, prop_new);
 	    }
 	}
-      /* end of 
-	 else if (oligomer->end_idx == 0)
-      */
     }
+  /* end of 
+     else if (oligomer->end_idx == 0)
+  */
+
 
   /* MASS CALCULATION PROPER STUFF.
    */
@@ -383,7 +381,7 @@ pxmchem_oligomer_with_options_new (PxmPolymer *polymer,
 					      oligomer->masspair))
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 _("%s@%d: failed computing the masses for oligomer '%s'\n"),
+		 _("%s@%d: failed to calculate the masses of oligomer: '%s'\n"),
 		 __FILE__, __LINE__, oligomer->name);	
 	}
     }
