@@ -62,7 +62,7 @@ pxmchem_polchemdefdata_xml_node_choose_renderer (gchar *version)
   
 
   g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
-	 "%s@%d: plugin for version %s has no registered xml renderer\n",
+	_("%s@%d: plugin for version: '%s' has no registered xml renderer\n"),
 	 __FILE__, __LINE__, version);
   
   return NULL;
@@ -125,8 +125,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "polchemdefdata"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "polchemdefdata"));
 
   polchemdef = pxmchem_polchemdef_new ();
 
@@ -144,15 +143,14 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <type> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "type"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "type"));
 
   /* Since we have allocated the polchemdef instance at the line above, we
      know that its member data are NULL, so we can make direct
      assignements, without recoursing to the _set_xxx ().
   */
   polchemdef->type = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->type != NULL && strlen (polchemdef->type) > 0);
     
   /* Go to the next sibling, which according to DTD has to be 
@@ -164,11 +162,10 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <leftcap> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			 (const xmlChar *) "leftcap"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "leftcap"));
   
   polchemdef->leftcap = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->leftcap != NULL && strlen (polchemdef->leftcap) > 0);
 
   /* Go to the next sibling, which according to DTD has to be 
@@ -180,11 +177,10 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <rightcap> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "rightcap"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "rightcap"));
   
   polchemdef->rightcap = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->rightcap != NULL
 	    && strlen (polchemdef->rightcap) > 0);
 
@@ -197,10 +193,9 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <codelen> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "codelen"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "codelen"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 
   if (FALSE == libpolyxmass_globals_strtoi (help, &test, 10))
     {
@@ -208,7 +203,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
       pxmchem_polchemdef_free (polchemdef);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not convert value to gint: %s\n",
+	    _("%s@%d: failed to  convert from '%s' to gint\n"),
 	     __FILE__, __LINE__, xml_node->xmlChildrenNode->content);
       
       return NULL;
@@ -230,8 +225,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <ionizerule> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "ionizerule"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "ionizerule"));
 
   /* Now deal with the <ionizerule> element, and ask the specific 
    * function to read the xml data and make the proper allocations.
@@ -255,7 +249,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
       pxmchem_polchemdef_free (polchemdef);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not render xml ionizerule node\n",
+	    _("%s@%d: failed to render xml ionizerule node\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -270,8 +264,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <monomers> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "monomers"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "monomers"));
   
   /* The <monomers> element may contain no, one, more <mnm> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -285,8 +278,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <mnm>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "mnm"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "mnm"));
       
       monomer = pxmchem_monomer_render_xml_node_mnm (xml_doc,
 						     xml_child_node,
@@ -297,7 +289,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating monomer from xml data\n",
+		_("%s@%d: failed to create monomer from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -320,8 +312,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <modifs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "modifs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "modifs"));
   
   /* The <modifs> element may contain no, one, more <mdf> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -335,8 +326,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <mdf>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "mdf"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "mdf"));
       
       modif = pxmchem_modif_render_xml_node_mdf (xml_doc,
 					     xml_child_node,
@@ -347,7 +337,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating modif from xml data\n",
+		_("%s@%d: failed to create modif from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -370,8 +360,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <cleavespecs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "cleavespecs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "cleavespecs"));
   
   /* The <cleavespecs> element may contain no, one, more <cls> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -385,8 +374,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <cls>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "cls"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "cls"));
       
       cleavespec = pxmchem_cleavespec_render_xml_node_cls (xml_doc,
 						       xml_child_node,
@@ -397,7 +385,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating cleavespec from xml data\n",
+		_("%s@%d: failed to create cleavespec from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -420,8 +408,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <fragspecs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "fragspecs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "fragspecs"));
   
   /* The <fragspecs> element may contain no, one, more <fgs> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -435,8 +422,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <fgs>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "fgs"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "fgs"));
       
       fragspec = pxmchem_fragspec_render_xml_node_fgs (xml_doc,
 						       xml_child_node,
@@ -447,7 +433,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_none (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating fragspec from xml data\n",
+		_("%s@%d: failed to create fragspec from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -522,12 +508,12 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
    * xml element.
    */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "polchemdefdata"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "polchemdefdata"));
 
   polchemdef = pxmchem_polchemdef_new ();
 
-  polchemdef->version = xmlGetProp (xml_node, "version");
+  polchemdef->version = 
+    (gchar *) xmlGetProp (xml_node, (guchar *) "version");
   g_assert (polchemdef->version != NULL);
   
   
@@ -545,15 +531,14 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <type> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "type"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "type"));
 
   /* Since we have allocated the polchemdef instance at the line above, we
      know that its member data are NULL, so we can make direct
      assignements, without recoursing to the _set_xxx ().
   */
   polchemdef->type = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->type != NULL && strlen (polchemdef->type) > 0);
     
   /* Go to the next sibling, which according to DTD has to be 
@@ -565,11 +550,10 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <leftcap> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			 (const xmlChar *) "leftcap"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "leftcap"));
   
   polchemdef->leftcap = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->leftcap != NULL && strlen (polchemdef->leftcap) > 0);
 
   /* Go to the next sibling, which according to DTD has to be 
@@ -581,11 +565,10 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <rightcap> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "rightcap"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "rightcap"));
   
   polchemdef->rightcap = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (polchemdef->rightcap != NULL
 	    && strlen (polchemdef->rightcap) > 0);
 
@@ -598,10 +581,9 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
   
   /* Check that we have effectively a <codelen> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "codelen"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "codelen"));
   
-  help = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+  help = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 
   if (FALSE == libpolyxmass_globals_strtoi (help, &test, 10))
     {
@@ -609,7 +591,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
       pxmchem_polchemdef_free (polchemdef);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not convert value to gint: %s\n",
+	    _("%s@%d: failed to convert from '%s' to gint\n"),
 	     __FILE__, __LINE__, xml_node->xmlChildrenNode->content);
       
       return NULL;
@@ -631,8 +613,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <ionizerule> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "ionizerule"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "ionizerule"));
 
   /* Now deal with the <ionizerule> element, and ask the specific 
    * function to read the xml data and make the proper allocations.
@@ -656,7 +637,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
       pxmchem_polchemdef_free (polchemdef);
       
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: could not render xml ionizerule node\n",
+	    _("%s@%d: failed to render xml ionizerule node\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -671,8 +652,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <monomers> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "monomers"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "monomers"));
   
   /* The <monomers> element may contain no, one, more <mnm> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -686,8 +666,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <mnm>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "mnm"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "mnm"));
       
       monomer = pxmchem_monomer_render_xml_node_mnm (xml_doc,
 						     xml_child_node,
@@ -698,7 +677,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating monomer from xml data\n",
+		_("%s@%d: failed to create monomer from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -721,8 +700,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <modifs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "modifs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "modifs"));
   
   /* The <modifs> element may contain no, one, more <mdf> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -736,8 +714,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <mdf>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "mdf"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "mdf"));
       
       modif = pxmchem_modif_render_xml_node_mdf (xml_doc,
 					     xml_child_node,
@@ -748,7 +725,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating modif from xml data\n",
+		_("%s@%d: failed to create modif from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -771,8 +748,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <cleavespecs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "cleavespecs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "cleavespecs"));
   
   /* The <cleavespecs> element may contain no, one, more <cls> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -786,8 +762,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <cls>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "cls"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "cls"));
       
       cleavespec = pxmchem_cleavespec_render_xml_node_cls (xml_doc,
 						       xml_child_node,
@@ -798,7 +773,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating cleavespec from xml data\n",
+		_("%s@%d: failed to create cleavespec from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
@@ -821,8 +796,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 
   /* Check that we have effectively a <fragspecs> element here.
    */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "fragspecs"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "fragspecs"));
   
   /* The <fragspecs> element may contain no, one, more <fgs> elements.
    * So we should go to the child node, and if the gotten node is non
@@ -836,8 +810,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
     {
       /* A node is found, which should be <fgs>.
        */
-      g_assert (0 == xmlStrcmp (xml_child_node->name, 
-				(const xmlChar *) "fgs"));
+      g_assert (0 == strcmp ((gchar *) xml_child_node->name, "fgs"));
       
       fragspec = pxmchem_fragspec_render_xml_node_fgs (xml_doc,
 						       xml_child_node,
@@ -848,7 +821,7 @@ pxmchem_polchemdefdata_xml_node_renderer_v_0_1 (xmlDocPtr xml_doc,
 	  pxmchem_polchemdef_free (polchemdef);
 	  
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed creating fragspec from xml data\n",
+		_("%s@%d: failed to create fragspec from xml data\n"),
 		 __FILE__, __LINE__);
       
 	  return NULL;
