@@ -300,12 +300,12 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
   if (polchemdef->type == NULL)
     {
       g_string_append_printf (gs, 
-			 _("polchemdef has a NULL type\n"));
+			 _("polchemdef has a NULL 'type' member\n"));
     }
   else
     {
       if (strlen (polchemdef->type) <= 0)
-	g_string_append_printf (gs, _("polchemdef has an invalid type: "
+	g_string_append_printf (gs, _("polchemdef has an invalid 'type' member: "
 				      "'%s'\n"),
 				 polchemdef->type);
     }
@@ -317,14 +317,14 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
   if (polchemdef->leftcap == NULL || strlen (polchemdef->leftcap) <= 0)
     {
       g_string_append_printf (gs, 
-			      _("polchemdef has a NULL or empty leftcap\n"));
+			      _("polchemdef has a NULL or empty 'leftcap' member\n"));
     }
   else
     {
       if (FALSE == pxmchem_actform_check (polchemdef->leftcap, 
 					  polchemdef->atomGPA))
 	g_string_append_printf (gs, _("polchemdef has an invalid"
-				      " leftcap: '%s'\n"),
+				      " 'leftcap' member: '%s'\n"),
 				polchemdef->leftcap);
     }
   
@@ -335,14 +335,14 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
   if (polchemdef->rightcap == NULL || strlen (polchemdef->rightcap) <= 0)
     {
       g_string_append_printf (gs, 
-			 _("polchemdef has a NULL or empty rightcap\n"));
+			 _("polchemdef has a NULL or empty 'rightcap' member\n"));
     }
   else
     {
       if (FALSE == pxmchem_actform_check (polchemdef->rightcap, 
 					  polchemdef->atomGPA))
 	g_string_append_printf (gs, _("polchemdef has an invalid"
-				      " rightcap: '%s'\n"),
+				      " 'rightcap' member: '%s'\n"),
 				polchemdef->rightcap);
     }
   
@@ -351,7 +351,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
   if (polchemdef->ionizerule == NULL)
     {
       g_string_append_printf (gs, 
-			 _("polchemdef has a NULL ionizerule\n"));
+			 _("polchemdef has a NULL 'ionizerule' member\n"));
     }
   else
     {
@@ -361,7 +361,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-			     _("the polchemdef ionizerule has errors:\n%s\n"),
+			     _("the 'ionizerule' member of polchemdef has errors:\n'%s'\n"),
 			     help);
 	  g_free (help);
 	  help = NULL;
@@ -383,7 +383,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 						   polchemdef->monomerGPA))
 	{
 	  g_string_append_printf (gs, 
-			     _("monomer at index %d: name is '%s'"
+			     _("monomer at index: '%d' - name: '%s'"
 			       " is not unique\n"),
 			     iter, monomer->name);
 	}
@@ -392,7 +392,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 						   polchemdef->monomerGPA))
 	{
 	  g_string_append_printf (gs, 
-			     _("monomer at index %d: code is '%s'"
+			     _("monomer at index: '%d' - code: '%s'"
 			       " is not unique\n"),
 			     iter, monomer->code);
 	}
@@ -404,7 +404,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-			     _("monomer at index %d has errors:\n%s\n"),
+			     _("monomer at index: '%d' has errors:\n'%s'\n"),
 			     iter, help);
 	  g_free (help);
 	  help = NULL;
@@ -444,7 +444,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-			     _("modif at index %d has errors:\n%s\n"),
+			     _("modif at index: '%d' has errors:\n'%s'\n"),
 			     iter, help);
 	  g_free (help);
 	  help = NULL;
@@ -463,7 +463,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 					     polchemdef->cleavespecGPA))
 	{
 	  g_string_append_printf (gs,
-			     _("cleavespec at index %d: '%s'"
+			     _("cleavespec at index: '%d' - name: '%s'"
 			       " is not unique\n"),
 			     iter, cleavespec->name);
 	}      
@@ -477,7 +477,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-			     _("cleavespec at index %d has errors:\n%s\n"),
+			     _("cleavespec at index: '%d' has errors:\n'%s'\n"),
 			     iter, help);
 	  g_free (help);
 	  help = NULL;
@@ -495,7 +495,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 						    polchemdef->fragspecGPA))
 	{
 	  g_string_append_printf (gs,
-			     _("fragspec at index %d: '%s'"
+			     _("fragspec at index: '%d' - name: '%s'"
 			       " is not unique\n"),
 			     iter, fragspec->name);
 	}      
@@ -506,7 +506,7 @@ pxmchem_polchemdef_validate_all (PxmPolchemdef *polchemdef, gchar **valid)
 	  g_assert (help != NULL);
 	  
 	  g_string_append_printf (gs, 
-			     _("fragspec at index %d has errors:\n%s\n"),
+			     _("fragspec at index: '%d' has errors:\n'%s'\n"),
 			     iter, help);
 	  g_free (help);
 	  help = NULL;
@@ -1032,7 +1032,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	    _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1045,7 +1045,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1058,7 +1058,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
      return NULL;
@@ -1071,7 +1071,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -1079,11 +1079,11 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
       return NULL;
     }
 
-  if (xmlStrcmp (xml_node->name, (const xmlChar *) "polchemdefdata"))
+  if (0 != strcmp ((gchar *) xml_node->name, "polchemdefdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"polchemdefdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not \"polchemdefdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1096,7 +1096,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
      
      We thus have to get a pointer to the proper function.
   */
-  help = xmlGetProp (xml_node, "version");
+  help = (gchar *) xmlGetProp (xml_node, (guchar *) "version");
   
   pxmchem_polchemdefdata_xml_node_render_plugin = 
     pxmchem_polchemdefdata_xml_node_choose_renderer (help);
@@ -1104,8 +1104,8 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (pxmchem_polchemdefdata_xml_node_render_plugin == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: Failed getting polchemdefdata renderer "
-	       "for XML file format version %s\n"),
+	     _("%s@%d: failed to get the polchemdefdata renderer "
+	       "for XML file format version: '%s'\n"),
 	     __FILE__, __LINE__,
 	     (help != NULL ? help : "(none)"));
       
@@ -1126,7 +1126,7 @@ pxmchem_polchemdef_render_xml_file (gchar *file)
   if (polchemdef == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: Could not render a polchemdef from file: %s\n"),
+	     _("%s@%d: failed to render a polchemdef from file: '%s'\n"),
 	     __FILE__, __LINE__, file);
     }
   else
@@ -1164,7 +1164,7 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	    _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1177,7 +1177,7 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1190,7 +1190,7 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
      return NULL;
@@ -1203,7 +1203,7 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -1211,11 +1211,11 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
       return NULL;
     }
 
-  if (0 != xmlStrcmp (xml_node->name, (const xmlChar *) "polchemdefdata"))
+  if (0 != strcmp ((gchar *) xml_node->name, "polchemdefdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"polchemdefdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not \"polchemdefdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1223,7 +1223,7 @@ pxmchem_polchemdef_get_xml_file_version (gchar *file)
       return NULL;
     }
   
-  help = xmlGetProp (xml_node, "version");
+  help = (gchar *) xmlGetProp (xml_node, (guchar *) "version");
   
   if (help == NULL)
     {
