@@ -36,7 +36,7 @@
 #include "pxmchem-polymer.h"
 #include "pxmchem-monomer.h"
 #include "pxmchem-oligomer.h"
-#include "pxmchem-plugin.h"
+#include "libpolyxmass-plugin.h"
 #include "pxmchem-polymer-plugins.h"
 
 
@@ -372,8 +372,8 @@ pxmchem_polymer_find_sequence_motif (PxmPolymer *polymer,
       if (motif == NULL || strlen (motif) <= 0)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: both 'motif' and 'motifGPA' cannot be "
-		 "NULL or empty\n",
+		 _("%s@%d: both 'motif' and 'motifGPA' cannot be "
+		 "NULL or empty\n"),
 		 __FILE__, __LINE__);
 	  
 	  return -1;
@@ -399,8 +399,8 @@ pxmchem_polymer_find_sequence_motif (PxmPolymer *polymer,
       if (count == -1)
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: failed filling array of monomers with the "
-		 " sequence motif string\n",
+		 _("%s@%d: failed to fill array of monomers with the "
+		 " sequence motif string\n"),
 		 __FILE__, __LINE__);
 	  
 	  return -1;
@@ -432,7 +432,7 @@ pxmchem_polymer_find_sequence_motif (PxmPolymer *polymer,
     9. It would be useless to iterated in the 9-10 indices, because
     the motif is 3 monomers long, and whatever the sequence of the
     oligomer 9-10, the number of monomers available would not be
-    sufficient. So we can compute the 'end' index of the polymer
+    sufficient. So we can calculate the 'end' index of the polymer
     sequence for which it still makes sense to try to find matches
     but after which we can stop iterating because there will be a
     lack of monomers to ensure any match with the motif.
@@ -1202,9 +1202,8 @@ pxmchem_polymer_composition (PxmPolymer *polymer,
       */
 
       /*
-	At this point either we have processed the monomer above,
-	or we could not process it because it was not found
-	in the GPA.
+	At this point either we have processed the monomer above, or
+	we failed to process it because it was not found in the GPA.
       */
       if (processed == TRUE)
 	continue;
@@ -1300,7 +1299,7 @@ pxmchem_polymer_make_codes_string (PxmPolymer *polymer,
 
 
 gint
-pxmchem_polymer_compute_length_from_string (gchar* seq,
+pxmchem_polymer_calculate_length_from_string (gchar* seq,
 					    gboolean check_codes,
 					    gint codelen,
 					    GPtrArray *mnm_refGPA)
@@ -1321,8 +1320,10 @@ pxmchem_polymer_get_current_xml_version (void)
 
 
 /*
-  XML-format TRANSACTIONS
+  Text-format TRANSACTIONS
 */
+
+/***** XML-format *****/
 gchar *
 pxmchem_polymer_get_type_from_xml_file (gchar *file)
 {
@@ -1348,7 +1349,7 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	    _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1362,7 +1363,7 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1376,7 +1377,7 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -1390,7 +1391,7 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -1398,11 +1399,11 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
       return NULL;
     }
 
-  if (0 != xmlStrcmp (xml_node->name, (const xmlChar *) "polseqdata"))
+  if (0 != strcmp ((gchar *) xml_node->name, "polseqdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"polseqdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not  \"polseqdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1424,10 +1425,10 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   while (TRUE == xmlIsBlankNode (xml_node))
     xml_node = xml_node->next;
 
-  if (0 != strcmp ("polseqinfo", xml_node->name))
+  if (0 != strcmp ("polseqinfo", (gchar *) xml_node->name))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is a badly formed xml file: %s\n",
+	    _("%s@%d: file is a badly formed xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1444,14 +1445,14 @@ pxmchem_polymer_get_type_from_xml_file (gchar *file)
   while (TRUE == xmlIsBlankNode (xml_node))
     xml_node = xml_node->next;
 
-  if (0 == xmlStrcmp (xml_node->name, (const xmlChar *) "type"))
+  if (0 == strcmp ((gchar *) xml_node->name, "type"))
     {
-      type = xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+      type = (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
     }
   else
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: failed searching polymer type; DTD error?: %s\n",
+	    _("%s@%d: failed to search the polymer type; DTD error?: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -1648,12 +1649,12 @@ pxmchem_polymer_format_xml_string_polseqdata (PxmPolymer *polymer,
       prop = g_ptr_array_index (polymer->propGPA, iter);
       g_assert (prop != NULL);
       
-      pxmchem_prop_formatter_xml_prop_plugin =
-	pxmchem_prop_choose_format_xml_prop_plugin (prop->name);
+      libpolyxmass_prop_formatter_xml_prop_plugin =
+	libpolyxmass_prop_choose_format_xml_prop_plugin (prop->name);
 
-      if (pxmchem_prop_formatter_xml_prop_plugin != NULL)
+      if (libpolyxmass_prop_formatter_xml_prop_plugin != NULL)
 	{
-	  help = pxmchem_prop_formatter_xml_prop_plugin (prop, 
+	  help = libpolyxmass_prop_formatter_xml_prop_plugin (prop, 
 							 indent,
 							 new_offset,
 							 NULL);
@@ -1661,8 +1662,8 @@ pxmchem_polymer_format_xml_string_polseqdata (PxmPolymer *polymer,
 	  if (help == NULL)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: failed formatting xml string for polymer "
-		     "prop '%s' with plugin\n",
+		     _("%s@%d: failed to format xml string for polymer "
+		     "prop: '%s' with plugin\n"),
 		     __FILE__, __LINE__, prop->name);
 	    }
 	  else
@@ -1685,7 +1686,7 @@ pxmchem_polymer_format_xml_string_polseqdata (PxmPolymer *polymer,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
-		 "%s@%d: prop '%s' has no registered xml formatter plugin\n",
+		_("%s@%d: prop: '%s' has no registered xml formatter plugin\n"),
 		 __FILE__, __LINE__, prop->name);
 	}
     }
@@ -1858,6 +1859,7 @@ pxmchem_polymer_format_xml_string_polseqinfo (PxmPlminfo *plminfo,
 }
 
 
+
 gchar *
 pxmchem_polymer_format_xml_string_polseq_with_mnm_GPA (GPtrArray *GPA, 
 						       gchar *indent, 
@@ -1984,8 +1986,8 @@ pxmchem_polymer_format_xml_string_polseq_with_mnm_GPA (GPtrArray *GPA,
 	  if (gs_codes == NULL)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: plugin prop of name %s has no registered "
-		     "xml formatter... using monomer code only.\n",
+		     _("%s@%d: plugin prop of name: '%s' has no registered "
+		     "xml formatter... using monomer code only.\n"),
 		     __FILE__, __LINE__, prop->name);
 	      
 	      gs_codes = g_string_new ("");
@@ -2083,12 +2085,15 @@ pxmchem_polymer_format_xml_string_polseq_with_mnm_GPA (GPtrArray *GPA,
 }
 
 
+
 gint
 pxmchem_polymer_write_xml_file (PxmPolymer *polymer, gchar *file, 
 				gpointer user_data)
 {
   gint result = -1;
 
+  gsize size = 0;
+  
   gchar *xml = NULL;
       
   FILE *filep = NULL;
@@ -2106,7 +2111,7 @@ pxmchem_polymer_write_xml_file (PxmPolymer *polymer, gchar *file,
   if (filep == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with opening file for writing: '%s'\n"),
+	     _("%s@%d: failed to open file for writing: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return -1;
@@ -2130,7 +2135,7 @@ pxmchem_polymer_write_xml_file (PxmPolymer *polymer, gchar *file,
   if (result == EOF || result < 0)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with saving polymer sequence to file: '%s'\n"),
+	     _("%s@%d: failed to save polymer sequence to file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       g_free (xml);
@@ -2167,7 +2172,9 @@ pxmchem_polymer_write_xml_file (PxmPolymer *polymer, gchar *file,
     can return this value.
   */  
 
-  result = strlen (xml);
+  size = strlen (xml);
+  g_assert (size < G_MAXINT);
+  result = (gint) size;
   
   g_free (xml);
 
@@ -2190,6 +2197,8 @@ pxmchem_plminfo_write_xml_file (PxmPlminfo *plminfo, gchar *file,
   gint offset = 0;
   gint new_offset = 0;
   
+  gsize size = 0;
+  
   gchar *lead = NULL;
   gchar *xml = NULL;
   
@@ -2208,7 +2217,7 @@ pxmchem_plminfo_write_xml_file (PxmPlminfo *plminfo, gchar *file,
   if (filep == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with opening file for writing: '%s'\n"),
+	     _("%s@%d: failed to open file for writing: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return -1;
@@ -2301,7 +2310,7 @@ pxmchem_plminfo_write_xml_file (PxmPlminfo *plminfo, gchar *file,
   if (result == EOF || result < 0)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: error with saving polymer sequence to file: '%s'\n"),
+	     _("%s@%d: failed to save polymer sequence to file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       g_free (xml);
@@ -2315,8 +2324,10 @@ pxmchem_plminfo_write_xml_file (PxmPlminfo *plminfo, gchar *file,
     cannot be 0-length, because we have explicitly written things
     into it in this precise function.
   */  
-  result = strlen (xml);
-  
+  size = strlen (xml);
+  g_assert (size < G_MAXINT);
+  result = (gint) size;
+
   g_free (xml);
 
 
@@ -2362,8 +2373,7 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
     xml element.
   */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "polseqinfo"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "polseqinfo"));
   
   /*
     Now go to the first child of current node: <name>.
@@ -2382,8 +2392,7 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   /*
     Check that we have effectively a <type> element here.
   */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "type"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "type"));
   
   plminfo = pxmchem_plminfo_new ();
   
@@ -2393,7 +2402,7 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
     the _set_xxx ().
   */
   plminfo->type = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (plminfo->type != NULL);
   
   /*
@@ -2406,11 +2415,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   /*
     Check that we have effectively a <name> element here.
   */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "name"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "name"));
 
   plminfo->name = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (plminfo->name != NULL);
 
   /*
@@ -2423,11 +2431,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   /*
     Check that we have effectively a <code> element here.
   */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "code"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "code"));
 
   plminfo->code = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (plminfo->code != NULL);
 
   /*
@@ -2440,11 +2447,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   /*
     Check that we have effectively a <author> element here.
   */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "author"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "author"));
 
   plminfo->author = 
-    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
   g_assert (plminfo->author != NULL);
 
   /*
@@ -2457,8 +2463,7 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   /*
     Check that we have effectively a <date> element here.
   */
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "date"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "date"));
 
   /*
     Go the first child of the <date> element: <year>.
@@ -2468,11 +2473,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode (xml_child_node))
     xml_child_node = xml_child_node->next;
   
-  g_assert (0 == xmlStrcmp (xml_child_node->name, 
-			    (const xmlChar*) "year"));
+  g_assert (0 == strcmp ((gchar *) xml_child_node->name, "year"));
   
   plminfo->date_year = 
-    xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
   g_assert (plminfo->date_year != NULL);
 
   /*
@@ -2482,11 +2486,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode (xml_child_node))
     xml_child_node = xml_child_node->next;
   
-  g_assert (0 == xmlStrcmp (xml_child_node->name, 
-			    (const xmlChar*) "month"));
+  g_assert (0 == strcmp ((gchar *) xml_child_node->name, "month"));
   
   plminfo->date_month = 
-    xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
   g_assert (plminfo->date_month != NULL);
 
   /*
@@ -2496,11 +2499,10 @@ pxmchem_polymer_render_xml_node_polseqinfo (xmlDocPtr xml_doc,
   while (TRUE == xmlIsBlankNode (xml_child_node))
     xml_child_node = xml_child_node->next;
   
-  g_assert (0 == xmlStrcmp (xml_child_node->name, 
-			    (const xmlChar*) "day"));
+  g_assert (0 == strcmp ((gchar *) xml_child_node->name, "day"));
   
   plminfo->date_day = 
-    xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
+    (gchar *) xmlNodeListGetString (xml_doc, xml_child_node->xmlChildrenNode, 1);
   g_assert (plminfo->date_day != NULL);
 
   /*
@@ -2583,8 +2585,7 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
     xml element.
   */
   g_assert (xml_node != NULL);
-  g_assert (0 == xmlStrcmp (xml_node->name, 
-			    (const xmlChar *) "polseq"));
+  g_assert (0 == strcmp ((gchar *) xml_node->name, "polseq"));
   
   g_assert (fillGPA != NULL);
   g_assert (refGPA != NULL);
@@ -2614,11 +2615,10 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
   */
   while (xml_node != NULL)
     {
-      if (0 == xmlStrcmp (xml_node->name, 
-			  (const xmlChar*) "codes"))
+      if (0 == strcmp ((gchar *) xml_node->name, "codes"))
 	{
 	  help = 
-	    xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
+	    (gchar *) xmlNodeListGetString (xml_doc, xml_node->xmlChildrenNode, 1);
 	  
 	  g_assert (help != NULL);
 	  
@@ -2632,7 +2632,7 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
 	  if (count == -1)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: could not fill monomer array with %s\n",
+		    _("%s@%d: failed to fill monomer array with string: '%s'\n"),
 		     __FILE__, __LINE__, help);
 	      
 	      return -1;
@@ -2642,8 +2642,7 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
 	    len = len + count;
 	}
       
-      else if (0 == xmlStrcmp (xml_node->name, 
-			       (const xmlChar*) "monomer"))
+      else if (0 == strcmp ((gchar *) xml_node->name, "monomer"))
 	{
 	  xml_child_node = xml_node;
 	  
@@ -2654,7 +2653,7 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
 	  if (monomer == NULL)
 	    {
 	      g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		     "%s@%d: could not render monomer node\n",
+		    _("%s@%d: failed to render monomer node\n"),
 		     __FILE__, __LINE__);
 	      
 	      return -1;
@@ -2671,7 +2670,7 @@ pxmchem_polymer_render_xml_node_polseq (xmlDocPtr xml_doc,
       else
 	{
 	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-		 "%s@%d: xml document not well-formed.\n",
+		_("%s@%d: xml document not well-formed.\n"),
 		 __FILE__, __LINE__);
 	      
 	  return -1;
@@ -2724,7 +2723,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	    _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2738,7 +2737,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2752,7 +2751,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2766,7 +2765,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -2774,11 +2773,11 @@ pxmchem_polymer_render_xml_file (gchar *file,
       return NULL;
     }
 
-  if (0 != xmlStrcmp (xml_node->name, (const xmlChar *) "polseqdata"))
+  if (0 != strcmp ((gchar *) xml_node->name, "polseqdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"polseqdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not  \"polseqdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -2786,7 +2785,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
       return NULL;
     }
 
-  help = xmlGetProp (xml_node, "version");
+  help = (gchar *) xmlGetProp (xml_node, (guchar *) "version");
   
   pxmchem_polseqdata_xml_node_render_plugin = 
     pxmchem_polseqdata_xml_node_choose_renderer (help);
@@ -2794,8 +2793,8 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (pxmchem_polseqdata_xml_node_render_plugin == NULL)
       {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: Failed getting polseqdata renderer "
-	       "for XML file format version %s\n"),
+	     _("%s@%d: failed to get polseqdata renderer "
+	       "for XML file format version: '%s'\n"),
 	     __FILE__, __LINE__,
 	     (help != NULL ? help : "(none)"));
       
@@ -2820,7 +2819,7 @@ pxmchem_polymer_render_xml_file (gchar *file,
   if (polymer == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     _("%s@%d: Could not render the polymer from file: %s\n"),
+	     _("%s@%d: failed to render the polymer from file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       return NULL;
@@ -2853,7 +2852,7 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file does not exist: %s\n",
+	    _("%s@%d: file not found: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2867,7 +2866,7 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
   if (FALSE == libpolyxmass_globals_check_xml_file (file))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2881,7 +2880,7 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
   if (xml_doc == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is not valid xml format: %s\n",
+	    _("%s@%d: file is not valid xml format: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return NULL;
@@ -2895,7 +2894,7 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
   if (xml_node == NULL)
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is an empty xml file: %s\n",
+	    _("%s@%d: file is an empty xml file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       xmlFreeDoc (xml_doc);
@@ -2903,11 +2902,11 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
       return NULL;
     }
 
-  if (0 != xmlStrcmp (xml_node->name, (const xmlChar *) "polseqdata"))
+  if (0 != strcmp ((gchar *) xml_node->name, "polseqdata"))
     {
       g_log (G_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL,
-	     "%s@%d: file is of wrong type, "
-	     "root node != \"polseqdata\": %s\n",
+	     _("%s@%d: file is of wrong type, "
+	     "root node is not \"polseqdata\": '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       xmlFreeDoc (xml_doc);
@@ -2915,7 +2914,7 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
       return NULL;
     }
   
-  help = xmlGetProp (xml_node, "version");
+  help = (gchar *) xmlGetProp (xml_node, (guchar *) "version");
   
   if (help == NULL)
     {
@@ -2936,8 +2935,296 @@ pxmchem_polymer_get_xml_file_version (gchar *file)
 }
 
 
+/***** TEXT-format *****/
+GString *
+pxmchem_polymer_format_txt_string_polseqinfo (PxmPlminfo *plminfo,
+					      PxmReportOpt *reportopt,
+					      GString *gs)
+{
+  gchar *help = NULL;
+  
+  time_t the_time;
+  struct tm *date_elements;
+  gchar date_element [80] = "'\x0'";
+    
+  g_assert (plminfo != NULL);
+  g_assert (gs != NULL);
+  
+  /*
+    We are willing to create a string that contains the <polseqinfo>
+    data looking like this:
 
 
+    polymer sequence data:
+    ----------------------
+
+    type: protein
+    name: hamster P-glycoprotein
+    code: P09765
+    author: rusconi
+    date: year month day
+  */
+  
+  
+  g_string_append_printf (gs, _("Polymer Sequence Data:\n"
+			  "----------------------\n\n"));
+  
+  /* 
+     The type of the polymer sequence is compulsory.
+  */
+  g_assert (plminfo->type != NULL && strlen (plminfo->type) > 0);
+  g_string_append_printf (gs, "Polymer Type: '%s'\n", plminfo->type);
+  
+  /*
+    The name of the polymer is not formally required, so we have to
+    check this carefully.
+  */
+  if (plminfo->name == NULL || strlen (plminfo->name) <= 0)
+    plminfo->name = g_strdup_printf (_("Name not set"));
+
+  g_string_append_printf (gs, _("Name: '%s'\n"), plminfo->name);
+  
+  /*
+    The code of the polymer is not formally required, so we have to
+    check this carefully.
+  */
+  if (plminfo->code == NULL || strlen (plminfo->code) <= 0)
+    plminfo->code = g_strdup_printf (_("Code not set"));
+
+  g_string_append_printf (gs, _("Code: '%s'\n\n"), plminfo->code);
+  
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_AUTHOR) == 
+      PXM_PLM_REPORTOPT_AUTHOR)
+    {
+      /*
+	Special case of username, since we have to modify the
+	plminfo->author member value, because we are writing this
+	sequence to file. Function g_get_user_name () does not allocate
+	the string.
+      */
+      help = (gchar *) g_get_user_name ();
+      g_assert (help != NULL);
+      g_string_append_printf (gs, _("Author: '%s'\n\n"), help);
+    }
+  
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_DATE) == 
+      PXM_PLM_REPORTOPT_DATE)
+    {
+      /*
+	Special case of the date.
+      */
+      time (&the_time);
+      date_elements = gmtime (&the_time);
+
+      g_string_append_printf (gs, _("Date: "));
+  
+      /* Year
+       */
+      strftime (date_element, 79, "%Y", date_elements);
+      g_string_append_printf (gs, "%s ", date_element);
+
+      /* Month
+       */
+      strftime (date_element, 79, "%m", date_elements);
+      g_string_append_printf (gs, "%s ", date_element);
+
+      /* Date
+       */
+      strftime (date_element, 79, "%d", date_elements);
+      g_string_append_printf (gs, "%s\n\n", date_element);
+    }
+    
+  return gs;
+}
+
+
+GString *
+pxmchem_polymer_format_txt_string_polseq_with_mnm_GPA (GPtrArray *GPA,
+						       PxmReportOpt *reportopt,
+						       GString *gs)
+{
+  gint iter = 0;
+  gint char_count = 0;
+    
+  gchar *help = NULL;
+  
+  GString *gs_seq = NULL;
+  GString *gs_prop = NULL;
+
+  PxmMonomer *monomer = NULL;
+  
+  
+  g_assert (GPA != NULL && reportopt != NULL);
+  g_assert (gs != NULL);
+
+  gs_seq = g_string_new ("");
+  gs_prop = g_string_new ("");
+
+  /*
+    We are willing to create a string describing the polymer sequence
+    looking like this:
+   
+    polymer sequence:
+    -----------------
+
+    MEFEEDWYGEEDWYGTEEDWYGTEEDWYGTEEDWYGTEEDWYGTEEDWYGT
+
+    monomer Y at position 123 has prop "MODIF": Acetylation
+    monomer K at position 136 has prop "COMMENT": This one is methylated
+  */
+  
+  for (iter = 0; iter < GPA->len; iter++)
+    {
+      if (char_count >= 70)
+	{
+	  gs_seq = g_string_append (gs_seq, "\n");
+	  char_count = 0;
+	}
+      
+      monomer = g_ptr_array_index (GPA, iter);
+      g_assert (monomer != NULL);
+      
+      /* First integrate the monomer code in the sequence string.
+       */
+      g_string_append_printf (gs_seq, "%s", monomer->code);
+            
+      char_count += strlen (monomer->code);
+      
+      /* We only deal with monomer prop objects if that is required
+	 by the 'reportopt' argument to the function call.
+      */
+      if ((reportopt->monomer_opt & PXM_MNM_REPORTOPT_PROP) == 
+	  PXM_MNM_REPORTOPT_PROP)
+	{
+	  /* If the monomer has no prop object in its propGPA array, then
+	     we have finished with it. Otherwise, we'll have to format a
+	     string describing its prop object(s) in detail in the gs_prop
+	     string... that we'll append later to the gs_seq sequence
+	     string proper.
+	  */
+	  if (monomer->propGPA->len <= 0)
+	    {
+	      continue;
+	    }
+	  
+	  /*
+	    Apparently, if we are here, that means that there is at least
+	    one prop instance in the monomer->propGPA array of prop
+	    instances. We must deal with it (or them).
+	  */
+	  help = 
+	    pxmchem_monomer_format_txt_string_monomer (monomer, reportopt);
+	  
+	  g_assert (help != NULL);
+	  
+	  g_string_append_printf (gs_prop, 
+				  _("Monomer: '%s' at position: '%d', "
+				  "has\n%s\n\n"), 
+				  monomer->name,
+				  iter,
+				  help);
+	  
+	  g_free (help);
+	}
+    }
+  /*
+    End of:
+    for (iter = 0; iter < GPA->len; iter++)
+  */
+  g_string_append_printf (gs,
+			  _("Polymer Sequence:\n"
+			  "-----------------\n\n"
+			  "%s\n\n"),
+			  gs_seq->str);
+  
+  if ((reportopt->monomer_opt & PXM_MNM_REPORTOPT_PROP) == 
+      PXM_MNM_REPORTOPT_PROP)
+    g_string_append_printf (gs,
+			    _("Monomer Properties:\n"
+			    "-------------------\n\n"
+			    "%s\n\n"),
+			    gs_prop->str);
+    
+  g_string_free (gs_seq, TRUE);
+  g_string_free (gs_prop, TRUE);
+    
+  return gs;
+}
+
+GString *
+pxmchem_polymer_format_txt_string_polymer_prop (PxmPolymer *polymer,
+						PxmReportOpt *reportopt,
+						GString *gs)
+{
+  gint iter = 0;
+  gchar *txt = NULL;
+  
+  GString *gs_local = gs;
+  
+  PxmProp *prop = NULL;
+  
+
+  /* We have to iterate in the array of prop object from the polymer
+     and for each prop instance we have to produce a txt string that we
+     append to the gs GString passed as parameter.
+  */
+  
+
+  g_assert (polymer != NULL);
+  g_assert (reportopt != NULL);
+  g_assert (gs != NULL);
+  
+  
+  for (iter = 0; iter < polymer->propGPA->len; iter++)
+    {
+      /* Get the iterated PxmProp object.
+       */
+      prop = g_ptr_array_index (polymer->propGPA, iter);
+      g_assert (prop != NULL && prop->name != NULL);
+
+      /* Ask what function is responsible for formatting the xml
+        string corresponding to the current PxmProp instance.
+       */
+      libpolyxmass_prop_formatter_txt_prop_plugin =
+	libpolyxmass_prop_choose_format_txt_prop_plugin (prop->name);
+      
+      if (libpolyxmass_prop_formatter_txt_prop_plugin != NULL)
+	{
+	  txt = libpolyxmass_prop_formatter_txt_prop_plugin (prop, NULL);
+	  
+	  g_assert (txt != NULL);
+	  
+	  /* In some cases, we want to bypass a given prop processing
+	     (like the monomer chembridge prop, for example) returning
+	     a string that says not to append it to the elongating
+	     gs_prop GString... this is why we check for a "non
+	     applicable" "N/A" pattern. See the chembridge dealing
+	     function write_seq_monomer_chembridge_prop_plugin for an
+	     explanation.
+	  */
+	  if (0 != strcmp ("N/A", txt))
+	    gs_local = g_string_append (gs_local, txt);
+	  
+	  g_free (txt);
+	  txt = NULL;
+	}
+      else
+	{
+	  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
+		 _("%s@%d: plugin prop: '%s' has no registered txt formatter\n"),
+		 __FILE__, __LINE__, prop->name);
+	  
+	}
+    }
+  /* end of:
+     for (iter = 0; iter < polymer->propGPA->len; iter++)
+  */
+  
+  g_string_append_printf (gs_local, 
+			  _("--------------------------------------------\n\n"));
+  return gs_local;
+}
+
 
 
 
@@ -2971,7 +3258,7 @@ pxmchem_polymer_free (PxmPolymer *polymer)
     {
       if (0 == pxmchem_monomer_GPA_free (polymer->monomerGPA))
 	g_log (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE,
-	       "%s@%d: the polymer's monomers' array was empty.\n",
+	       _("%s@%d: the polymer's monomers' array was empty.\n"),
 	       __FILE__, __LINE__);
     }
   
